<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


// Include the affiliate field in GetPaid discount pages
add_action( 'wpinv_discount_form_last', 'slicewp_add_affiliate_coupon_gpd' );

// Save the affiliate id in the discount meta
add_action( 'getpaid_discount_metabox_save', 'slicewp_save_affiliate_coupon_gpd', 10, 2 );

// Save the affiliate id associated to the discount used in payment
add_filter( 'slicewp_referrer_affiliate_id_gpd', 'slicewp_get_coupon_affiliate_id_gpd', 10, 2 );


/**
 * Show the affiliate field in Easy Digital Downloads discount page
 * 
 * @param WPInv_Discount $discount
 *
 */
function slicewp_add_affiliate_coupon_gpd( $discount ) {

    $affiliate_id = get_post_meta( $discount->get_id(), 'slicewp_affiliate_id', true );
    
    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email      = ( ! empty( $user ) ? $user->user_email : '' );

    }
    
?>

   
	<div class="form-group row">
		<label for="slicewp-affiliate" class="col-sm-3 col-form-label">
			<?php echo __( 'Affiliate Name', 'slicewp' ); ?>
		</label>
		<div class="col-sm-8">
			<input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" style="width: 100%;" />
			<input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
			<?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
		</div>
		<div class="col-sm-1 pt-2 pl-0">
			<span class="wpi-help-tip dashicons dashicons-editor-help" title="<?php echo __( 'Enter the affiliate name that you want to be associated with this discount.', 'slicewp' ); ?>"></span>
		</div>
	</div>

<?php

}

/**
 * Saves the affiliate id in the discount post meta
 * 
 * @param int 			 $discount_id
 * @param WPInv_Discount $discount
 *
 */
function slicewp_save_affiliate_coupon_gpd( $discount_id = 0, $discount ) {

    // Check if the affiliate was deleted from the form and remove it from discount
    if ( empty( $_POST['slicewp_affiliate_id'] ) ) {

        delete_post_meta( $discount_id, 'slicewp_affiliate_id' );
        return;

    }

    // Save the affiliate id in the discount
    update_post_meta( $discount_id, 'slicewp_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}


/**
 * Saves the affiliate id associated to the Discount used in payment
 *
 * @param int $affiliate_id 
 * @param int $invoice_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_gpd( $affiliate_id, $invoice_id ) {

    // Get the payment data
    $invoice = wpinv_get_invoice( $invoice_id );

	// Get the invoice discount code
	$discount_code = $invoice->get_discount_code();

    // Verify if any discounts were used in payment
    if ( empty( $discount_code ) ) {
        return $affiliate_id;
    }

    // Get the discounts used in payment
    $discount = wpinv_get_discount( $discount_code );

    if ( empty( $discount ) ) {
        return $affiliate_id;
    }

	// Get the affiliate id associated with the discount
	$discount_affiliate_id = get_post_meta( $discount->get_id(), 'slicewp_affiliate_id', true );

	if ( ! empty( $discount_affiliate_id ) ) {
        return absint( $discount_affiliate_id );
    }

    // The discounts are not associated to any affiliate
    return $affiliate_id;

}