<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in MemberPress coupon pages
add_action( 'add_meta_boxes', 'slicewp_add_affiliate_coupon_mepr' );

// Save the affiliate id in the coupon meta
add_action( 'save_post_memberpresscoupon', 'slicewp_save_affiliate_coupon_mepr', 10, 2 );

// Save the affiliate id associated to the coupon used in payment
add_filter( 'slicewp_referrer_affiliate_id_mepr', 'slicewp_get_coupon_affiliate_id_mepr', 10, 2 );


/**
 * Add the affiliate box in the MemberPress coupon page
 *
 */
function slicewp_add_affiliate_coupon_mepr() {

    add_meta_box( 'memberpress-coupon-slicewp-affiliate', __( 'SliceWP', 'slicewp' ), 'slicewp_display_affiliate_coupon_mepr', MeprCoupon::$cpt, 'side', 'default' );

}


/**
 * Show the affiliate field in the MemberPress coupon page
 *
 */
function slicewp_display_affiliate_coupon_mepr(){

    global $post;

    $affiliate_id = get_post_meta( $post->ID, 'slicewp_affiliate_id', true );

    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email      = ( ! empty( $user ) ? $user->user_email : '' );

    }
?>

    <p class="form-field slicewp-memberpress-coupon-field">

        <label for="slicewp-affiliate" class="memberpress-meta-box-field-label"><?php echo __( 'Enter the affiliate that you want to be associated with this coupon:', 'slicewp' ); ?></label>
        <input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
        <input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
        <?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
        <?php wp_nonce_field( 'slicewp_meta_box', 'slicewp_token', false ); ?>

    </p>

<?php
}


/**
 * Saves the affiliate id in the coupon post meta
 * 
 * @param int     $coupon_id - the post_id of the post that contains the coupon
 * @param WP_Post $coupon - the post that contains the coupon
 *
 */
function slicewp_save_affiliate_coupon_mepr( $coupon_id = 0, $coupon ) {

    if( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_meta_box' ) ) {
        return $coupon_id;
    }
    
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $coupon_id;
    }

    if ( wp_is_post_revision( $coupon_id ) || wp_is_post_autosave( $coupon_id ) ) {
        return $coupon_id;
    }
  
    // Check if the affiliate was deleted from the form and remove it from discount
    if( empty( $_POST['slicewp_affiliate_id'] ) ) {

        delete_post_meta( $coupon_id, 'slicewp_affiliate_id' );
        return;

    }

    // Save the affiliate id in the discount
    update_post_meta( $coupon_id, 'slicewp_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}


/**
 * Saves the affiliate id associated to the coupon used in transaction
 *
 * @param int $affiliate_id 
 * @param int $transaction_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_mepr( $affiliate_id, $transaction_id ) {

    // Get the payment data
    $transaction = new MeprTransaction( $transaction_id );

    // Verify if any discounts were used in payment
    if ( empty( $transaction->coupon_id ) ) {
        return $affiliate_id;
    }

    // Get the affiliate id from coupon
    $coupon_affiliate_id = get_post_meta( $transaction->coupon_id, 'slicewp_affiliate_id', true );

    if ( ! empty( $coupon_affiliate_id ) ) {
        return absint( $coupon_affiliate_id );
    }

    // The discount is not associated to any affiliate
    return $affiliate_id;

}