<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Paid Memberships Pro discount pages
add_action( 'pmpro_discount_code_after_settings', 'slicewp_add_affiliate_coupon_pmpro' );

// Save the discount code in the affiliate meta
add_action( 'pmpro_save_discount_code', 'slicewp_save_affiliate_coupon_pmpro' );

// Delete the discount code from the affiliate meta
add_action( 'pmpro_delete_discount_code', 'slicewp_delete_affiliate_coupon_pmpro' );

// Save the affiliate id associated with the discount used in order
add_filter( 'slicewp_referrer_affiliate_id_pmpro', 'slicewp_get_coupon_affiliate_id_pmpro', 10, 2 );


/**
 * Show the affiliate field in Paid Memberships Pro discount page
 * 
 * @param int $discount_id
 *
 */
function slicewp_add_affiliate_coupon_pmpro( $discount_id = 0 ) {

    global $wpdb;

    // Get the affiliate id associated with the received discount id
    if ( $discount_id > 0 ) {

        $affiliate_id = $wpdb->get_var( $wpdb->prepare( "SELECT slicewp_affiliate_id FROM $wpdb->slicewp_affiliatemeta WHERE meta_key = %s", '_discount_pmpro_' . $discount_id ) );

    }

    // Get the affiliate information
    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email      = ( ! empty( $user ) ? $user->user_email : '' );

    }
    
?>

    <table class="form-table">
		<tbody>
            <tr>
                <th scope="row" valign="top">
					<label for="slicewp-affiliate"><?php echo __( 'Affiliate Name', 'slicewp' ); ?></label>
				</th>
				<td>
                    <input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
                    <input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
                    <?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
					<p class="description"><?php echo __( 'Enter the affiliate name that you want to be associated with this discount.', 'slicewp' ); ?></p>
				</td>
			</tr>
        </tbody>
    </table>

<?php

}


/**
 * Saves the discount id in the affiliate meta
 * 
 * @param int $discount_id
 *
 */
function slicewp_save_affiliate_coupon_pmpro( $discount_id ) {

    global $wpdb;

    // Get the received discount code from db
    $discount = $wpdb->get_row( "SELECT * FROM $wpdb->pmpro_discount_codes WHERE id = '" . $discount_id . "'" );

    // Get the affiliate id already associated with the discount
    $affiliate_id = slicewp_get_affiliate_id_by_discount_pmpro( $discount->code );
    
    // Check if the affiliate was deleted from the form and remove it from discount
    if ( ! empty( $affiliate_id ) && empty( $_POST['slicewp_affiliate_id'] ) ) {

        slicewp_delete_affiliate_meta( $affiliate_id, '_discount_pmpro_' . $discount_id );
        return;

    }

    // Get the new affiliate id to be associated with the discount
    $new_affiliate_id = absint( $_POST['slicewp_affiliate_id'] );

    // Do nothing if it's the same affiliate
    if ( $new_affiliate_id == $affiliate_id ) {
        return;
    }

    // Delete the previously associated affiliate
    slicewp_delete_affiliate_meta( $affiliate_id, '_discount_pmpro_' . $discount_id );

    // Associate the discount id with the new affiliate
    slicewp_add_affiliate_meta( $new_affiliate_id, '_discount_pmpro_' . $discount_id, $discount->code );

}


/**
 * Returns the affiliate id associated with the discount used in order.
 *
 * @param int         $affiliate_id 
 * @param MemberOrder $order
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_pmpro( $affiliate_id, $order ) {

    $discount_code = ( ! empty( $order->discount_code->code ) && is_string( $order->discount_code->code ) ? $order->discount_code->code : ( ! empty( $_POST['pmpro_discount_code'] ) ? $_POST['pmpro_discount_code'] : '' ) );

    // Verify if any discounts were used in order.
    if ( empty( $discount_code ) ) {
        return $affiliate_id;
    }

    // Check the validity of the discount code.
    if ( ! pmpro_checkDiscountCode( $discount_code ) ) {
        return $affiliate_id;
    }
        
    // Get the affiliate id associated with the discount.
    $discount_affiliate_id = slicewp_get_affiliate_id_by_discount_pmpro( $discount_code );

    if ( ! empty( $discount_affiliate_id ) ) {
        return $discount_affiliate_id;
    }

    // The discount is not associated with any affiliate.
    return $affiliate_id;

}


/**
 * Retrieve the affiliate id associated with a Paid Memberships Pro discount.
 *
 * @param int $discount
 * 
 * @return int|null
 * 
 */
function slicewp_get_affiliate_id_by_discount_pmpro( $discount ){

    global $wpdb;

    // Get from db the affiliate id associated with the discount.
    $affiliate_id = $wpdb->get_var( $wpdb->prepare( "SELECT slicewp_affiliate_id FROM $wpdb->slicewp_affiliatemeta WHERE meta_key LIKE '_discount_pmpro%' AND meta_value = %s", $discount ) );
    
    // Return the affiliate_id
    if ( ! empty ( $affiliate_id ) ) {
        return absint( $affiliate_id );
    }
    
    return 0;

}


/** 
 * Deletes the affiliate meta associated with the discount
 * 
 * @param int $discount_id
 *
 */ 
function slicewp_delete_affiliate_coupon_pmpro( $discount_id ) {

    global $wpdb;

    // Get from db the affiliate id associated with the discount
    $affiliate_id = $wpdb->get_var( $wpdb->prepare( "SELECT slicewp_affiliate_id FROM $wpdb->slicewp_affiliatemeta WHERE meta_key = %s", '_discount_pmpro_' . $discount_id ) );

    // Exit if the discount is not associated with any affiliate
    if ( empty( $affiliate_id ) ) {
        return;
    }

    // Delete the affiliate meta
    slicewp_delete_affiliate_meta( $affiliate_id, '_discount_pmpro_' . $discount_id );

}