<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Restrict Content Pro coupon pages
add_action( 'rcp_add_discount_form', 'slicewp_add_affiliate_coupon_rcp' );
add_action( 'rcp_edit_discount_form', 'slicewp_add_affiliate_coupon_rcp' );

// Save the affiliate id in the discount meta
add_action( 'rcp_add_discount', 'slicewp_save_affiliate_coupon_rcp', 10, 2 );
add_action( 'rcp_edit_discount', 'slicewp_edit_affiliate_coupon_rcp', 10, 2 );

// Delete the discount code from the affiliate meta
add_action( 'rcp_delete_discount', 'slicewp_delete_affiliate_coupon_rcp' );

// Save the affiliate id associated to the discount used in payment
add_filter( 'slicewp_referrer_affiliate_id_rcp', 'slicewp_get_coupon_affiliate_id_rcp', 10, 2 );


/**
 * Show the affiliate field in Restrict Content Pro discount page
 * 
 * @param int $discount_id
 *
 */
function slicewp_add_affiliate_coupon_rcp( $discount_id = 0 ) {
	
	// Get the affiliate id associated with the received discount id
	if ( $discount_id > 0 ) {

		$affiliate_id = slicewp_get_affiliate_id_by_discount_rcp( $discount_id );

	}

	// Get the affiliate information
	if ( ! empty ( $affiliate_id ) ) {

		$affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

		$user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
		$user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
		$user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
		$user_email      = ( ! empty( $user ) ? $user->user_email : '' );

	}
	
?>

	<tr>
		<th scope="row" valign="top">
			<label for="slicewp-affiliate"><?php echo __( 'Affiliate Name', 'slicewp' ); ?></label>
		</th>
		<td>
			<input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
			<input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
			<?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
			<p class="description"><?php echo __( 'Enter the affiliate name that you want to be associated with this discount.', 'slicewp' ); ?></p>
		</td>
	</tr>

<?php

}


/**
 * Add the discount id in the affiliate meta when adding a new discount
 * 
 * @param array $discount_args
 * @param int   $discount_id
 *
 */
function slicewp_save_affiliate_coupon_rcp( $discount_args, $discount_id ) {

	if ( empty( $_POST['rcp-action'] ) || $_POST['rcp-action'] != 'add-discount' ) {
		return;
	}

	// Check for affiliate id
	if ( empty( $_POST['slicewp_affiliate_id'] ) ) {
		return;
	}

	// Add the discount id in the affiliate meta
	slicewp_add_affiliate_meta( absint( $_POST['slicewp_affiliate_id'] ), '_discount_rcp_' . $discount_id, $discount_args['code'] );

}


/**
 * Saves the discount id in the affiliate meta when editing a discount
 * 
 * @param int   $discount_id
 * @param array $discount_args
 *
 */
function slicewp_edit_affiliate_coupon_rcp( $discount_id, $discount_args ) {

	if ( empty( $_POST['rcp-action'] ) || $_POST['rcp-action'] != 'edit-discount' ) {
		return;
	}

	// Get the affiliate id already associated with the discount
	$affiliate_id = slicewp_get_affiliate_id_by_discount_rcp( $discount_id );

	// Check if the affiliate was deleted from the form and remove it from discount
	if ( ! empty( $affiliate_id ) && empty( $_POST['slicewp_affiliate_id'] ) ) {

		slicewp_delete_affiliate_meta( $affiliate_id, '_discount_rcp_' . $discount_id );
		return;

	}

	// Get the new affiliate id to be associated with the discount
	$new_affiliate_id = absint( $_POST['slicewp_affiliate_id'] );

	// If the coupon code changes, make the change in the DB.
	if ( $new_affiliate_id == $affiliate_id ) {

		slicewp_update_affiliate_meta( $affiliate_id, '_discount_rcp_' . $discount_id, $discount_args['code'] );

	} else {

		// Delete the previously associated affiliate
		slicewp_delete_affiliate_meta( $affiliate_id, '_discount_rcp_' . $discount_id );

		// Associate the discount id with the new affiliate
		slicewp_add_affiliate_meta( $new_affiliate_id, '_discount_rcp_' . $discount_id, $discount_args['code'] );
		
	}

}


/**
 * Returns the affiliate id associated with the discount used in order
 *
 * @param int $affiliate_id 
 * @param int $payment_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_rcp( $affiliate_id, $payment_id ) {
	
	// Get the payment
	$payments = new RCP_Payments();
	$payment  = $payments->get_payment( $payment_id );
	
	// Verify if any discounts were used in order
	if ( empty( $payment->discount_code ) ) {
		return $affiliate_id;
	}

	// Get the discount
	$discounts = new RCP_Discounts;
	$discount  = $discounts->get_by( 'code', $payment->discount_code );

	// Get the affiliate id associated with the discount
	$discount_affiliate_id = slicewp_get_affiliate_id_by_discount_rcp( $discount->id );

	if ( ! empty( $discount_affiliate_id ) ) {
		return $discount_affiliate_id;
	}

	// The discount is not associated with any affiliate
	return $affiliate_id;

}


/** 
 * Deletes the affiliate meta associated with the discount
 * 
 * @param int $discount_id
 *
 */ 
function slicewp_delete_affiliate_coupon_rcp( $discount_id ) {

    // Get from db the affiliate id associated with the discount
    $affiliate_id = slicewp_get_affiliate_id_by_discount_rcp( $discount_id );

    // Exit if the discount is not associated with any affiliate
    if ( empty( $affiliate_id ) ) {
		return;
	}

    // Delete the affiliate meta
    slicewp_delete_affiliate_meta( $affiliate_id, '_discount_rcp_' . $discount_id );

}


/**
 * Retrieve the affiliate id associated with a Restrict Content Pro discount
 *
 * @param int $discount_id
 * 
 * @return int
 * 
 */
function slicewp_get_affiliate_id_by_discount_rcp( $discount_id ) {

	global $wpdb;

	// Get from db the affiliate id associated with the discount
	$affiliate_id = $wpdb->get_var( $wpdb->prepare( "SELECT slicewp_affiliate_id FROM $wpdb->slicewp_affiliatemeta WHERE meta_key = %s", '_discount_rcp_' . $discount_id ) );

	// Return the affiliate_id
	if ( ! empty ( $affiliate_id ) ) {
		return absint( $affiliate_id );
	}

	return 0;

}