<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Studiocart for each coupon in product pages
add_filter( 'sc_product_setting_tab_coupons_fields', 'slicewp_add_affiliate_coupon_stc' );

// Update the discount code in the affiliate meta
add_action( 'save_post_sc_product', 'slicewp_save_affiliate_coupon_stc', 25, 2 );

// Save the affiliate id associated with the discount used in order
add_filter( 'slicewp_referrer_affiliate_id_stc', 'slicewp_get_coupon_affiliate_id_stc', 10, 2 );


/**
 * Add the affiliate field in Studiocart product page, coupons tab
 * 
 * @param array $fields
 *
 */
function slicewp_add_affiliate_coupon_stc( $fields ) {

	global $post;

	$coupons = get_post_meta( $post->ID, '_sc_coupons', true );

	$fields[array_search( '_sc_coupons', array_column( $fields, 'id' ) )]['fields'][]['text'] = array(
		'class' 		=> 'widefat',
		'id' 			=> 'slicewp_affiliate_id',
		'label'			=> __( 'Affiliate ID:', 'slicewp' ),
		'description'	=> __( 'Enter the affiliate ID to be associated with this coupon.', 'slicewp' ),
		'type'			=> 'text',
		'value'			=> ''
	);

	return $fields;

}


/**
 * Saves the affiliate id associated with the coupon in the product meta
 * 
 * @param int $post_id
 * @param WP_Post $post
 *
 */
function slicewp_save_affiliate_coupon_stc( $post_id, $post ) {

	// Check if we have any coupons
	if ( empty( $_POST['code'] ) ) {
		return;
	}

	// Get the coupons associated to the product
	$coupons = get_post_meta( $post_id, '_sc_coupons', true );

	// Parse all the coupons
	foreach ( $_POST['code'] as $key => $coupon ) {

		// Save the affiliate id if is associated to the coupon
		$affiliate_id = ( ! empty( $_POST['slicewp_affiliate_id'][$key] ) ? absint( $_POST['slicewp_affiliate_id'][$key] ) : '' );

		foreach ( $coupons as $_key => $coupon_data ) {

			if ( $coupon == $coupon_data['code'] ) {

				$coupons[$key]['slicewp_affiliate_id'] = $affiliate_id;

			}

		}

	}

	// Update the product coupons
	update_post_meta( $post_id, '_sc_coupons', $coupons );

}


/**
 * Returns the affiliate id associated to the coupon used in order
 *
 * @param int $affiliate_id 
 * @param int $order_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_stc( $affiliate_id, $order_id ) {

    // Get the order data
    $order_data = get_post_meta( $order_id );

    // Verify if any discount was used in order
    if ( empty( $order_data['_sc_coupon'][0] ) ) {
		return $affiliate_id;
	}

    // Get the affiliate id associated with the coupon
	$coupons 	= get_post_meta( $order_data['_sc_product_id'][0], '_sc_coupons', true );
	$coupon_key = array_search( $order_data['_sc_coupon_id'][0], array_column( $coupons, 'code' ) );

	$coupon_affiliate_id = ( ! empty( $coupons[$coupon_key]['slicewp_affiliate_id'] ) ? absint( $coupons[$coupon_key]['slicewp_affiliate_id'] ) : 0 );

	if ( ! empty( $coupon_affiliate_id ) ) {
		return $coupon_affiliate_id;
	}

	// The coupon is not associated to any affiliate
    return $affiliate_id;

}