<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Studiocart for each coupon in product pages
add_filter( 'upsell_coupon_field_group', 'slicewp_add_affiliate_coupon_upsell', 10, 2 );

// Returns the affiliate id associated with the discount used in order
add_filter( 'slicewp_referrer_affiliate_id_upsell', 'slicewp_get_coupon_affiliate_id_upsell', 10, 2 );


/**
 * Add the affiliate field in the coupon settings
 * 
 * @param array $fieldGroup
 * @param int $id
 *
 */
function slicewp_add_affiliate_coupon_upsell( $fieldGroup, $id ) {

	if ( isset( $fieldGroup['fields'] ) ) {

		// Add the Affiliate ID field in the coupon settings
		array_splice( $fieldGroup['fields'], 6, 0, 
			array(
				array(
					'key' => 'slicewp_affiliate_id',
					'label' => 'Affiliate ID',
					'name' => 'slicewp_affiliate_id',
					'class' => '',
					'type' => 'number',
					'instructions' => __( 'Enter the affiliate ID that you want to be associated with this coupon.', 'slicewp' ),
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => ''
				)
			)
		);

	}

	return $fieldGroup;

}


/**
 * Returns the affiliate id associated to the coupon used in order
 *
 * @param int $affiliate_id 
 * @param int $order_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_upsell( $affiliate_id, $order_id ) {

	// Get the order coupons
	$coupon_codes = get_post_meta( $order_id, '_coupons', true );

	// Verify if any coupon was used in order
	if ( empty( $coupon_codes ) ) {
		return $affiliate_id;
	}

	// Get the coupons post ids
	$coupon_args = array(
		'numberposts'  => -1,
		'fields'       => 'ids',
		'post_type'    => 'upsell_coupon',
		'meta_key'     => '_coupon_code',
		'meta_value'   => $coupon_codes[0],
		'meta_compare' => 'IN'
	);

	$coupon_ids = get_posts( $coupon_args );

	if ( empty( $coupon_ids ) ) {
		return $affiliate_id;
	}

	// Check if we have any affiliates associated to the coupons used
	foreach ( $coupon_ids as $coupon_id ) {

		// Get the affiliate id associated with the coupon
		$coupon_affiliate_id = absint( get_post_meta( $coupon_id, 'slicewp_affiliate_id', true ) );

		// Return the first affiliate id found
		if ( ! empty( $coupon_affiliate_id ) ) {
			return $coupon_affiliate_id;
		}

	}

	// The coupon is not associated to any affiliate
	return $affiliate_id;

}