<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


// Include the affiliate field in WooCommerce coupon page
add_action( 'woocommerce_coupon_options', 'slicewp_add_affiliate_coupon_woo' );

// Save the affiliate id in the coupon meta
add_action( 'woocommerce_coupon_options_save', 'slicewp_save_affiliate_coupon_woo' );

// Save the affiliate id associated to the coupon used in order
add_filter( 'slicewp_referrer_affiliate_id_woo', 'slicewp_get_coupon_affiliate_id_woo', 10, 2 );

// Appends the WooCommerce coupons attached to the affiliate.
add_filter( 'slicewp_get_affiliate_coupons', 'slicewp_get_affiliate_coupons_add_woo', 10, 2 );


/**
 * Show the affiliate field in WooCommerce coupon page
 *
 */
function slicewp_add_affiliate_coupon_woo() {

    global $post;

    $affiliate_id = get_post_meta( $post->ID, 'slicewp_affiliate_id', true );
    
    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name	 = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email		 = ( ! empty( $user ) ? $user->user_email : '' );

    }
    
?>
    
    <p class="form-field slicewp-woo-affiliate-field">
        <label for="slicewp-affiliate"><?php echo __( 'Affiliate Name', 'slicewp' ); ?></label>
        <span class="slicewp-ajax-search-wrap">
            <span class="slicewp-woo-affiliate-input-wrap">
                <input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
                <input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
                <?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
            </span>
            <span class="woocommerce-help-tip" data-tip="<?php echo __( 'Enter the affiliate name that you want to be associated with this coupon code.', 'slicewp' ); ?>"></span>
            </span>
        </span>
    </p>

<?php

}


/**
 * Saves the affiliate id in the coupon post meta
 * 
 * @param int $coupon_id
 *
 */
function slicewp_save_affiliate_coupon_woo( $coupon_id = 0 ) {

    // Check if the affiliate was deleted from the form and remove it from coupon
    if ( empty( $_POST['slicewp_affiliate_id'] ) ) {

        delete_post_meta( $coupon_id, 'slicewp_affiliate_id' );
        return;

    }

    // Save the affiliate id in the coupon
    update_post_meta( $coupon_id, 'slicewp_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}


/**
 * Saves the affiliate id associated to the coupon used in order
 *
 * @param int $affiliate_id 
 * @param int $order_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_woo( $affiliate_id, $order_id ) {
 
    // Retrieve the order
    $order = wc_get_order( $order_id );

    // Get the coupons used in order
    $coupons = $order->get_coupon_codes();

    // No coupons used
    if ( empty( $coupons ) ) {
        return $affiliate_id;
    }
        
    // Parse all the coupons used in order
    foreach ( $coupons as $code ) {

        $coupon = new WC_Coupon( $code );

        // Save the coupon id
        $coupon_id = ( true === version_compare( WC()->version, '3.0.0', '>=' ) ? $coupon->get_id() : $coupon->id );

        // Get the affiliate id associated with the coupon
        $coupon_affiliate_id = get_post_meta( $coupon_id, 'slicewp_affiliate_id', true );

        if ( ! empty( $coupon_affiliate_id ) ) {
            return absint( $coupon_affiliate_id );
        }

    }

    // The coupons are not associated to any affiliate
    return $affiliate_id;

}


/**
 * Appends the WooCommerce coupons attached to the affiliate.
 * 
 * @param array $coupons
 * @param int   $affiliate_id
 * 
 * @return array
 * 
 */
function slicewp_get_affiliate_coupons_add_woo( $coupons, $affiliate_id ) {

    if ( ! slicewp_is_integration_plugin_active( 'woo' ) || ! slicewp_is_integration_active( 'woo' ) ) {
        return $coupons;
    }

    // Get the IDs for all coupons attached to the given affiliate.
    $args = array(
        'numberposts' => -1,
        'fields'      => 'ids',
        'post_type'   => 'shop_coupon',
        'post_status' => 'publish',
        'meta_key'    => 'slicewp_affiliate_id',
        'meta_value'  => $affiliate_id
    );

    $coupons_ids = get_posts( $args );

    // Bail if affiliate doesn't have any coupons attached.
    if ( empty( $coupons_ids ) ) {
        return $coupons;
    }

    // Go through each coupon and append the coupon data.
    foreach ( $coupons_ids as $coupon_id ) {

        $coupon_type   = get_post_meta( $coupon_id, 'discount_type', true );
        $coupon_amount = get_post_meta( $coupon_id, 'coupon_amount', true );

        if ( 'percent' == $coupon_type ) {

            $amount = $coupon_amount . '%';

        } elseif ( 'fixed_cart' == $coupon_type || 'fixed_product' == $coupon_type ) {

            $amount = wc_price( $coupon_amount );

        } else {

            $amount = $coupon_amount . ' (' . esc_html( wc_get_coupon_type( $coupon_type ) ) . ')';

        }

        // Add the current coupon data.
        $coupons[] = array(
            'origin' => 'woo',
            'id'     => $coupon_id,
            'code'   => get_the_title( $coupon_id ),
            'amount' => $amount
        );

    }

    return $coupons;

}