jQuery( function($) {

	/**
	 * Show the empty affiliate landing pages message.
	 * 
	 */
	if ( $( '#slicewp-card-affiliate-landing-pages .slicewp-affiliate-landing-pages-list .slicewp-affiliate-landing-page' ).length == 0 ) {
		$( '#slicewp-card-affiliate-landing-pages .slicewp-affiliate-landing-pages-empty' ).show();
	}

	/**
	 * Link the affiliate to the landing page.
	 *
	 */
	 $(document).on( 'click', '#slicewp-affiliate-landing-page-link', function(e) {

		e.preventDefault();

		$button = $(this);

		// Exit if no option is selected
		if ( $button.siblings( 'select' ).val() === null || $button.siblings( 'select' ).val() == '' ) {
			return false;
		}

		// Disable select field
		$button.siblings( 'select' ).attr( 'disabled', 'true' );

		// Disable the button
		$button.addClass( 'slicewp-disabled' );

		// Remove the label
		$button.find( 'span' ).hide();

		// Add a spinner
		if ( $button.find( '.spinner' ).length == 0 ) {
			$button.append( '<div class="spinner"></div>' );
		}

		// Remove all messages
		$button.closest( '.slicewp-field-wrapper' ).parent().find( '.slicewp-field-notice' ).fadeOut( 200, function() {
			$(this).remove();
		});

		// Prepare AJAX call data
		var data = {
			action        : 'slicewp_action_ajax_alp_link_affiliate',
			slicewp_token : $('#slicewp_token_alp_link').val(),
			post_id       : $('#slicewp-affiliate-landing-page').val(),
			affiliate_id  : $('#slicewp-affiliate-affiliate-id').val()
		}

		// Make AJAX call
		$.post( ajaxurl, data, function( response ) {

			// Re-enable the select dropdown
			$button.siblings( 'select' ).removeAttr( 'disabled' );

			// Re-enable the button
			$button.removeClass( 'slicewp-disabled' );

			// Remove spinner
			$button.find( '.spinner' ).remove();

			// Show the label
			$button.find( 'span' ).show();

			if ( response.success == false ) {

				$( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' ).insertAfter( '.slicewp-flex-wrapper' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn( 200 );

			} else {

				// Remove the linked post from the select list
				$("#slicewp-affiliate-landing-page option[value='" + data.post_id + "']").each(function() {
					$(this).remove();
				});

				// Clear the selected option
				$('#slicewp-affiliate-landing-page').val(null).trigger('change');

				// Show the success message
				$( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' ).insertAfter( '.slicewp-flex-wrapper' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn( 200 );

				// Add the linked landing page at the end of the list
				$( '.slicewp-affiliate-landing-pages-list' ).append( $(response.data.landing_page).hide().fadeIn( 200 ) );

				// Update the hidden input containing the post args
				if ( document.getElementById('slicewp_post_args') ) {

					post_args = JSON.parse( $('#slicewp_post_args').val() )
					post_args['exclude'].push( parseInt( data.post_id ) );
 					$('#slicewp_post_args').val( JSON.stringify( post_args ) );

				}

				// Update the hidden input containing the affiliate landing pages id
				var affiliate_landing_page_ids = [];

				$('.slicewp-affiliate-landing-page-unlink').each( function() {
					affiliate_landing_page_ids.push( parseInt( $(this).attr( 'data-landing-page-id' ) ) )
				});

				$('[name="affiliate_landing_page_ids"]').val( affiliate_landing_page_ids.join( ',' ) );

				// Hide the empty affiliate landing pages message.
				$( '#slicewp-card-affiliate-landing-pages .slicewp-affiliate-landing-pages-empty' ).hide();

			}

		});

	});


	/**
	 * Unlink the affiliate from the landing page
	 *
	 */
	 $(document).on( 'click', '.slicewp-affiliate-landing-page-unlink a', function(e) {

		e.preventDefault();

		// Wait for confirmation
		if ( ! confirm ( $(this).attr( 'data-message' ) ) )
			return false;

		$(this).blur();

		$button = $(this).parent();

		// Add a spinner
		if ( $button.closest('.slicewp-affiliate-landing-page').find( '.spinner' ).length == 0 )
			$button.closest('.slicewp-affiliate-landing-page').prepend( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );

		// Prepare AJAX call data
		var data = {
			action        : 'slicewp_action_ajax_alp_unlink_affiliate',
			slicewp_token : $('#slicewp_token_alp_link').val(),
			post_id       : $button.attr('data-landing-page-id'),
			post_title    : $button.attr('data-landing-page-title'),
			affiliate_id  : $('#slicewp-affiliate-affiliate-id').val()
		}

		// Make AJAX call.
		$.post( ajaxurl, data, function( response ) {

			if ( response.success == true ) {

				// Remove the unlinked landing page from the list.
				$button.closest('.slicewp-affiliate-landing-page').fadeOut( 200, function() {

					$(this).remove();

					// Show the empty affiliate landing pages message.
					if ( $( '#slicewp-card-affiliate-landing-pages .slicewp-affiliate-landing-pages-list .slicewp-affiliate-landing-page' ).length == 0 ) {
						$( '#slicewp-card-affiliate-landing-pages .slicewp-affiliate-landing-pages-empty' ).show();
					}
					
				});

				// Add the unlinked page in the select list.
				if ( ! document.getElementById( 'slicewp_post_args' ) ) {

					var unlinkedPage = new Option( data.post_title, data.post_id, false, false );
					$('#slicewp-affiliate-landing-page').append( unlinkedPage ).trigger( 'change' );

				} else {

					post_args = JSON.parse( $('#slicewp_post_args').val() );

					if ( post_args['exclude'].indexOf( parseInt( data.post_id ) ) > -1 ) {

						post_args['exclude'].splice( post_args['exclude'].indexOf( parseInt( data.post_id ) ), 1 );
						$('#slicewp_post_args').val( JSON.stringify( post_args ) );

					}

				}

				// Update the hidden input containing the affiliate landing pages id.
				var affiliate_landing_page_ids = [];

				$('.slicewp-affiliate-landing-page-unlink').each( function() {

					if ( $(this).attr( 'data-landing-page-id' ) != data.post_id )
						affiliate_landing_page_ids.push( parseInt( $(this).attr( 'data-landing-page-id' ) ) )

				});

				$('[name="affiliate_landing_page_ids"]').val( affiliate_landing_page_ids.join( ',' ) );

			}

		});

	});


	/**
	 * Copy the Affiliate Landing URL.
	 *
	 */
	 $(document).on( 'click', 'a.slicewp-copy-link', function(e) {

		e.preventDefault();

		navigator.clipboard.writeText( $(this).siblings('span').text() );

	 });
	 

    /**
     * Page: Affiliates.
     *
     */
	 $(document).on( 'click', '.slicewp-wp-list-table.slicewp_landing_pages .column-title .slicewp-tooltip-wrapper', function() {

        var $tooltip = $(this);

        if( $tooltip.hasClass( 'slicewp-copied' ) ) {
			return false;
		}

		navigator.clipboard.writeText( $tooltip.siblings('a').attr('href') );

        $tooltip.addClass( 'slicewp-copied' );

        $tooltip.find( '.slicewp-tooltip-message span:nth-child(1)' ).hide();
        $tooltip.find( '.slicewp-tooltip-message span:nth-child(2)' ).fadeIn( 200 );

        setTimeout( function() {

            $tooltip.removeClass( 'slicewp-copied' );
            $tooltip.removeClass( 'slicewp-hover' );

        }, 1500 );

        setTimeout( function() {

            $tooltip.find( '.slicewp-tooltip-message span:nth-child(1)' ).fadeIn( 200 );
            $tooltip.find( '.slicewp-tooltip-message span:nth-child(2)' ).hide();

        }, 1750 );

    });

    var affiliate_url_tooltip_hover;

    $(document).on( 'mouseenter', '.slicewp-wp-list-table.slicewp_landing_pages .column-title .slicewp-tooltip-wrapper', function(e) {
        
        var $this = $(this);

        affiliate_url_tooltip_hover = setTimeout( function() {
            $this.addClass('slicewp-hover');
        }, 600 );

    });

    $(document).on( 'mouseleave', '.slicewp-wp-list-table.slicewp_landing_pages .column-title .slicewp-tooltip-wrapper', function(e) {

        $(this).removeClass('slicewp-hover');
        
        clearTimeout( affiliate_url_tooltip_hover );

    });

});
