<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Links the affiliate to the landing page.
 *
 */
function slicewp_action_ajax_alp_link_affiliate() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_alp_link' ) ) {
		wp_die( 0 );
	}

	if ( ! current_user_can( 'manage_options' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['post_id'] ) ) {
		wp_die( 0 );
	}

	// Prepare variables
	$post_id 	  = absint( $_POST['post_id'] );
	$affiliate_id = ( ! empty( $_POST['affiliate_id'] ) ? absint( $_POST['affiliate_id'] ) : 0 );

	// Check if the post is linked to another affiliate
	$linked_affiliate_id = slicewp_alp_get_landing_page_affiliate_id( $post_id );

	if ( empty( $linked_affiliate_id ) ) {

		// Add the affiliate id in post meta
		if ( ! empty( $affiliate_id ) ) {
			update_post_meta( $post_id, 'slicewp_landing_page_affiliate_id', $affiliate_id );
		}

		// Prepare the landing page HTML card
		$landing_page  = '<div class="slicewp-affiliate-landing-page">';
		$landing_page .= '	<div class="slicewp-affiliate-landing-page-details">';
		$landing_page .= '		<div class="slicewp-affiliate-landing-page-title">' . esc_html( get_the_title( $post_id ) ) . '</div>';
		$landing_page .= '		<div class="slicewp-affiliate-landing-page-permalink"><a href="' . esc_url( get_permalink( $post_id ) ) . '" target="_blank">' . esc_url( get_permalink( $post_id ) ) . '</a></div>';
		$landing_page .= '	</div>';
		$landing_page .= '	<div class="slicewp-affiliate-landing-page-actions">';
		$landing_page .= '		<a href="' . esc_url( get_edit_post_link( $post_id ) ) . '">' . __( 'Edit page', 'slicewp' ) . '</a>';
		$landing_page .= '		<span class="slicewp-affiliate-landing-page-unlink slicewp-trash" data-landing-page-id="' . absint( $post_id ) . '" data-landing-page-title="' . esc_html( get_the_title( $post_id ) ) . '"><a href="#" data-message="' . __( 'Are you sure you want to unlink the affiliate from this landing page?', 'slicewp' ) . '">' . __( 'Unlink', 'slicewp' ) . '</a></span>';
		$landing_page .= '	</div>';
		$landing_page .= '</div>';

		// Send success message
		wp_send_json_success( array( 'message' => __( 'Affiliate linked succesfully to the landing page.', 'slicewp' ), 'landing_page' => $landing_page ) );

	} else {

		// Send error message
		wp_send_json_error( array( 'message' => __( 'The selected landing page is linked to another affiliate.', 'slicewp' ) ) );

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_alp_link_affiliate', 'slicewp_action_ajax_alp_link_affiliate' );


/**
 * Unlinks the affiliate from the landing page.
 *
 */
function slicewp_action_ajax_alp_unlink_affiliate() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_alp_link' ) ) {
		wp_die( 0 );
	}

	if ( ! current_user_can( 'manage_options' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['post_id'] ) ) {
		wp_die( 0 );
	}

	$post_id = absint( $_POST['post_id'] );

	// Delete the post meta containing the affiliate id
	$deleted = delete_post_meta( $post_id, 'slicewp_landing_page_affiliate_id' );

	// Check if everything went ok and send the status
	if ( ! $deleted ) {
		wp_send_json_error();
	} else {
		wp_send_json_success();
	}

}
add_action( 'wp_ajax_slicewp_action_ajax_alp_unlink_affiliate', 'slicewp_action_ajax_alp_unlink_affiliate' );