<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Include the landing pages in the add/edit affiliate page.
 *
 */
function slicewp_alp_add_landing_pages_affiliate() {

	if ( slicewp_is_add_on_active( 'affiliate_landing_pages' ) ) {
		include_once 'views/view-affiliate-landing-pages-affiliate.php';
	}

}
add_action( 'slicewp_view_affiliates_add_affiliate_bottom', 'slicewp_alp_add_landing_pages_affiliate' );
add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', 'slicewp_alp_add_landing_pages_affiliate' );


/**
 * Adds the affiliate landing page metabox.
 *
 * @param string  $post_type
 * @param WP_Post $post
 *
 */
function slicewp_alp_add_landing_page_metabox( $post_type, $post ) {

	// Check if the user is administrator.
	if ( ! current_user_can( 'administrator' ) ) {
		return;
	}

	// Check if we're on a post or page.
	if ( ! in_array( $post_type, array( 'post', 'page' ) ) ) {
		return;
	}

	// Check if add-on is enabled.
	if ( ! slicewp_is_add_on_active( 'affiliate_landing_pages' ) ) {
		return;
	}

	// Check that this is not the all posts page or the home page.
	if ( in_array( $post->ID, array( get_option( 'page_on_front' ), get_option( 'page_for_posts' ) ) ) ) {
		return;
	}

	// Add the metabox.
	add_meta_box( 'slicewp_metabox_affiliate_landing_page', __( 'Affiliate Landing Page', 'slicewp' ), 'slicewp_alp_add_landing_page_settings', $post_type, 'side', 'high' );

}
add_action( 'add_meta_boxes', 'slicewp_alp_add_landing_page_metabox', 10, 2 );


/**
 * Adds the affiliate landing page settings in the metabox.
 *
 */
function slicewp_alp_add_landing_page_settings() {

	global $post;

	// Get the landing page affiliate ID.
	$affiliate_id = get_post_meta( $post->ID, 'slicewp_landing_page_affiliate_id', true );

	// Get affiliate data.
	if ( ! empty ( $affiliate_id ) ) {

		$affiliate = slicewp_get_affiliate( $affiliate_id );

		$user_id = ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 );
		$user    = get_userdata( $user_id );

		$user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
		$user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
		$user_email      = ( ! empty( $user ) ? $user->user_email : '' );

	}

	?>

		<div id="slicewp_alp_settings" class="slicewp-options-groups-wrapper">

			<div class="slicewp-options-group">

				<div class="slicewp-option-field-wrapper" style="margin-top: 0;">
					<input id="slicewp-affiliate" style="width: 100%;" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
					<input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate ) ? $affiliate->get( 'id' ) : '' ) ); ?>" />
					<?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
					<p class="description"><?php echo __( 'Search and select the affiliate that you want to be associated with this landing page.', 'slicewp' ); ?></p>
				</div>

			</div>

		</div>

	<?php

	// Add nonce field
	wp_nonce_field( 'slicewp_alp_save_meta', 'slicewp_token', false );

}


/**
 * Saves the affiliate id in the affiliate landing page meta.
 *
 * @param int $post_id - the id of the post
 *
 */
function slicewp_alp_save_affiliate_id( $post_id ) {

	// Verify for nonce
	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_alp_save_meta' ) ) {
		return;
	}

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
		return;
	}
	
	// Check if the user is administrator.
	if ( ! current_user_can( 'administrator' ) ) {
		return;
	}

	// Check if the affiliate has to be removed from post meta.
	if ( empty( $_POST['slicewp_affiliate_id'] ) ) {

		delete_post_meta( $post_id, 'slicewp_landing_page_affiliate_id' );
		return;

	}

	// Save the affiliate id in the post meta
	update_post_meta( $post_id, 'slicewp_landing_page_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}
add_action( 'save_post', 'slicewp_alp_save_affiliate_id', 10, 2 );


/**
 * Updates the affiliate_id for the landing pages that have been linked on the add new affiliate page.
 *
 * @param int $affiliate_id
 *
 */
function slicewp_alp_insert_affiliate_update_landing_page_affiliate_id( $affiliate_id ) {

	if ( ! slicewp_verify_request_action( 'add_affiliate' ) ) {
		return;
	}

	if ( empty( $_POST['affiliate_landing_page_ids'] ) ) {
		return;
	}

	$landing_page_ids = array_unique( array_map( 'absint', explode( ',', $_POST['affiliate_landing_page_ids'] ) ) );

	// Add the affiliate id in the post meta.
	foreach ( $landing_page_ids as $landing_page_id ) {

		if ( empty( $landing_page_id ) ) {
			continue;
		}

		update_post_meta( $landing_page_id, 'slicewp_landing_page_affiliate_id', absint( $affiliate_id ) );

	}

}
add_action( 'slicewp_insert_affiliate', 'slicewp_alp_insert_affiliate_update_landing_page_affiliate_id' );


/**
 * Delete the affiliate id from landing page meta when deleting an affiliate.
 *
 * @param int $affiliate_id
 *
 */
function slicewp_alp_delete_affiliate_remove_landing_page_affiliate_id( $affiliate_id ) {

	// Get affiliate landing pages.
	$landing_page_ids = slicewp_get_affiliate_landing_pages( $affiliate_id );

	// Check if we have any landing pages for this affiliate.
	if ( empty( $landing_page_ids ) ) {
		return;
	}

	// Delete the affiliate id from landing page meta
	foreach ( $landing_page_ids as $landing_page_id ) {

		delete_post_meta( $landing_page_id, 'slicewp_landing_page_affiliate_id' );

	}

}
add_action( 'slicewp_delete_affiliate', 'slicewp_alp_delete_affiliate_remove_landing_page_affiliate_id' );