<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

?>

<div id="slicewp-card-affiliate-landing-pages" class="slicewp-card">

	<div class="slicewp-card-header">
		<span class="slicewp-card-title"><?php echo __( 'Landing Pages', 'slicewp' ); ?></span>
		<?php echo slicewp_output_tooltip( __( 'Select the landing pages that you want this affiliate to be linked to.', 'slicewp' ) ); ?>
	</div>

	<div class="slicewp-card-inner">

		<!-- Affiliate Landing Pages -->
		<div class="slicewp-field-wrapper slicewp-field-wrapper-affiliate-landing-pages slicewp-last">

			<div class="slicewp-flex-wrapper">

				<?php

					// Exclude the landing pages that already have a linked affiliate
					$excluded_posts_args = array(
						'numberposts' => -1,
						'post_type'	  => 'any',
						'meta_key'	  => 'slicewp_landing_page_affiliate_id',
						'fields'      => 'ids'
					);

					$excluded_post_ids = get_posts( $excluded_posts_args );

					// Also exclude the front page and the posts page from the list.
					array_push( $excluded_post_ids, absint( get_option( 'page_on_front' ) ), absint( get_option( 'page_for_posts' ) ) );

					// Prepare field args.
					$field_args = array(
						'id'    	 => 'slicewp-affiliate-landing-page',
						'name'  	 => 'slicewp_affiliate_landing_page',
						'query_args' => array(
							'post__not_in' => $excluded_post_ids
						)
					);

					// Output the posts field
					slicewp_output_select2_posts_search( $field_args );

				?>

				<a id="slicewp-affiliate-landing-page-link" class="slicewp-button-secondary" href="#">
					<span class="slicewp-affiliate-landing-page-link"><?php echo __( 'Link Affiliate', 'slicewp' ); ?></span>
				</a>

				<?php wp_nonce_field( 'slicewp_alp_link', 'slicewp_token_alp_link', false ); ?>

			</div>

			<div class="slicewp-affiliate-landing-pages-list">

				<?php

					// Check if we have any landing pages set for this affiliate
					if ( ! empty( $_POST['affiliate_landing_page_ids'] ) ) {

						$landing_page_ids = explode( ',', $_POST['affiliate_landing_page_ids'] );

					} else if ( ! empty( $_GET['affiliate_id'] ) ) {

						$landing_page_ids = slicewp_get_affiliate_landing_pages( absint( $_GET['affiliate_id'] ) );

					}

					if ( ! empty( $landing_page_ids ) ) {

						// Get the affiliate landing pages
						$landing_pages_args = array(
							'numberposts' => -1,
							'post_type'   => 'any',
							'include'     => $landing_page_ids
						);

						$landing_pages = get_posts( $landing_pages_args );

						// Show the affiliate landing pages
						if ( ! empty ( $landing_pages ) ) {

							foreach ( $landing_pages as $landing_page ) {

								?>

									<div class="slicewp-affiliate-landing-page">
										<div class="slicewp-affiliate-landing-page-details">
											<div class="slicewp-affiliate-landing-page-title"><?php echo esc_html( $landing_page->post_title ); ?></div>
											<div class="slicewp-affiliate-landing-page-permalink"><a href="<?php echo esc_url( get_permalink( $landing_page->ID ) ); ?>" target="_blank"><?php echo esc_url( get_permalink( $landing_page->ID ) ); ?></a></div>
										</div>

										<div class="slicewp-affiliate-landing-page-actions">
											<a href="<?php echo esc_url( get_edit_post_link( $landing_page->ID ) ); ?>"><?php echo __( 'Edit page','slicewp' ); ?></a>
											<span class="slicewp-affiliate-landing-page-unlink slicewp-trash" data-landing-page-id="<?php echo esc_attr( $landing_page->ID ) ?>" data-landing-page-title="<?php echo esc_html( $landing_page->post_title ); ?>"><a href="#" data-message="<?php echo __( 'Are you sure you want to unlink the affiliate from this landing page?', 'slicewp' ); ?>"><?php echo __( 'Unlink','slicewp' ); ?></a></span>
											<br>
										</div>
									</div>

								<?php

							}

						}

					}

				?>

			</div>

			<div class="slicewp-affiliate-landing-pages-empty" style="display: none;">
				<p><?php echo __( 'No posts or pages are linked to this affiliate.', 'slicewp' ); ?></p>
			</div>

			<input type="hidden" name="affiliate_landing_page_ids" value="<?php echo( ! empty( $landing_page_ids ) ? implode( ',', $landing_page_ids ) : '' ); ?>" />

		</div>
		<!-- / Affiliate Landing Pages -->

	</div>

</div>