<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Outputs the CSS needed for the affiliate landing pages card in the affiliate account page.
 *
 * @param string $slug
 * @param string $name
 * @param array  $templates
 * @param array  $args
 *
 */
function slicewp_affiliate_account_tab_affiliate_landing_pages_styling( $slug, $name, $templates, $args ) {

	if ( 'affiliate-area/affiliate-account-tab-affiliate_links' != $slug ) {
		return;
	}

	// Get the affiliate landing pages.
	$landing_pages = slicewp_get_affiliate_landing_pages( absint( $args['affiliate_id'] ) );

	if ( empty( $landing_pages ) ) {
		return;
	}

	?>

	<style>

		.slicewp-card-affiliate-landing-pages .slicewp-card-header { font-weight: normal; border-bottom: 0; }

		.slicewp-affiliate-landing-page { display: flex; align-items: center; gap: 10px; padding: 10px 20px; border-top: 1px solid rgba( 200, 215, 225, 0.5 ); }
		.slicewp-affiliate-landing-page > :first-child { flex: 1; }
		.slicewp-affiliate-landing-page input[type="text"] { color: inherit; font-size: inherit; padding: 0; margin: 0; border: 0; background: transparent; outline: 0; box-shadow: none; }

	</style>

	<?php

}
add_action( 'slicewp_get_template_part', 'slicewp_affiliate_account_tab_affiliate_landing_pages_styling', 10, 4 );


/**
 * Outputs the content, as a card, for the affiliate landing pages, in the affiliate account "affiliate_links" tab.
 * 
 */
function slicewp_affiliate_account_tab_affiliate_landing_pages_content() {

	$landing_pages = slicewp_get_affiliate_landing_pages( slicewp_get_current_affiliate_id() );

	if ( empty( $landing_pages ) ) {
		return;
	}

	?>

	<div class="slicewp-card-affiliate-landing-pages slicewp-card">

		<div class="slicewp-card-header">

			<span class="slicewp-card-title"><?php echo __( 'Your Landing Pages', 'slicewp' ); ?></span>

			<div class="slicewp-description">
				<p><?php echo __( 'The following landing pages have been linked to your account. You will receive commissions for purchases made by users after they reach any of your landing pages.', 'slicewp' ); ?></p>
			</div>

		</div>

		<div class="slicewp-affiliate-landing-pages">

			<?php foreach ( $landing_pages as $page_id ): ?>

				<div class="slicewp-affiliate-landing-page">

					<div>
						<input type="text" value="<?php echo esc_url( get_permalink( absint( $page_id ) ) ); ?>" readonly />
					</div>

					<button class="slicewp-copy-link">
						<?php echo slicewp_get_svg( 'outline-duplicate' ); ?>
						<span class="slicewp-input-copy-label"><?php echo __( 'Copy', 'slicewp' ); ?></span>
						<span class="slicewp-input-copy-label-copied"><?php echo __( 'Copied!', 'slicewp' ); ?></span>
					</button>

				</div>

			<?php endforeach; ?>

		</div>

	</div>

	<?php

}
add_action( 'slicewp_affiliate_account_tab_affiliate_links_bottom', 'slicewp_affiliate_account_tab_affiliate_landing_pages_content', 15 );