<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Gets the data for the affiliate leaderboard
 *
 * @param array $leaderboard_args
 * 
 * @return array
 * 
 */
function slicewp_alb_get_affiliate_leaderboard_data( $leaderboard_args = array() ) {

	// Prepare the default args
	$defaults = array(
		'id'		=> '',
		'number'	=> 10,
		'columns'	=> array( 'commissions_amount' ),
		'orderby'	=> '',
		'date'		=> 'all_time'
	);

	$leaderboard_args = wp_parse_args( $leaderboard_args, $defaults );

	$leaderboard_data_raw = array();

	// Get the 'commissions_amount' data set
	if ( in_array( 'commissions_amount', $leaderboard_args['columns'] ) ) {

		$commission_args = array(
			'number'	=> -1,
			'status'	=> array( 'paid', 'unpaid' ),
			'fields'	=> array( 'affiliate_id', 'amount' ),
			'date_min'	=> ( ! empty( $leaderboard_args['date_min'] ) ? get_gmt_from_date( $leaderboard_args['date_min'] ) : '' ),
			'date_max'	=> ( ! empty( $leaderboard_args['date_max'] ) ? get_gmt_from_date( $leaderboard_args['date_max'] ) : '' )
		);

		$commissions = slicewp_get_commissions( $commission_args );
		
		$commissions_amount = array();

		// Save the commission sums in an array
		foreach ( $commissions as $commission ) {

			$commissions_amount[$commission->affiliate_id] = empty( $commissions_amount[$commission->affiliate_id] ) ? $commission->amount : $commissions_amount[$commission->affiliate_id] + $commission->amount;

		}

		// add the commissions sum in the leaderboard data
		$leaderboard_data_raw['commissions_amount'] = $commissions_amount;

	}


	// Get the 'commissions number' data set
	if ( in_array( 'commissions_number', $leaderboard_args['columns'] ) ) {

		$commission_args = array(
			'number'	=> -1,
			'status'	=> array( 'paid', 'unpaid' ),
			'fields'	=> array( 'affiliate_id' ),
			'date_min'	=> ( ! empty( $leaderboard_args['date_min'] ) ? get_gmt_from_date( $leaderboard_args['date_min'] ) : '' ),
			'date_max'	=> ( ! empty( $leaderboard_args['date_max'] ) ? get_gmt_from_date( $leaderboard_args['date_max'] ) : '' )
		);

		$commissions = slicewp_get_commissions( $commission_args );

		// Save the coomissions number in the leaderboard data
		$leaderboard_data_raw['commissions_number'] = array_count_values( $commissions );

	}


	// Get the 'sales' data set
	if ( in_array( 'sales', $leaderboard_args['columns'] ) ) {

		$commission_args = array(
			'number'	=> -1,
			'status'	=> array( 'paid', 'unpaid' ),
			'fields'	=> array( 'affiliate_id', 'reference_amount' ),
			'date_min'	=> ( ! empty( $leaderboard_args['date_min'] ) ? get_gmt_from_date( $leaderboard_args['date_min'] ) : '' ),
			'date_max'	=> ( ! empty( $leaderboard_args['date_max'] ) ? get_gmt_from_date( $leaderboard_args['date_max'] ) : '' )
		);

		$commissions = slicewp_get_commissions( $commission_args );

		$sales = array();

		// Save the sales in an array
		foreach ( $commissions as $commission ) {

			$sales[$commission->affiliate_id] = empty( $sales[$commission->affiliate_id] ) ? $commission->reference_amount : $sales[$commission->affiliate_id] + $commission->reference_amount;

		}

		// Save the sales in the leaderboard data
		$leaderboard_data_raw['sales'] = $sales;

	}


	// Get the 'visits' data set
	if ( in_array( 'visits', $leaderboard_args['columns'] ) ) {

		$visit_args = array(
			'number'	=> -1,
			'fields'	=> array( 'affiliate_id' ),
			'date_min'	=> ( ! empty( $leaderboard_args['date_min'] ) ? get_gmt_from_date( $leaderboard_args['date_min'] ) : '' ),
			'date_max'	=> ( ! empty( $leaderboard_args['date_max'] ) ? get_gmt_from_date( $leaderboard_args['date_max'] ) : '' )
		);

		$visits = slicewp_get_visits( $visit_args );

		// Save the visits number in the leaderboard data
		$leaderboard_data_raw['visits'] = array_count_values( $visits );

	}


	/**
	 * Filter the leaderboard raw data
	 *
	 * @param array $leaderboard_data_raw
	 * @param array $leaderboard_args
	 * 
	 */
	$leaderboard_data_raw = apply_filters( 'slicewp_affiliate_leaderboard_data_raw', $leaderboard_data_raw, $leaderboard_args );

	// Process the leaderboard data
	$leaderboard_data = slicewp_alb_process_leaderboard_raw_data( $leaderboard_data_raw, $leaderboard_args );


	/**
	 * Filter the leaderboard data
	 *
	 * @param array $leaderboard_data
	 * @param array $leaderboard_args
	 *
	 */
	$leaderboard_data = apply_filters( 'slicewp_affiliate_leaderboard_data', $leaderboard_data, $leaderboard_args );

	return $leaderboard_data;

}


/**
 * Processes the raw data for the leaderboard
 *
 * @param array $leaderboard_data_raw
 * @param array $leaderboard_args
 * 
 * @return array
 * 
 */
function slicewp_alb_process_leaderboard_raw_data( $leaderboard_data_raw, $leaderboard_args ) {

	// Check for leaderboard data raw
	if ( empty( $leaderboard_data_raw ) ) {
		return;
	}

	// Check the leaderboard args
	if ( empty( $leaderboard_args['orderby'] ) || empty( $leaderboard_args['columns'] ) ) {
		return;
	}

	// Get the registered leaderboard data sets
	$leaderboard_data_sets = slicewp_alb_get_registered_leaderboard_data_sets();

	// Sort the data set used in the 'orderby' attribute
	if ( 'string' != $leaderboard_data_sets[$leaderboard_args['orderby']]['type'] ) {
		arsort( $leaderboard_data_raw[$leaderboard_args['orderby']] );
	} else {
		asort( $leaderboard_data_raw[$leaderboard_args['orderby']] );
	}

	// Get the top affiliates
	$top_affiliates = array_slice( array_keys( $leaderboard_data_raw[$leaderboard_args['orderby']] ), 0, $leaderboard_args['number'] );

	// Get the currency to format the data sets containing amounts
	$currency = slicewp_get_setting( 'active_currency', 'USD' );

	$leaderboard_data = array();

	// Parse all the affiliates
	foreach ( $top_affiliates as $key => $affiliate_id ) {

		// Get the affiliate name
		$leaderboard_data[$key]['affiliate_id']		= $affiliate_id;
		$leaderboard_data[$key]['affiliate_name']	= slicewp_get_affiliate_name( $affiliate_id );

		// Parse all the data sets
		foreach ( $leaderboard_args['columns'] as $data_set_slug ) {

			// Check if we have any data for this affiliate
			if ( ! empty( $leaderboard_data_raw[$data_set_slug][$affiliate_id] ) ) {

				// Save the data in the leaderboard data
				$leaderboard_data[$key][$data_set_slug] = ( 'amount' == $leaderboard_data_sets[$data_set_slug]['type'] ? slicewp_format_amount( $leaderboard_data_raw[$data_set_slug][$affiliate_id], $currency ) : $leaderboard_data_raw[$data_set_slug][$affiliate_id] );

			} else {

				// No data available
				switch ( $leaderboard_data_sets[$data_set_slug]['type'] ) {
					case 'int':
						$leaderboard_data[$key][$data_set_slug] = 0;
						break;
					case 'amount':
						$leaderboard_data[$key][$data_set_slug] = slicewp_format_amount( 0, $currency );
						break;
					case 'string':
					default:
						$leaderboard_data[$key][$data_set_slug] = __( 'No data.', 'slicewp' );
						break;
				}

			}

		}

	}

	return $leaderboard_data;

}


/**
 * Returns all the registered affiliate leaderboard data sets
 *
 * @return array
 *
 */
function slicewp_alb_get_registered_leaderboard_data_sets() {

	// Register the affiliate leaderboard data sets
	$leaderboard_data_sets = array(
		'affiliate_name' => array( 
			'name'	=> __( 'Affiliate Name' , 'slicewp' ),
			'type'	=> 'string'
		),
		'commissions_amount' => array(
			'name'	=> __( 'Commissions Amount', 'slicewp' ),
			'type'	=> 'amount'
		),
		'commissions_number' => array(
			'name'	=> __( 'Commissions Number', 'slicewp' ),
			'type'	=> 'int'
		),
		'visits' => array(
			'name'	=> __( 'Visits', 'slicewp' ),
			'type'	=> 'int'
		),
		'sales' => array(
			'name'	=> __( 'Sales', 'slicewp' ),
			'type'	=> 'amount'
		)
	);


	/**
	 * Filter the data sets of the affiliate leaderboard
	 *
	 * @param array $leaderboard_data_sets
	 *
	 */
	$leaderboard_data_sets = apply_filters( 'slicewp_affiliate_leaderboard_data_sets', $leaderboard_data_sets );

	return $leaderboard_data_sets;

}


/**
 * Returns all the registered affiliate leaderboard date intervals
 *
 * @return array
 *
 */
function slicewp_alb_get_registered_leaderboard_date_intervals() {

	// Register the affiliate leaderboard date intervals
	$leaderboard_date_intervals = array(
		'all_time' => array(
			'date_min' => '',
			'date_max' => ''
		),
		'this_week' => array(
			'date_min' => ( new DateTime( 'Monday this week' ) )->format( 'Y-m-d 00:00:00' ),
			'date_max' => ( new DateTime( 'now', wp_timezone() ) )->format( 'Y-m-d H:i:s' )
		),
		'last_week' => array(
			'date_min' => ( new DateTime( 'Monday last week' ) )->format( 'Y-m-d 00:00:00' ),
			'date_max' => ( new DateTime( 'Sunday last week' ) )->format( 'Y-m-d 23:59:59' )
		),
		'this_month' => array(
			'date_min' => ( new DateTime() )->format( 'Y-m-01 00:00:00' ),
			'date_max' => ( new DateTime( 'now', wp_timezone() ) )->format( 'Y-m-d H:i:s' )
		),
		'last_month' => array(
			'date_min' => ( ( new DateTime() ) )->sub( new DateInterval( 'P1M' ) )->format( 'Y-m-01 00:00:00' ),
			'date_max' => ( ( new DateTime() ) )->sub( new DateInterval( 'P1M' ) )->format( 'Y-m-t 23:59:59' )
		),
		'this_year' => array(
			'date_min' => ( new DateTime() )->format( 'Y-01-01 00:00:00' ),
			'date_max' => ( new DateTime( 'now', wp_timezone() ) )->format( 'Y-m-d H:i:s' )
		),
		'last_year' => array(
			'date_min' => ( ( new DateTime() ) )->sub( new DateInterval( 'P1Y' ) )->format( 'Y-01-01 00:00:00' ),
			'date_max' => ( ( new DateTime() ) )->sub( new DateInterval( 'P1Y' ) )->format( 'Y-12-t 23:59:59' ),
		),
		'range' => array(
			'date_min' => '',
			'date_max' => ''
		)
	);


	/**
	 * Filter the affiliate leaderboard date intervals
	 *
	 * @param array $leaderboard_date_intervals
	 *
	 */
	$leaderboard_date_intervals = apply_filters( 'slicewp_affiliate_leaderboard_date_intervals', $leaderboard_date_intervals );

	return $leaderboard_date_intervals;

}