<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Affiliate Leaderboard" add-on class.
 * 
 */
class SliceWP_Add_On_Affiliate_Leaderboard extends SliceWP_Add_On {

	/**
	 * Construct.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'affiliate_leaderboard';

		// Name.
		$this->name = 'Affiliate Leaderboard';

		// Description.
		$this->description = 'Show an affiliate leaderboard on your website to encourage your affiliates to make you more sales.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-affiliate-leaderboard.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/affiliate-leaderboard/';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		if ( $this->is_active() ) {

			add_filter( 'slicewp_template_paths', array( $this, 'register_template_paths' ) );

		}

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'users/shortcodes/functions-shortcodes.php',
		);

		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Register the affiliate leaderboard templates directory.
	 *
	 * @param array $template_paths
	 *
	 * @return array
	 *
	 */
	public function register_template_paths( $template_paths ) {

		$template_paths[] = untrailingslashit( $this->get_dir_path() ) . '/templates/';

		return $template_paths;

	}

}


/**
 * Registers the Affiliate Leaderboard add-on.
 * 
 * @param array
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_affiliate_leaderboard( $add_ons ) {

	$add_ons['affiliate_leaderboard'] = 'SliceWP_Add_On_Affiliate_Leaderboard';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_affiliate_leaderboard', 180 );