<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Affiliate Social Share" add-on class.
 * 
 */
class SliceWP_Add_On_Affiliate_Social_Share extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'affiliate_social_share';

		// Name.
		$this->name = 'Affiliate Social Share';

		// Description.
		$this->description = 'Make it easier for your affiliates to share your products to their social media profiles by adding share button in their affiliate account.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-affiliate-social-share.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/affiliate-social-share/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-settings-affiliate-social-share';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		if ( $this->is_active() ) {

			// Frontend scripts.
			add_action( 'slicewp_enqueue_front_end_scripts', array( $this, 'register_front_end_scripts' ) );
			add_action( 'slicewp_affiliate_account_tab_affiliate_links_top', array( $this, 'enqueue_front_end_scripts' ) );

		}

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'admin/functions.php',
			'users/functions.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Registers and enqueues the scripts and style for the user area.
	 *
	 */
	public function register_front_end_scripts( $hook ) {

		// Plugin script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script-front-end', $this->get_dir_url() . 'assets/js/script-front-end.js', array( 'jquery', 'slicewp-script' ), $this->get_parent_plugin_version() );

	}


	/**
	 * Enqueues the scripts and style for the user area.
	 * 
	 */
	public function enqueue_front_end_scripts() {

		// Print the CSS from the front-end file in the page.
		ob_start();

		if ( file_exists( $this->get_dir_path() . 'assets/css/style-front-end.css' ) ) {
			include $this->get_dir_path() . 'assets/css/style-front-end.css';
		}

		$css = ob_get_contents();
		ob_end_clean();

		printf(
			"<style id='slicewp-" . esc_attr( str_replace( '_', '-', $this->slug ) ) . "-style-front-end-inline-css' type='text/css'>\n%s\n</style>\n",
			$css
		);

		// Enqueue the front-end script.
		wp_enqueue_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script-front-end' );

	}

}


/**
 * Registers the Affiliate Social Share add-on.
 * 
 * @param array
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_affiliate_social_share( $add_ons ) {

	$add_ons['affiliate_social_share'] = 'SliceWP_Add_On_Affiliate_Social_Share';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_affiliate_social_share', 190 );