<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Handles the settings fields and meta-data saving on SliceWP's admin side.
 *
 */
class SliceWP_Admin_Custom_Affiliate_Slug {

	/**
	 * Initializez the admin.
	 *
	 */
	public static function init() {

		// Adds the custom affiliate slug general settings fields.
		add_action( 'slicewp_view_settings_tab_general_bottom', array( __CLASS__, 'include_general_settings_view' ) );

		// Adds the custom affiliate slug fields to the add/edit affiliate pages.
		add_action( 'slicewp_view_affiliates_add_affiliate_bottom', array( __CLASS__, 'include_affiliate_view' ), 9 );
		add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', array( __CLASS__, 'include_affiliate_view' ), 9 );

		// Validate the affiliate specific custom affiliate slug settings.
		add_action( 'slicewp_admin_action_add_affiliate', array( __CLASS__, 'validate_metadata' ), 25 );
		add_action( 'slicewp_admin_action_update_affiliate', array( __CLASS__, 'validate_metadata' ), 25 );

		// Saves the affiliate specific custom affiliate slug settings.
		add_action( 'slicewp_insert_affiliate', array( __CLASS__, 'save_affiliate_meta' ) );
		add_action( 'slicewp_update_affiliate', array( __CLASS__, 'save_affiliate_meta' ) );

	}


	/**
	 * Adds the custom affiliate slug general settings fields
	 *
	 */
	public static function include_general_settings_view() {

		include 'views/view-custom-affiliate-slug-general-settings.php';

	}


	/**
	 * Adds the custom affiliate slug fields to the add/edit affiliate pages
	 *
	 */
	public static function include_affiliate_view() {

		include 'views/view-custom-affiliate-slug-affiliate.php';

	}


	/**
	 * Saves the affiliate specific custom affiliate slug settings
	 *
	 * @param int $affiliate_id
	 *
	 */
	public static function save_affiliate_meta( $affiliate_id ) {

		if ( ! slicewp_doing_admin_action( 'add_affiliate' ) && ! slicewp_doing_admin_action( 'update_affiliate' ) ) {
			return;
		}

		// Enable affiliate custom slug creation.
		if ( ! empty( $_POST['custom_slug_creation'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'custom_slug_creation', sanitize_text_field( $_POST['custom_slug_creation'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'custom_slug_creation' );
		}

		// Affiliate custom slug.
		if ( ! empty( $_POST['custom_slug'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'custom_slug', sanitize_text_field( $_POST['custom_slug'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'custom_slug' );
		}

	}


	/**
	 * Validates the affiliate custom affiliate slug metadata.
	 *
	 */
	public static function validate_metadata() {

		if ( empty( $_POST['custom_slug'] ) ) {
			return;
		}

		$custom_slug = sanitize_text_field( $_POST['custom_slug'] );

		// Make sure the custom slug isn't numeric.
		if ( is_numeric( $custom_slug ) ) {

			slicewp_form_errors()->add( 'custom_slug', __( 'Error! The custom slug cannot have a numeric value.', 'slicewp' ) );

		}

		// Make sure the custom slug contains only alphanumeric values.
		if ( ! ( ctype_alpha( $custom_slug ) || ctype_alnum( $custom_slug ) ) ) {

			slicewp_form_errors()->add( 'custom_slug', __( 'Error! The custom slug contains invalid characters. Please make sure the slug contains only alphanumeric characters and no spaces.', 'slicewp' ) );

		}

		// Make sure the custom slug is unique.
		$affiliate_id = ( ! empty( $_POST['affiliate_id'] ) ? absint( $_POST['affiliate_id'] ) : 0 );
		$_affiliate   = slicewp_get_affiliate_by_custom_slug( $custom_slug );

		if ( ( ! is_null( $_affiliate ) && empty( $affiliate_id ) ) || ( ! is_null( $_affiliate ) && $_affiliate->get( 'id' ) != $affiliate_id ) ) {

			slicewp_form_errors()->add( 'custom_slug', __( 'Error! The custom slug is already set for another affiliate.', 'slicewp' ) );

		}

	}
	
}

SliceWP_Admin_Custom_Affiliate_Slug::init();