<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Custom Affiliate Slug" add-on class.
 * 
 */
class SliceWP_Add_On_Custom_Affiliate_Slug extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'custom_affiliate_slug';

		// Name.
		$this->name = 'Custom Affiliate Slug';

		// Description.
		$this->description = 'Set custom slugs or generate random ones for your affiliates, which help customize the affiliate referral links.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-custom-affiliate-slug.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/custom-affiliate-slug/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-settings-custom-affiliate-slug';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		if ( $this->is_active() ) {

			// Frontend scripts.
			add_action( 'slicewp_enqueue_front_end_scripts', array( $this, 'register_front_end_scripts' ) );
			add_action( 'slicewp_affiliate_account_tab_settings_top', array( $this, 'enqueue_front_end_scripts' ) );

		}

	}	


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'admin/class-admin-custom-affiliate-slug.php',
			'users/functions.php',
			'users/class-users-custom-affiliate-slug.php',
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Registers and enqueues the scripts and style for the user area.
	 *
	 */
	public function register_front_end_scripts( $hook ) {

		// Plugin script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script', $this->get_dir_url() . 'assets/js/script-front-end.js', array(), $this->get_parent_plugin_version() );

	}


	/**
	 * Enqueues the scripts for the user area.
	 * 
	 */
	public function enqueue_front_end_scripts() {

		// Enqueue the front-end script.
		wp_enqueue_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script' );

	}

}


/**
 * Registers the Custom Affiliate Slug add-on.
 * 
 * @param array
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_custom_affiliate_slug( $add_ons ) {

	$add_ons['custom_affiliate_slug'] = 'SliceWP_Add_On_Custom_Affiliate_Slug';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_custom_affiliate_slug', 80 );