jQuery( function($) {

	/**
	 * Handles the hiding and showing of different elements based on what export type
	 * the user selects
	 *
	 */
	$(document).on( 'change', '#slicewp-export-type', function() {

		var statuses = slicewp_export_data_filters.statuses;

		var $option = $(this).find('option:selected');
		var filters = ( typeof $option.attr('data-filters') != 'undefined' ? JSON.parse( $option.attr('data-filters') ) : null );

		/**
		 * Shows/hides the export filters wrapper
		 * Enabled/disabled the export button
		 *
		 */
		if ( $(this).val() != '' ) {

			if ( filters ) {

				// Show export filters wrapper
				$('#slicewp-export-filters-wrapper').show();

				// Show each filter based on the selected export type
				$('#slicewp-export-filters-wrapper .slicewp-field-wrapper').removeClass('slicewp-last').hide();

				filters.forEach( function(element) {
					$('#slicewp-export-filter-' + element).show();
				});

				$('#slicewp-export-filters-wrapper .slicewp-field-wrapper:visible').last().addClass('slicewp-last');

				// Set the statuses in the status select drop-down
				if ( typeof statuses[$(this).val()] != 'undefined' ) {

					$('#slicewp-export-filter-field-status').find('option').not(':first').remove();

					for ( key in statuses[$(this).val()] ) {
						$('#slicewp-export-filter-field-status').append( '<option value="' + key + '">' + statuses[$(this).val()][key] + '</option>' );
					}

				}

				// Remove the slicewp-last class, as the field isn't the last one anymore
				$(this).closest( '.slicewp-field-wrapper' ).removeClass('slicewp-last');

			}

			// Enable the export button
			$(this).closest('.slicewp-card').find( '.slicewp-card-footer .slicewp-button-primary' ).removeClass('slicewp-disabled');

		} else {

			// Hide export filters wrapper
			$('#slicewp-export-filters-wrapper').hide();

			// Add the slicewp-last class, as the field is the last one in the card
			$(this).closest( '.slicewp-field-wrapper' ).addClass('slicewp-last');

			// Disable the export button
			$(this).closest('.slicewp-card').find( '.slicewp-card-footer .slicewp-button-primary' ).addClass('slicewp-disabled');

		}

		// Reset the progressbar
		$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper').removeClass( 'slicewp-export-complete' ).hide();
		$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper .slicewp-progressbar-fill').css( 'width', '0' );

	});

	
	/**
	 * Handle the start of the export process.
	 *
	 */
	$(document).on( 'click', '#slicewp-card-export .slicewp-card-footer .slicewp-button-primary', function(e) {

		e.preventDefault();

		if ( $(this).hasClass('slicewp-disabled') ) {
			return false;
		}

		// Disable button
		$(this).addClass('slicewp-disabled');

		// Get form data for export.
		var form_data = {};

		$.each( $(this).closest('.slicewp-card').find( 'input, select, textarea' ).serializeArray(), function(e) {
			form_data[this.name] = this.value;
		});

		// Disable all fields
		$(this).closest('.slicewp-card').find( 'input, select, textarea' ).attr( 'disabled', true );

		// Reset the progressbar
		$(this).closest('.slicewp-card-footer').find('.slicewp-progressbar-wrapper').removeClass( 'slicewp-export-complete slicewp-export-data-empty slicewp-export-error' ).fadeIn( 200 );
		$(this).closest('.slicewp-card-footer').find('.slicewp-progressbar-wrapper .slicewp-progressbar-fill').css( 'width', '0' );

		// Process the first step in the batch process
		process_batch_step( { step : 1 }, form_data );

	});


	/**
	 *
	 *
	 */
	function process_batch_step( args, form_data ) {

		var data = {
			action 		  	: 'slicewp_action_ajax_process_batch_export',
			export_type	  	: form_data.export_type,
			step  		  	: ( args.step ? args.step : 1 ),
			items_processed : ( args.items_processed ? args.items_processed : 0 ),
			items_total		: ( args.items_total ? args.items_total : 0 ),
			file_name		: ( args.file_name ? args.file_name : '' ),
			form_data 	    : form_data,
			slicewp_token 	: $('[name="slicewp_token"]').val()
		};

		// Make AJAX call.
		$.post( ajaxurl, data, function( response ) {

			// Process next step.
			if ( ! response.data.complete && ! response.data.error ) {

				args = {
					export_type	  	: form_data.export_type,
					step  		  	: ( response.data.step ? response.data.step : 1 ),
					items_processed : ( response.data.items_processed ? response.data.items_processed : 0 ),
					items_total		: ( response.data.items_total ? response.data.items_total : 0 ),
					file_name		: ( response.data.file_name ? response.data.file_name : '' )
				};

				process_batch_step( args, form_data );

				// Animate progress bar
				$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-fill').css( 'width', response.data.percentage + '%' );

			}

			// Export is complete.
			if ( response.data.complete ) {

				if ( response.data.items_total == 0 ) {
					
					$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper').addClass( 'slicewp-export-data-empty' );

				} else {

					// Animate the progress bar.
					$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper').addClass( 'slicewp-export-complete' );

					// Add extra success message.
					$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper .slicewp-progressbar-details.slicewp-complete').find('span').last().html( response.data.message );

					// Download the file.
					if ( response.data.download_url ) {
						window.location = response.data.download_url;
					}

				}

				// Enable the export button and fields
				setTimeout( function() {
					$('#slicewp-card-export').find( 'input, select, textarea' ).attr( 'disabled', false );
					$('#slicewp-card-export').find( '.slicewp-button-primary' ).removeClass( 'slicewp-disabled' );
				}, 1000 );

			}

			// Something went wrong.
			if ( response.data.error ) {

				$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper').addClass( 'slicewp-export-error' );
				$('#slicewp-card-export .slicewp-card-footer .slicewp-progressbar-wrapper .slicewp-progressbar-details.slicewp-error').find('span').last().html( response.data.error );

				// Enable the export button and fields
				setTimeout( function() {
					$('#slicewp-card-export').find( 'input, select, textarea' ).attr( 'disabled', false );
					$('#slicewp-card-export').find( '.slicewp-button-primary' ).removeClass( 'slicewp-disabled' );
				}, 1000 );

			}


		}).fail( function( response ) {

			if ( window.console && window.console.log ) {

				console.log( response );

			}

		});

	}

});