<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * AJAX callback that processes an export batch step.
 *
 */
function slicewp_action_ajax_process_batch_export() {

	// Bail if nonce is missing
	if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {

		wp_send_json_error( array( 'error' => __( 'You do not have permission to export data.', 'slicewp' ) ) );

	}


	// Prepare args to load the processor
	$processor_name = 'export_' . sanitize_text_field( $_POST['export_type'] );

	$args = array(
		'step' 			  => ( ! empty( $_POST['step'] ) ? absint( $_POST['step'] ) : 1 ),
		'file_name' 	  => ( ! empty( $_POST['file_name'] ) ? sanitize_text_field( $_POST['file_name'] ) : '' ),
		'items_processed' => ( ! empty( $_POST['items_processed'] ) ? absint( $_POST['items_processed'] ) : 0 ),
		'items_total' 	  => ( ! empty( $_POST['items_total'] ) ? absint( $_POST['items_total'] ) : 0 )
	);
	
	// Load processor
	$processor = slicewp()->services['batch_processor_manager']->load_processor( $processor_name, $args );

	
	// Bail if the processor doesn't exist.
	if ( is_null( $processor ) ) {

		wp_send_json_error( array( 'error' => __( 'Could not load batch processor.', 'slicewp' ) ) );

	}

	// Bail if the user doesn't have export permission.
	if ( ! $processor->can_export() ) {

		wp_send_json_error( array( 'error' => __( 'You do not have permission to export data.', 'slicewp' ) ) );

	}


	// Set processor filters
	$processor->set( 'filters', _slicewp_array_sanitize_text_field( $_POST['form_data'] ) );
	$processor->init();

	$items_total   = $processor->get( 'items_total' );
	$response_data = array();

	// If no items matching the filters were found, bail.
	if ( 0 == $items_total ) {

		$response_data['complete'] 	  = true;
		$response_data['items_total'] = $items_total;

	// If we have items to export, process step.
	} else {

		// Process step
		$percentage = $processor->process_step();

		// Process complete
		if ( 100 == $percentage ) {

			$response_data['complete'] 	   = true;
			$response_data['items_total']  = $items_total;
			$response_data['message']	   = $processor->get_message( 'complete' );
			$response_data['download_url'] = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'tools', 'slicewp_action' => 'batch_export_file', 'slicewp_token' => wp_create_nonce( 'slicewp_batch_export_file' ), 'export_type' => sanitize_text_field( $_POST['export_type'] ), 'file_name' => $processor->get( 'file_name' ) ), admin_url( 'admin.php' ) );

		} else {

			$response_data['complete']		  = false;
			$response_data['step'] 			  = absint( $processor->get( 'step' ) + 1 );
			$response_data['percentage']	  = $percentage;
			$response_data['file_name'] 	  = $processor->get( 'file_name' );
			$response_data['items_processed'] = $processor->get( 'items_processed' );
			$response_data['items_total'] 	  = $items_total;

		}

	}

	wp_send_json_success( $response_data );

}
add_action( 'wp_ajax_slicewp_action_ajax_process_batch_export', 'slicewp_action_ajax_process_batch_export' );