<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Import Export" add-on class.
 * 
 */
class SliceWP_Add_On_Import_Export extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'import_export';

		// Name.
		$this->name = 'Data Export';

		// Description.
		$this->description = 'Export affiliates, commissions, affiliate payments and visits to a CSV file. Filter the exported data by affiliate, date and status.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-import-export.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/import-export/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'tools' ), admin_url( 'admin.php' ) ) . '#slicewp-card-export';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/abstracts/abstract-class-export.php',
			'base/abstracts/abstract-class-batch-export.php',
			'base/functions.php',
			'admin/functions.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}

}


/**
 * Registers the "Import Export" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_import_export( $add_ons ) {

	$add_ons['import_export'] = 'SliceWP_Add_On_Import_Export';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_import_export', 210 );