<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Register the class that handles database queries for the leads
 *
 * @param array $classes
 *
 * @return array
 *
 */
function slicewp_register_database_classes_leads( $classes ) {

	$classes['leads'] = 'SliceWP_Object_DB_Leads';

	return $classes;

}
add_filter( 'slicewp_register_database_classes', 'slicewp_register_database_classes_leads' );


/**
 * Returns an array with SliceWP_Lead objects from the database
 *
 * @param array $args
 * @param bool  $count
 *
 * @return array
 *
 */
function slicewp_get_leads( $args = array(), $count = false ) {

	$leads = slicewp()->db['leads']->get_leads( $args, $count );

	/**
	 * Add a filter hook just before returning
	 *
	 * @param array $leads
	 * @param array $args
	 * @param bool  $count
	 *
	 */
	return apply_filters( 'slicewp_get_leads', $leads, $args, $count );

}


/**
 * Gets a lead from the database
 *
 * @param mixed int|object      - lead id or object representing the lead
 *
 * @return SliceWP_Lead|null
 *
 */
function slicewp_get_lead( $lead ) {

	return slicewp()->db['leads']->get_object( $lead );

}


/**
 * Inserts a new lead into the database
 *
 * @param array $data
 *
 * @return mixed int|false
 *
 */
function slicewp_insert_lead( $data ) {

	return slicewp()->db['leads']->insert( $data );

}


/**
 * Updates a lead from the database
 *
 * @param int 	$lead_id
 * @param array $data
 *
 * @return bool
 *
 */
function slicewp_update_lead( $lead_id, $data ) {

	return slicewp()->db['leads']->update( $lead_id, $data );

}


/**
 * Deletes a lead from the database
 *
 * @param int $lead_id
 *
 * @return bool
 *
 */
function slicewp_delete_lead( $lead_id ) {

	return slicewp()->db['leads']->delete( $lead_id );

}


/**
 * Removes the "commission_id" from the lead when the commission is deleted from the database
 *
 * @param int $commission_id
 *
 */
function slicewp_remove_commission_from_lead( $commission_id ) {

	// Get the lead associated to the commission
	$leads = slicewp_get_leads( array( 'commission_id' => absint( $commission_id ) ) );

	if ( empty( $leads ) ) {
		return;
	}

	$lead = $leads[0];

	// Remove the commission_id from the lead
	$lead_args = array(
		'commission_id'	=> '',
		'date_modified' => slicewp_mysql_gmdate()
	);

	slicewp_update_lead( $lead->get('id'), $lead_args );

}
add_action( 'slicewp_delete_commission', 'slicewp_remove_commission_from_lead', 10, 1 );