<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Handles the settings fields and meta-data saving on SliceWP's admin side.
 *
 */
class SliceWP_Admin_Lifetime_Commissions {

	/**
	 * Initialize the admin.
	 *
	 */
	public static function init() {

		// Adds the lifetime commissions general settings fields.
		add_action( 'slicewp_view_settings_tab_general_bottom', array( __CLASS__, 'add_lifetime_commissions_general_settings' ) );

		// Adds the lifetime commissions fields to the add/edit affiliate pages.
		add_action( 'slicewp_view_affiliates_add_affiliate_bottom', array( __CLASS__, 'add_lifetime_commissions_affiliate' ) );
		add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', array( __CLASS__, 'add_lifetime_commissions_affiliate' ) );

		// Adds the lifetime commissions fields to the add/edit affiliate group pages.
		add_action( 'slicewp_view_affiliate_groups_add_affiliate_group_bottom', array( __CLASS__, 'add_lifetime_commissions_affiliate_group' ) );
		add_action( 'slicewp_view_affiliate_groups_edit_affiliate_group_bottom', array( __CLASS__, 'add_lifetime_commissions_affiliate_group' ) );

		// Saves the affiliate specific lifetime commissions settings.
		add_action( 'slicewp_insert_affiliate', array( __CLASS__, 'save_lifetime_commissions_affiliate' ) );
		add_action( 'slicewp_update_affiliate', array( __CLASS__, 'save_lifetime_commissions_affiliate' ) );

		// Saves the affiliate group specific lifetime commissions settings.
		add_action( 'slicewp_insert_collection', array( __CLASS__, 'save_lifetime_commissions_affiliate_group' ) );
		add_action( 'slicewp_update_collection', array( __CLASS__, 'save_lifetime_commissions_affiliate_group' ) );

	}

	/**
	 * Adds the lifetime commissions general settings fields.
	 *
	 */
	public static function add_lifetime_commissions_general_settings() {

		include 'views/view-lifetime-commissions-general-settings.php';

	}

	/**
	 * Adds the lifetime commissions fields to the add/edit affiliate pages.
	 *
	 */
	public static function add_lifetime_commissions_affiliate() {

		include 'views/view-lifetime-commissions-affiliate.php';

	}

	/**
	 * Adds the lifetime commissions fields to the add/edit affiliate group pages.
	 *
	 */
	public static function add_lifetime_commissions_affiliate_group() {

		include 'views/view-lifetime-commissions-affiliate-group.php';

	}

	/**
	 * Saves the affiliate specific lifetime commissions settings.
	 *
	 * @param int $affiliate_id
	 *
	 */
	public static function save_lifetime_commissions_affiliate( $affiliate_id ) {

		if ( ! slicewp_doing_admin_action( 'add_affiliate' ) && ! slicewp_doing_admin_action( 'update_affiliate' ) ) {
			return;
		}

		// Enable lifetime commissions.
		if ( ! empty( $_POST['lifetime_commissions'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'lifetime_commissions', sanitize_text_field( $_POST['lifetime_commissions'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'lifetime_commissions' );
		}

		// Commissions lifetime rates.
		if ( isset( $_POST['commission_rate_lifetime_sale'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_lifetime_sale', sanitize_text_field( $_POST['commission_rate_lifetime_sale'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commission_rate_lifetime_sale' );
		}

		if ( ! empty( $_POST['commission_rate_type_lifetime_sale'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_type_lifetime_sale', sanitize_text_field( $_POST['commission_rate_type_lifetime_sale'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commission_rate_type_lifetime_sale' );
		}

		// Lifetime mode.
		if ( ! empty( $_POST['commissions_lifetime_duration'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commissions_lifetime_duration', sanitize_text_field( $_POST['commissions_lifetime_duration'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commissions_lifetime_duration' );
		}
			
		// Lifetime duration.
		if( ! empty( $_POST['commissions_lifetime_limit'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commissions_lifetime_limit', sanitize_text_field( $_POST['commissions_lifetime_limit'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commissions_lifetime_limit' );
		}

	}


	/**
	 * Saves the affiliate group specific lifetime commissions settings.
	 *
	 * @param int $affiliate_group_id
	 *
	 */
	public static function save_lifetime_commissions_affiliate_group( $affiliate_group_id ) {

		if ( ! slicewp_doing_admin_action( 'add_affiliate_group' ) && ! slicewp_doing_admin_action( 'update_affiliate_group' ) ) {
			return;
		}

		// Enable lifetime commissions.
		if ( ! empty( $_POST['lifetime_commissions'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_lifetime_commissions', sanitize_text_field( $_POST['lifetime_commissions'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_lifetime_commissions' );
		}

		// Commissions lifetime rates.
		if ( isset( $_POST['commission_rate_lifetime_sale'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commission_rate_lifetime_sale', sanitize_text_field( $_POST['commission_rate_lifetime_sale'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commission_rate_lifetime_sale' );
		}

		if ( ! empty( $_POST['commission_rate_type_lifetime_sale'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commission_rate_type_lifetime_sale', sanitize_text_field( $_POST['commission_rate_type_lifetime_sale'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commission_rate_type_lifetime_sale' );
		}

		// Lifetime mode.
		if ( ! empty( $_POST['commissions_lifetime_duration'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commissions_lifetime_duration', sanitize_text_field( $_POST['commissions_lifetime_duration'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commissions_lifetime_duration' );
		}
			
		// Lifetime duration.
		if( ! empty( $_POST['commissions_lifetime_limit'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commissions_lifetime_limit', sanitize_text_field( $_POST['commissions_lifetime_limit'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commissions_lifetime_limit' );
		}

	}

}

SliceWP_Admin_Lifetime_Commissions::init();