<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Links the customer to affiliate.
 *
 */
function slicewp_action_ajax_link_customer() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_link_customer' ) ) {
		wp_die( 0 );
	}
	
	if ( ! current_user_can( 'manage_options' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['customer_email'] ) ) {
		wp_die( 0 );
	}
	
	// Prepare variables
	$customer_email = sanitize_email( $_POST['customer_email'] );
	$affiliate_id   = ( ! empty( $_POST['affiliate_id'] ) ? absint( $_POST['affiliate_id'] ) : 0 );

	// Check if the customer exists
	$user = get_user_by( 'email', $customer_email );

	$customer_args = array(
		'email'   	 => $customer_email,
		'user_id' 	 => ( ! empty( $user ) ? $user->get( 'id' ) : 0 ),
		'first_name' => ( ! empty( $user ) ? $user->get( 'first_name' ) : '' ),
		'last_name'  => ( ! empty( $user ) ? $user->get( 'last_name' ) : '' )
	);

	// Process the customer data
	$customer_id = slicewp_process_customer( $customer_args );

	// Check if the customer is linked to another affiliate
	$customer_meta = slicewp_get_customer_meta( $customer_id, 'affiliate_id', true );

	if ( empty( $customer_meta ) ) {

		// Update the affiliate ID for the customer
		slicewp_update_customer_meta( $customer_id, 'affiliate_id', $affiliate_id );

		// Prepare the linked customer HTML card
		$linked_customer  = '<div class="slicewp-affiliate-lifetime-linked-customer">';
		$linked_customer .= '	<div class="slicewp-affiliate-lifetime-linked-customer-details">';
		$linked_customer .= '		<div class="slicewp-affiliate-lifetime-linked-customer-name">' . ( ! empty( $customer_args['first_name'] ) || ! empty( $customer_args['last_name'] ) ? esc_html( $customer_args['first_name'] . ' ' . $customer_args['last_name'] ) : __( 'Unnamed customer', 'slicewp' ) ) . '</div>';
		$linked_customer .= '		<div class="slicewp-affiliate-lifetime-linked-customer-email">' . esc_html( $customer_args['email'] ) . '</div>';
		$linked_customer .= '	</div>';
		$linked_customer .= '	<div class="slicewp-affiliate-lifetime-linked-customer-actions">';
		$linked_customer .= 		( ! empty( $user ) ? '<a href="' . esc_url( add_query_arg( array( 'user_id' => absint( $user->get('ID') ) ), admin_url( 'user-edit.php' ) ) ) . '">' . __( 'View profile', 'slicewp' ) . '</a>' : '' );
		$linked_customer .= '		<span class="slicewp-affiliate-lifetime-unlink-customer slicewp-trash" data-customer-id="' . absint( $customer_id ) . '"><a href="#" data-message="' . __( 'Are you sure you want to unlink this customer?', 'slicewp' ) . '">' . __( 'Unlink', 'slicewp' ) . '</a></span>';
		$linked_customer .= '	</div>';
		$linked_customer .= '</div>';

		// Send success message
		wp_send_json_success( array( 'message' => __( 'Customer linked succesfully to affiliate.', 'slicewp' ), 'customer' => $linked_customer ) );

	} else {

		// Send error message
		wp_send_json_error( array( 'message' => __( 'Customer is already linked to an affiliate.', 'slicewp' ) ) );

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_link_customer', 'slicewp_action_ajax_link_customer' );


/**
 * Unlinks the customer from affiliate.
 *
 */
function slicewp_action_ajax_unlink_customer() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_link_customer' ) ) {
		wp_die( 0 );
	}

	if ( ! current_user_can( 'manage_options' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['customer_id'] ) ) {
		wp_die( 0 );
	}

	$customer_id  = absint( $_POST['customer_id'] );
	$affiliate_id = ( ! empty( $_POST['affiliate_id'] ) ? absint( $_POST['affiliate_id'] ) : 0 );

	// Delete the meta containing the affiliate id.
	$deleted = slicewp_delete_customer_meta( $customer_id, 'affiliate_id', $affiliate_id );

	// Check if everything went ok and send the status.
	if ( ! $deleted ) {

		wp_send_json_error();

	} else {

		wp_send_json_success();

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_unlink_customer', 'slicewp_action_ajax_unlink_customer' );