<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Lifetime Commissions" add-on class.
 * 
 */
class SliceWP_Add_On_Lifetime_Commissions extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'lifetime_commissions';

		// Name.
		$this->name = 'Lifetime Commissions';

		// Description.
		$this->description = 'Enables you to reward commissions to your affiliates for all future purchases made by a customer.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-lifetime-commissions.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/lifetime-commissions/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-settings-lifetime-commissions';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		add_action( 'slicewp_activated_add_on', array( $this, 'set_general_settings' ) );

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'base/abstracts/abstract-class-integration-lifetime-commissions.php',
			'base/integrations/easy-digital-downloads/functions.php',
			'base/integrations/getpaid/functions.php',
			'base/integrations/woocommerce/functions.php',
			'base/integrations/memberpress/functions.php',
			'base/integrations/surecart/functions.php',
			'admin/class-admin-lifetime-commissions.php',
			'admin/functions-actions-ajax.php',
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Sets the default general settings on add-on activation.
	 * 
	 * @param string $add_on_slug
	 * 
	 */
	public function set_general_settings( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		$settings = slicewp_get_option( 'settings', array() );

		if ( ! is_array( $settings ) ) {
			return;
		}

		if ( ! isset( $settings['commission_rate_lifetime_sale'] ) ) {
			$settings['commission_rate_lifetime_sale'] = 10;
		}

		if ( ! isset( $settings['commission_rate_type_lifetime_sale'] ) ) {
			$settings['commission_rate_type_lifetime_sale'] = 'percentage';
		}

		if ( ! isset( $settings['commissions_lifetime_duration'] ) ) {
			$settings['commissions_lifetime_duration'] = 'unlimited';
		}

		slicewp_update_option( 'settings', $settings );

	}

}


/**
 * Registers the "Lifetime Commissions" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_lifetime_commissions( $add_ons ) {

	$add_ons['lifetime_commissions'] = 'SliceWP_Add_On_Lifetime_Commissions';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_lifetime_commissions', 110 );