jQuery( function($) {

	/**
	 * Connect to Mailchimp
	 *
	 */
	$(document).on( 'click', '#slicewp-connect-mailchimp', function(e){

		e.preventDefault();

		$button = $(this);
		
		// Exit if button is disabled
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

		// Exit if the API key field is empty
		if ( $button.siblings( 'input[type="password"]' ).val() == '' ) {
			$button.siblings( 'input[type="password"]' ).focus();
			return false;
		}

		// Disable API key field
		$button.siblings( 'input[type="password"]' ).attr( 'disabled', 'true' );

		// Disable the button
		$button.addClass( 'slicewp-disabled' );

		// Show spinner
		$button.addClass( 'slicewp-spinner-active' );

		// Add a spinner over API settings
		if ( $( '#slicewp-mailchimp-integration-fields' ).children().length > 0 ) {
			$( '#slicewp-mailchimp-integration-fields' ).prepend( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );
		}

		// Prepare AJAX call data
		var data = {
			action			: 'slicewp_mailchimp_integration_action_ajax_connect',
			slicewp_token	: $( '#slicewp_token' ).val(),
			api_key			: $( '#slicewp-mailchimp-api-key' ).val(),
		}

		// Make AJAX call
		$.post( ajaxurl, data, function( response ) {

			// Remove API notice
			$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).remove();

			// Re-enable the button
			$button.siblings( 'input[type="password"]' ).removeAttr( 'disabled' );

			// Re-enable the button
			$button.removeClass( 'slicewp-disabled' );
			
			// Hide spinner
			$button.removeClass( 'slicewp-spinner-active' );

			// Remove API fields
			$( '#slicewp-mailchimp-integration-fields' ).remove();

			if ( response.success == true ) {

				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();

				$fields = $( response.data.integration_fields );
				
				// Check if we have select fields
				if ( $fields.find( 'select' ) ) {

					$this = $fields.find( 'select' );

					$this.each( function() {

						$(this).select2({
							minimumResultsForSearch : 20,
							placeholder : $(this).attr( 'placeholder' )
						}).on('select2:open', function() {
							var container = $('.select2-container').last();
							container.addClass('slicewp-select2-container');
						})

					})

				}

				// Show the fields
				$fields.hide();
				$fields.insertAfter( '#slicewp-field-wrapper-mailchimp-api-key' );
				$fields.fadeIn();

				// Show the double opt-in setting
				$( '#slicewp-mailchimp-double-optin' ).closest( '.slicewp-field-wrapper' ).show();

			} else {

				// Show the error message
				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();
				
				// Hide the double opt-in setting
				$( '#slicewp-mailchimp-double-optin' ).closest( '.slicewp-field-wrapper' ).hide();

			}

		});

	});


	/**
	 * Show/hide the tags field.
	 *
	 */	
	$(document).on( 'change', '#slicewp-mailchimp-select-audience', function() {

		// Remove the tags field
		$( '#slicewp-mailchimp-tags' ).hide();

		if ( $(this).val() != '' ) {

			// Add a spinner over Audience selection
			$( '#slicewp-mailchimp-audience' ).prepend( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );

			// Prepare AJAX call data
			var data = {
				action			: 'slicewp_mailchimp_integration_action_ajax_get_tags',
				slicewp_token	: $( '#slicewp_token' ).val(),
				audience_id		: $(this).val()
			}

			// Make AJAX call
			$.post( ajaxurl, data, function( response ) {

				// Remove the spinner from Audience selection
				$( '#slicewp-mailchimp-audience' ).find( '.slicewp-overlay' ).remove();

				if ( response.success == true ) {
					
					$fields = $( response.data.tags_field );

					// Check if we have select fields
					if ( $fields.find( 'select' ) ) {

						$this = $fields.find( 'select' );

						$this.select2({
							dropdownPosition : 'below',
							placeholder : $this.attr( 'placeholder' )
						}).on('select2:open', function() {
							var container = $('.select2-container').last();
							container.addClass('slicewp-select2-container');
						});

					}

					// Check if the tags field exists
					if ( $( '#slicewp-mailchimp-tags' ).length ) {

						// Replace the old fields
						$( '#slicewp-mailchimp-tags' ).replaceWith( $fields );
						$( '#slicewp-mailchimp-tags' ).fadeIn();

					} else {

						// Insert new fields
						$fields.hide();
						$fields.insertAfter( '#slicewp-mailchimp-audience' );
						$fields.fadeIn();

					}

				}

			});

		}

	});


	/**
	 * 	Hide the double opt-in setting if no API key is provided.
	 *
	 */
	$(document).ready(function() {

		if ( $( '#slicewp-mailchimp-api-key' ).val() == '' ) {

			$( '#slicewp-mailchimp-double-optin' ).closest( '.slicewp-field-wrapper' ).hide();

		}

	});


	/**
	 * Change the select2 properties for tags
	 *
	 */
	$('.slicewp-select2-mailchimp-tags').each( function() {

		var $this = $(this);

		$this.select2({
			dropdownPosition : 'below',
			placeholder : $this.attr( 'placeholder' )
		}).on('select2:open', function() {
			var container = $('.select2-container').last();
			container.addClass('slicewp-select2-container');
		});

	});

});
