<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Adds the Mailchimp mailing list agreement checkbox on the affiliate registration form
 *
 * @param array $fields
 *
 */
function slicewp_register_mailing_list_agreement_field_mailchimp( $form ) {

	if ( 'affiliate_registration' != $form ) {
		return;
	}

	// Check if the mailing list agreement has to be shown on the affiliate registration form
	$enabled = slicewp_get_setting( 'mailchimp_enabled' );
	$api_key  = slicewp_get_setting( 'mailchimp_api_key' );
	$audience = slicewp_get_setting( 'mailchimp_audience' );

	if ( ! empty( $enabled ) && ! empty( $api_key ) && ! empty( $audience ) ) {

	?>

		<!-- Affiliate Mailing List Agreement -->
		<div class="slicewp-field-wrapper slicewp-field-wrapper-mailchimp-mailing-list-agreement">

			<div class="slicewp-field-label-wrapper">

				<input id="slicewp-mailchimp-mailing-list-agreement" name="mailchimp_mailing_list_agreement" type="checkbox" value="1" <?php checked( ! empty( $_POST['mailchimp_mailing_list_agreement'] ), '1' ) ?>/>
				<label for="slicewp-mailchimp-mailing-list-agreement"><?php echo ( ! empty( slicewp_get_setting( 'mailchimp_mailing_list_agreement_label' ) ) ? slicewp_get_setting( 'mailchimp_mailing_list_agreement_label' ) :  __( 'Join our mailing list.', 'slicewp' ) ); ?></label>

			</div>

		</div><!-- / Affiliate Mailing List Agreement -->

	<?php

	}

}
add_action( 'slicewp_form_fields', 'slicewp_register_mailing_list_agreement_field_mailchimp', 20 );


/**
 * Subscribe the affiliate to the mailing list.
 *
 * @param int $affiliate_id
 *
 */
function slicewp_subscribe_affiliate_mailchimp( $affiliate_id ) {

	// Check for affiliate id
	if ( empty( $affiliate_id ) ) {
		return;
	}

	if ( doing_action( 'slicewp_register_affiliate' ) ) {

		// Check if the user wants to join the email list
		if ( empty( $_POST['mailchimp_mailing_list_agreement'] ) ) {
			return;
		}

		// Save the affiliate mailing consent in affiliate meta
		slicewp_update_affiliate_meta( $affiliate_id, 'mailchimp_mailing_list_agreement', 1 );

	}

	if ( doing_action( 'slicewp_update_affiliate' ) ) {

		// Check if we are reviewing the affiliate
		if ( 'review_affiliate' != $_POST['slicewp_action'] ) {
			return;
		}

		// Check if the user wants to join the email list
		if ( empty( slicewp_get_affiliate_meta( $affiliate_id, 'mailchimp_mailing_list_agreement', true ) ) ) {
			return;
		}

	}

	// Check if the affiliate has 'active' status
	$affiliate = slicewp_get_affiliate( $affiliate_id );
	
	if ( 'active' != $affiliate->get( 'status' ) ) {
		return;
	}

	// Prepare the affiliate data for mailing list
	$user = new WP_User( $affiliate->get( 'user_id' ) );

	$subscriber_data = array(
		'email'			=> $user->user_email,
		'first_name'	=> ! empty( $user->first_name ) ? $user->first_name : '',
		'last_name'		=> ! empty( $user->last_name ) ? $user->last_name : '',
	);

	// Subscribe the affiliate to the mailing list
	$initialized = slicewp()->services['mailchimp']->init( slicewp_get_setting( 'mailchimp_api_key' ) );

	// Check for errors
	if ( ! $initialized ) {

		slicewp_add_log( 'Mailchimp API: init() failed: Invalid MailChimp API key supplied.' );
		return;

	}

	slicewp()->services['mailchimp']->add_subscriber( $subscriber_data );

}
add_action( 'slicewp_register_affiliate', 'slicewp_subscribe_affiliate_mailchimp', 30 );
add_action( 'slicewp_update_affiliate', 'slicewp_subscribe_affiliate_mailchimp', 30 );