jQuery( function($) {

	/**
	 * Connect to MailerLite
	 *
	 */
	$(document).on( 'click', '#slicewp-connect-mailerlite', function(e){

		e.preventDefault();

		$button = $(this);
		
		// Exit if button is disabled
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

		// Exit if the API key field is empty
		if ( $button.siblings( 'input[type="password"]' ).val() == '' ) {
			$button.siblings( 'input[type="password"]' ).focus();
			return false;
		}

		// Disable API key field
		$button.siblings( 'input[type="password"]' ).attr( 'disabled', 'true' );

		// Disable the button
		$button.addClass( 'slicewp-disabled' );

		// Show spinner
		$button.addClass( 'slicewp-spinner-active' );

		// Add a spinner over API settings
		if ( $( '#slicewp-mailerlite-integration-fields' ).children().length > 0 ) {
			$( '#slicewp-mailerlite-integration-fields' ).prepend( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );
		}

		// Prepare AJAX call data
		var data = {
			action			: 'slicewp_mailerlite_integration_action_ajax_connect',
			slicewp_token	: $( '#slicewp_token' ).val(),
			api_key			: $( '#slicewp-mailerlite-api-key' ).val(),
		}

		// Make AJAX call
		$.post( ajaxurl, data, function( response ) {

			// Remove API notice
			$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).remove();

			// Re-enable API key field
			$button.siblings( 'input[type="password"]' ).removeAttr( 'disabled' );

			// Re-enable the button
			$button.removeClass( 'slicewp-disabled' );

			// Hide spinner
			$button.removeClass( 'slicewp-spinner-active' );

			if ( response.success == true ) {

				// Remove API fields
				$( '#slicewp-mailerlite-integration-fields' ).remove();

				// Output the API message
				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();

				// Output the API fields
				$fields = $( response.data.integration_fields );
					
				// Check if we have select fields
				if ( $fields.find( 'select' ) ) {

					$this = $fields.find( 'select' );

					$this.select2({
						minimumResultsForSearch : 20
					}).on('select2:open', function() {
						var container = $('.select2-container').last();
						container.addClass('slicewp-select2-container');
						container.find('.select2-search__field').attr( 'placeholder', 'Type to search...' );
					});

				}

				$fields.hide();
				$fields.insertAfter( '#slicewp-field-wrapper-mailerlite-api-key' );
				$fields.fadeIn();

			} else {

				// Output the API message
				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();

				// Remove spinner from API settings
				if ( $( '#slicewp-mailerlite-integration-fields' ).children( '.slicewp-overlay' ).length > 0 ) {
					$( '#slicewp-mailerlite-integration-fields' ).children( '.slicewp-overlay' ).remove();
				}

			}

		});

	});

});