<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Attempts to connect ExchangeRates-API.
 *
 */
function slicewp_action_ajax_connect_exchangerate_api() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['api_key'] ) ) {
		wp_die( 0 );
	}

    // Sanitize API key.
	$api_key = sanitize_text_field( $_POST['api_key'] );

    // Make an API call to check the app ID.
    $response = wp_remote_get( 'https://v6.exchangerate-api.com/v6/' . $api_key . '/latest/' . slicewp_get_setting( 'active_currency', 'USD' ) );

    // Remove the exchange rates updater cron job.
    wp_unschedule_hook( 'slicewp_multi_currency_update_exchange_rates' );
    
    // Return with fail message if the call returns a WP_Error.
    if ( is_wp_error( $response ) ) {
    
	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'The connection to ExchangeRates-API could not be established.', 'slicewp' ) ) ) );

    }

    $data = json_decode( wp_remote_retrieve_body( $response ), true );

    // Return with fail message if the app ID is incorrect.
    if ( isset( $data['result'] ) && $data['result'] == 'error' ) {
    
        if ( isset( $data['error-type'] ) && $data['error-type'] == 'invalid-key' ) {

            $message = __( 'Invalid ExchangeRate-API API key provided.', 'slicewp' );

        } else {

            $message = sprintf( __( 'Error: %s', 'slicewp' ), ( ! empty( $data['error-type'] ) ? $data['error-type'] : 'not-specified' ) . '. ' . ( ! empty( $data['extra-info'] ) ? $data['extra-info'] : '' ) );

        }

	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => $message ) ) );

    } else {

        // Save the app ID.
        $multi_currency_settings = slicewp_get_option( 'multi_currency', array() );

        $multi_currency_settings['currency_exchange_rates_update_method'] = 'exchangerate-api';
        $multi_currency_settings['exchangerate_api_api_key']              = $api_key;

        slicewp_update_option( 'multi_currency', $multi_currency_settings );

        // Set the cron job to update the exchange rates.
        if ( ! wp_next_scheduled( 'slicewp_multi_currency_update_exchange_rates' ) ) {
            wp_schedule_event( time() + DAY_IN_SECONDS / 2, 'daily', 'slicewp_multi_currency_update_exchange_rates' );
        }

        // Return with a success message.
	    wp_send_json( array( 'success' => true, 'data' => array( 'message' =>  __( 'Connected succesfully to the ExchangeRate-API.', 'slicewp' ) ) ) );

    }

}
add_action( 'wp_ajax_slicewp_action_ajax_connect_exchangerate_api', 'slicewp_action_ajax_connect_exchangerate_api' );


/**
 * Disconnects from ExchangeRates-API.
 *
 */
function slicewp_action_ajax_disconnect_exchangerate_api() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}

    // Remove the exchange rates updater cron job.
    wp_unschedule_hook( 'slicewp_multi_currency_update_exchange_rates' );
    
    // Remove the API key.
    $multi_currency_settings = slicewp_get_option( 'multi_currency', array() );

    if ( ! empty( $multi_currency_settings['exchangerate_api_api_key'] ) ) {
        unset( $multi_currency_settings['exchangerate_api_api_key'] );
    }

    slicewp_update_option( 'multi_currency', $multi_currency_settings );

    // Return with a success message.
    wp_send_json( array( 'success' => true, 'data' => array( 'message' =>  __( 'Disconnected succesfully from ExchangeRate-API.', 'slicewp' ) ) ) );

}
add_action( 'wp_ajax_slicewp_action_ajax_disconnect_exchangerate_api', 'slicewp_action_ajax_disconnect_exchangerate_api' );


/*
 * Attempts to connect Open Exchange Rates API.
 *
 *
function slicewp_action_ajax_connect_openexchangerates() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}

	if ( empty( $_POST['app_id'] ) ) {
		wp_die( 0 );
	}

    // Sanitize app ID.
	$app_id = sanitize_text_field( $_POST['app_id'] );

    // Make an API call to check the app ID.
    $response = wp_remote_get( add_query_arg( array( 'app_id' => $app_id, 'base' => slicewp_get_setting( 'active_currency', 'USD' ) ), 'https://openexchangerates.org/api/latest.json' ) );

    // Remove the exchange rates updater cron job.
    wp_unschedule_hook( 'slicewp_multi_currency_update_exchange_rates' );
    
    // Return with fail message if the call returns a WP_Error.
    if ( is_wp_error( $response ) ) {
    
	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'The connection to Open Exchange Rates API could not be established.', 'slicewp' ) ) ) );

    }

    $data = json_decode( wp_remote_retrieve_body( $response ), true );

    // Return with fail message if the app ID is incorrect.
    if ( isset( $data['error'] ) && isset( $data['message'] ) && $data['message'] == 'invalid_app_id' ) {
    
	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'Invalid Open Exchange Rates API app ID.', 'slicewp' ) ) ) );

    }

    // Return with fail message from the API.
    if ( isset( $data['error'] ) ) {

        if ( ! empty( $data['description'] ) ) {
            $message = $data['description'];
        } else {
            $message = __( 'Something went wrong. Please try again.', 'slicewp' );
        }

        wp_send_json( array( 'success' => false, 'data' => array( 'message' => $message ) ) );

    } else {

        // Save the app ID.
        $multi_currency_settings = slicewp_get_option( 'multi_currency', array() );

        $multi_currency_settings['currency_exchange_rates_update_method'] = 'openexchangerates';
        $multi_currency_settings['openexchangerates_app_id']              = $app_id;

        slicewp_update_option( 'multi_currency', $multi_currency_settings );

        // Set the cron job to update the exchange rates.
        if ( ! wp_next_scheduled( 'slicewp_multi_currency_update_exchange_rates' ) ) {
            wp_schedule_event( time() + DAY_IN_SECONDS / 2, 'daily', 'slicewp_multi_currency_update_exchange_rates' );
        }

        // Return with a success message.
	    wp_send_json( array( 'success' => true, 'data' => array( 'message' =>  __( 'Connected succesfully to the Open Exchange Rates API.', 'slicewp' ) ) ) );

    }

}
add_action( 'wp_ajax_slicewp_action_ajax_connect_openexchangerates', 'slicewp_action_ajax_connect_openexchangerates' );
*/

/**
 * Fetch and update new currency exchange rates.
 * 
 */
function slicewp_action_ajax_multi_currency_fetch_update_rates() {

    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}

    if ( empty( $_POST['currencies'] ) ) {
        wp_die( 0 );
    }

    $currencies = array_map( 'sanitize_text_field', $_POST['currencies'] );

    // Get the multi-currency settings.
    $multi_currency_settings = slicewp_get_option( 'multi_currency', array() );
    
    // Return with fail message if there's no API key set.
    if ( empty( $multi_currency_settings['exchangerate_api_api_key'] ) ) {

        wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'The ExchangeRates-API API key is not set. Please add the API key below.', 'slicewp' ) ) ) );

    }

    // Make the call to pull new exchange rates.
    $response = wp_remote_get( 'https://v6.exchangerate-api.com/v6/' . sanitize_text_field( $multi_currency_settings['exchangerate_api_api_key'] ) . '/latest/' . sanitize_text_field( slicewp_get_setting( 'active_currency', 'USD' ) ) );

    // Return with fail message if the call returns a WP_Error.
    if ( is_wp_error( $response ) ) {
    
	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'The connection to ExchangeRates-API could not be established.', 'slicewp' ) ) ) );

    }

    $data = json_decode( wp_remote_retrieve_body( $response ), true );

    // Return with fail message if the app ID is incorrect.
    if ( isset( $data['result'] ) && $data['result'] == 'error' ) {
    
        if ( isset( $data['error-type'] ) && $data['error-type'] == 'invalid-key' ) {

            $message = __( 'Invalid ExchangeRate-API API key provided.', 'slicewp' );

        } else {

            $message = sprintf( __( 'Error: %s', 'slicewp' ), ( ! empty( $data['error-type'] ) ? $data['error-type'] : 'not-specified' ) . '. ' . ( ! empty( $data['extra-info'] ) ? $data['extra-info'] : '' ) );

        }

	    wp_send_json( array( 'success' => false, 'data' => array( 'message' => $message ) ) );

    }

    // Return with fail message if no exchange rates were found.
    if ( empty( $data['conversion_rates'] ) ) {

        wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'No exchange rates found.', 'slicewp' ) ) ) );

    }

    // Filter only the rates we need.
    $rates = array();
    
    foreach ( $currencies as $currency ) {

        $rates[$currency] = ( ! empty( $data['conversion_rates'][$currency] ) ? _slicewp_sanitize_currency_exchange_rate( 1 / $data['conversion_rates'][$currency] ) : null );

    }

    $formatted_rates = array();

    foreach ( $rates as $currency => $rate ) {

        if ( ! is_null( $rate ) ) {

            $formatted_rates[] = array(
                'currency'      => $currency,
                'exchange_rate' => $rate
            );

        } else {

            foreach ( $multi_currency_settings['currency_exchange_rates'] as $key => $rate_data ) {

                if ( $currency == $rate_data['currency'] ) {

                    $formatted_rates[] = $multi_currency_settings['currency_exchange_rates'][$key];

                }

            }

        }

    }

    // Update settings.
    $multi_currency_settings['currency_exchange_rates'] = $formatted_rates;

    slicewp_update_option( 'multi_currency', $multi_currency_settings );

    // Update last updated.
    $last_updated = slicewp_get_option( 'last_updated', array() );
    $last_updated['currency_exchange_rates'] = slicewp_mysql_gmdate();
    slicewp_update_option( 'last_updated', $last_updated );

    // Return with a success messages.
    wp_send_json( array( 'success' => true, 'data' => array( 'rates' => $rates, 'last_updated' => slicewp_date_i18n( $last_updated['currency_exchange_rates'] ), 'message' =>  __( "Exchange rates updated successfully.", 'slicewp' ) ) ) );

}
add_action( 'wp_ajax_slicewp_action_ajax_multi_currency_fetch_update_rates', 'slicewp_action_ajax_multi_currency_fetch_update_rates' );