<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Adds the settings card for the multi-currency functionality in the plugin's main settings page.
 * 
 */
function slicewp_add_multi_currency_general_settings() {

    include_once 'views/view-multi-currency-general-settings.php';

}
add_action( 'slicewp_view_settings_tab_general_bottom', 'slicewp_add_multi_currency_general_settings' );


/**
 * Saves the multi-currency settings.
 * 
 */
function slicewp_admin_action_save_settings_multi_currency() {

    // Verify for nonce.
	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
        return;
    }

    if ( empty( $_POST['multi_currency'] ) ) {
        return;
    }

    // Sanitize the settings.
    $settings = stripslashes_deep( $_POST['multi_currency'] );

    // Update the exchange rates.
    if ( isset( $settings['currency_exchange_rates'] ) ) {

        $rates  = ( ! empty( $settings['currency_exchange_rates'] ) && is_array( $settings['currency_exchange_rates'] ) ? $settings['currency_exchange_rates'] : array() );
        $_rates = array();

        // Sanitize array.
        foreach ( $rates as $index => $rate ) {

            $rates[$index]['currency']      = sanitize_text_field( $rate['currency'] );
            $rates[$index]['exchange_rate'] = sanitize_text_field( $rate['exchange_rate'] );
            
        }

        // Remove duplicate currencies.
        foreach ( $rates as $index => $rate ) {

            if ( in_array( $rate['currency'], array_column( $_rates, 'currency' ) ) ) {
                continue;
            }

            $_rates[] = $rate;

        }

        // Update the last_updated date.
        $prev_settings = slicewp_get_option( 'multi_currency', array() );
        $prev_rates    = ( ! empty( $prev_settings['currency_exchange_rates'] ) && is_array( $prev_settings['currency_exchange_rates'] ) ? $prev_settings['currency_exchange_rates'] : array() );

        if ( $prev_rates !== $_rates ) {

            $last_updated = slicewp_get_option( 'last_updated', array() );
            $last_updated['currency_exchange_rates'] = slicewp_mysql_gmdate();
            slicewp_update_option( 'last_updated', $last_updated );

        }

        // Replace the post rates with the sanitized ones.
        $settings['currency_exchange_rates'] = $_rates;

    }

    // Update the settings array.
    slicewp_update_option( 'multi_currency', $settings );

}
add_action( 'slicewp_admin_action_save_settings', 'slicewp_admin_action_save_settings_multi_currency', 40 );