<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

$settings  = slicewp_get_option( 'multi_currency', array() );
$can_fetch = ( ! empty( $settings['exchangerate_api_api_key'] ) ? true : false );

?>

<div id="slicewp-card-settings-multi-currency" class="slicewp-card">

	<div class="slicewp-card-header">
        <span class="slicewp-card-title"><?php echo __( 'Multi-currency Settings', 'slicewp' ); ?></span>
	</div>

    <div class="slicewp-card-inner">

        <!-- Currency exchange rates -->
        <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

            <div class="slicewp-field-label-wrapper">
                <label for="slicewp-currency-exchange-rate">
                    <?php echo __( 'Currency Exchange Rates', 'slicewp' ); ?>
                </label>
            </div>

            <?php

                $active_currency = slicewp_get_setting( 'active_currency', 'USD' );

                $rates = ( ! empty( $_POST['multi_currency']['currency_exchange_rates'] ) ? $_POST['multi_currency']['currency_exchange_rates'] : ( ! empty( $settings['currency_exchange_rates'] ) ? $settings['currency_exchange_rates'] : array() ) );
                $rates = ( ! empty( $rates ) && is_array( $rates ) ? $rates : array() );

            ?>

            <input type="hidden" name="multi_currency[currency_exchange_rates]" value="" />

            <!-- Exchange Rates -->
            <?php foreach ( $rates as $index => $rate ): ?>

                <div class="slicewp-currency-exchange-rate" data-currency="<?php echo esc_attr( $rate['currency'] ); ?>">

                    <div class="slicewp-flex">

                        <input disabled type="number" step="any" min="0" value="1.00" />

                        <select name="multi_currency[currency_exchange_rates][<?php echo absint( $index ); ?>][currency]">

                            <?php $currencies = slicewp_get_currencies( 'all' ); ?>

                            <?php foreach ( $currencies as $iso_code => $data ): ?>
                                <option value="<?php echo esc_attr( $iso_code ); ?>" <?php selected( $rate['currency'], $iso_code ); ?>><?php echo $iso_code . ' - ' . $data['name'] . ' (' . $data['symbol'] . ')'; ?></option>
                            <?php endforeach; ?>

                        </select>

                        <?php echo slicewp_get_svg( 'outline-arrow-small-right' ); ?>

                        <input name="multi_currency[currency_exchange_rates][<?php echo absint( $index ); ?>][exchange_rate]" type="number" step="any" min="0" value="<?php echo $rate['exchange_rate']; ?>" />

                        <select class="slicewp-select2" disabled>
                            <option value="<?php echo esc_attr( slicewp_get_setting( 'active_currency', 'USD' ) ); ?>" selected><?php echo slicewp_get_setting( 'active_currency', 'USD' ); ?></option>
                        </select>

                        <a href="#" class="slicewp-remove-currency-exchange-rate" title="<?php echo __( 'Remove exchange rate', 'slicewp' ); ?>"><?php echo slicewp_get_svg( 'outline-x-circle' ); ?></a>
                    
                    </div>

                </div>

            <?php endforeach; ?>

            <!-- Add new exchange rate button -->
            <a id="slicewp-add-currency-exchange-rate" href="#" class="slicewp-button-secondary"><?php echo __( 'Add Exchange Rate', 'slicewp' ); ?></a>

            <a id="slicewp-fetch-currency-exchange-rates" href="#" class="slicewp-button-secondary <?php echo ( ! $can_fetch ? 'slicewp-disabled' : '' ); ?>" <?php echo ( empty( $settings['currency_exchange_rates'] ) || empty( $settings['currency_exchange_rates_update_method'] ) || $settings['currency_exchange_rates_update_method'] == 'manual' ? 'style="display: none;"' : '' ); ?>><span class="dashicons dashicons-update"></span><?php echo __( 'Update Rates', 'slicewp' ); ?></a>

            <input type="hidden" value="<?php echo count( $rates ); ?>" />

            <?php
                $last_updated = slicewp_get_option( 'last_updated', array() );
                $last_updated = ( ! empty( $last_updated['currency_exchange_rates'] ) ? $last_updated['currency_exchange_rates'] : '' );
            ?>

            <div class="slicewp-field-notice slicewp-field-notice-last-updated" style="width: fit-content; <?php echo ( ! empty( $last_updated ) && ! empty( $rates ) ? 'display: block;' : '' ); ?>">
                <p><?php echo sprintf( __( 'Last updated: %s' ), '<span>' . ( ! empty( $last_updated ) ? slicewp_date_i18n( $last_updated ) : '-' ) ) . '</span>'; ?></p>
            </div>

            <!-- Exchange rate placeholder -->
            <div class="slicewp-currency-exchange-rate slicewp-currency-exchange-rate-placeholder" data-currency="USD">

                <div class="slicewp-flex">
                    
                    <input disabled type="number" step="any" min="0" value="1.00" />

                    <select data-name="multi_currency[currency_exchange_rates][#rate_key][currency]">
                        
                        <?php $currencies = slicewp_get_currencies( 'all' ); ?>

                        <?php foreach ( $currencies as $iso_code => $data ): ?>
                            <option value="<?php echo esc_attr( $iso_code ); ?>"><?php echo $iso_code . ' - ' . $data['name'] . ' (' . $data['symbol'] . ')'; ?></option>
                        <?php endforeach; ?>

                    </select>

                    <?php echo slicewp_get_svg( 'outline-arrow-small-right' ); ?>

                    <input data-name="multi_currency[currency_exchange_rates][#rate_key][exchange_rate]" type="number" step="any" min="0" value="1.00" />

                    <select disabled>
                        <option value="<?php echo esc_attr( slicewp_get_setting( 'active_currency', 'USD' ) ); ?>" selected><?php echo slicewp_get_setting( 'active_currency', 'USD' ); ?></option>
                    </select>

                    <a href="#" class="slicewp-remove-currency-exchange-rate" title="<?php echo __( 'Remove exchange rate', 'slicewp' ); ?>"><?php echo slicewp_get_svg( 'outline-x-circle' ); ?></a>

                </div>

            </div>

        </div>
        <!-- / Exchange Rates -->

        <!-- Exchange Rate Update Method -->
        <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

            <div class="slicewp-field-label-wrapper">
                <label for="slicewp-exchange-rates-update-method">
                    <?php echo __( 'Rates Update Method', 'slicewp' ); ?>
                </label>
            </div>

            <select id="slicewp-exchange-rates-update-method" name="multi_currency[currency_exchange_rates_update_method]" class="slicewp-select2">
				<option value="manual" <?php echo selected( ( ! empty( $_POST['multi_currency']['currency_exchange_rates_update_method'] ) ? $_POST['multi_currency']['currency_exchange_rates_update_method'] : ( empty( $_POST ) && ! empty( $settings['currency_exchange_rates_update_method'] ) ? $settings['currency_exchange_rates_update_method'] : '' ) ) , 'manual' ); ?>><?php echo __( 'Manual', 'slicewp' ); ?></option>
                <option value="exchangerate-api" <?php echo selected( ( ! empty( $_POST['multi_currency']['currency_exchange_rates_update_method'] ) ? $_POST['multi_currency']['currency_exchange_rates_update_method'] : ( empty( $_POST ) && ! empty( $settings['currency_exchange_rates_update_method'] ) ? $settings['currency_exchange_rates_update_method'] : '' ) ) , 'exchangerate-api' ); ?>><?php echo __( 'ExchangeRates-API', 'slicewp' ); ?></option>
                <?php /* <option value="openexchangerates" <?php echo selected( ( ! empty( $_POST['multi_currency']['currency_exchange_rates_update_method'] ) ? $_POST['multi_currency']['currency_exchange_rates_update_method'] : ( empty( $_POST ) && ! empty( $settings['currency_exchange_rates_update_method'] ) ? $settings['currency_exchange_rates_update_method'] : '' ) ) , 'openexchangerates' ); ?>><?php echo __( 'Open Exchange Rates API', 'slicewp' ); ?></option> */ ?>
			</select>

            <?php /* 
            <!-- Open Exchange Rates API -->
            <div class="slicewp-exchange-rates-update-method-settings" data-method="openexchangerates">

                <p><?php echo sprintf( __( '%sOpen Exchange Rates API%s is a service that provides real-time currency exchange rate data.', 'slicewp' ), '<a href="https://openexchangerates.org/" target="_blank">', '</a>' ); ?></p>

                <p><?php echo __( 'Add your Open Exchange Rates API app ID below to update the currency exchange rates on a daily basis.', 'slicewp' ); ?></p>

                <label for="slicewp-openexchangerates-app-id"><?php echo __( 'App ID', 'slicewp' ); ?></label>

                <div class="slicewp-flex">
                    <input id="slicewp-openexchangerates-app-id" name="multi_currency[openexchangerates_app_id]" type="password" value="<?php echo( ! empty( $_POST['multi_currency']['openexchangerates_app_id'] ) ? esc_attr( $_POST['multi_currency']['openexchangerates_app_id'] ) : ( ! empty( $settings['openexchangerates_app_id'] ) ? esc_attr( $settings['openexchangerates_app_id'] ) : '' ) ); ?>">
                    <a href="#" id="slicewp-connect-openexchangerates" class="slicewp-button-secondary">
                        <span><?php echo __( 'Connect', 'slicewp' ); ?></span>
                        <div class="spinner"></div>
                    </a>
                </div>

                <p><a class="slicewp-exchange-rates-update-method-more-info" href="https://slicewp.com/docs/" target="_blank"><span class="dashicons dashicons-info-outline"></span><?php echo __( 'Learn more about Open Exchange Rates API', 'slicewp' ); ?></a></p>

            </div>
            <!-- / Open Exchange Rates API -->
            */ ?>

            <!-- Exchange Rates-API -->
            <div class="slicewp-exchange-rates-update-method-settings slicewp-tooltip-wide" data-method="exchangerate-api">

                <label for="slicewp-exchangerate-api-api-key">
                    <?php echo __( 'API Key', 'slicewp' ); ?>
                    <?php echo slicewp_output_tooltip( '<p>' . sprintf( __( '%sExchangeRates-API%s is a service that provides real-time currency exchange rate data.', 'slicewp' ), '<a href="https://www.exchangerate-api.com/" target="_blank">', '</a>' ) . '</p>' . '<p>' . __( 'Add your API key below to automatically update the currency exchange rates on a daily basis.', 'slicewp' ) . '</p>' . '<hr />' . '<p><a class="slicewp-exchange-rates-update-method-more-info" href="https://slicewp.com/products/multi-currency/#exchangerate-api-setup" target="_blank"><span class="dashicons dashicons-info-outline"></span>' . __( 'Learn more about ExchangeRate-API', 'slicewp' ) . '</a></p>' ); ?>
                </label>

                <div class="slicewp-flex">
                    <input id="slicewp-exchangerate-api-api-key" name="multi_currency[exchangerate_api_api_key]" type="password" value="<?php echo( ! empty( $_POST['multi_currency']['exchangerate_api_api_key'] ) ? esc_attr( $_POST['multi_currency']['exchangerate_api_api_key'] ) : ( ! empty( $settings['exchangerate_api_api_key'] ) ? esc_attr( $settings['exchangerate_api_api_key'] ) : '' ) ); ?>">
                    <a href="#" id="slicewp-connect-exchangerate-api" class="slicewp-button-secondary" data-action="<?php echo ( ! empty( $settings['exchangerate_api_api_key'] ) ? 'disconnect' : 'connect' ); ?>">
                        <span data-connected="false" <?php echo ( ! empty( $settings['exchangerate_api_api_key'] ) ? 'style="display: none;"' : '' ); ?>><?php echo __( 'Connect', 'slicewp' ); ?></span>
                        <span data-connected="true" <?php echo ( empty( $settings['exchangerate_api_api_key'] ) ? 'style="display: none;"' : '' ); ?>><?php echo __( 'Disconnect', 'slicewp' ); ?></span>
                        <div class="spinner"></div>
                    </a>
                </div>

                <?php /*
                <p><a class="slicewp-exchange-rates-update-method-more-info" href="https://slicewp.com/docs/" target="_blank"><span class="dashicons dashicons-info-outline"></span><?php echo __( 'Learn more about ExchangeRate-API', 'slicewp' ); ?></a></p>
                */ ?>

            </div>
            <!-- Exchange Rates-API -->

        </div>
        <!-- / Exchange Rate Update Method -->
        
    </div>

</div>