<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Builds and outputs the children tree diagram for the given affiliate.
 * 
 */
class SliceWP_Admin_Affiliates_Tree_Diagram {

    /**
     * The affiliate for which to build the tree diagram.
     * 
     * @var    SliceWP_Affiliate;
     * @access protected
     * 
     */
    protected $affiliate = null;

    /**
     * The parent of the affiliate for which the tree is being built.
     * 
     * @var    SliceWP_Affiliate;
     * @access protected
     * 
     */
    protected $affiliate_parent = null;


    /**
     * Outputs the tree diagram for the given affiliate.
     * 
     * @param int|SliceWP_Affiliate $affiliate
     * 
     */
    public function output( $affiliate ) {

        $this->affiliate = slicewp_get_affiliate( $affiliate );

        if ( is_null( $this->affiliate ) ) {
            return;
        }

        $this->affiliate_parent = slicewp_get_affiliate( $this->affiliate->get( 'parent_id' ) );

        ?>

            <div class="slicewp-tree-diagram">

                <ul>

                    <li class="slicewp-tree-diagram-root">

                        <?php if ( is_null( $this->affiliate_parent ) ): ?>

                            <div class="slicewp-affiliate-card slicewp-root-affiliate">

                                <?php echo get_avatar( $this->affiliate->get( 'user_id' ), 36 ); ?>

                                <div>
                                    <div class="slicewp-affiliate-card-name"><?php echo slicewp_get_affiliate_name( $this->affiliate ); ?></div>
                                    <div class="slicewp-affiliate-card-email"><?php echo slicewp_get_affiliate_email( $this->affiliate ); ?></div>
                                </div>
                                
                            </div>

                            <?php self::output_children( $this->affiliate->get( 'id' ) ); ?>

                        <?php else: ?>
                           
                            <div class="slicewp-affiliate-card slicewp-parent-affiliate">

                                <a href="<?php echo esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'subpage' => 'edit-affiliate', 'tab' => 'network', 'affiliate_id' => $this->affiliate_parent->get( 'id' ) ), admin_url( 'admin.php' ) ) ); ?>">

                                    <?php echo get_avatar( $this->affiliate_parent->get( 'user_id' ), 36 ); ?>

                                    <div>
                                        <div class="slicewp-affiliate-card-name"><?php echo slicewp_get_affiliate_name( $this->affiliate_parent ); ?></div>
                                        <div class="slicewp-affiliate-card-email"><?php echo slicewp_get_affiliate_email( $this->affiliate_parent ); ?></div>
                                    </div>

                                </a>

                                <small><?php echo __( 'Parent', 'slicewp' ); ?></small>

                            </div>

                            <ul>

                                <li>

                                    <div class="slicewp-affiliate-card slicewp-root-affiliate">

                                        <?php echo get_avatar( $this->affiliate->get( 'user_id' ), 36 ); ?>

                                        <div>
                                            <div class="slicewp-affiliate-card-name"><?php echo slicewp_get_affiliate_name( $this->affiliate ); ?></div>
                                            <div class="slicewp-affiliate-card-email"><?php echo slicewp_get_affiliate_email( $this->affiliate ); ?></div>
                                        </div>

                                    </div>

                                    <?php self::output_children( $this->affiliate->get( 'id' ) ); ?>

                                </li>

                            </ul>

                        <?php endif; ?>

                    </li>

                </ul>

            </div>

        <?php

    }


    /**
     * Outputs the children of the given affiliate.
     * 
     * @param int|SliceWP_Affiliate $parent
     * 
     */
    protected function output_children( $parent ) {

        $parent   = slicewp_get_affiliate( $parent );
        $children = slicewp_get_affiliate_children( $parent );

        if ( empty( $children ) ) {
            return;
        }

        ?>

            <ul>
                
                <?php foreach ( $children as $affiliate ): ?>
                    
                    <li>

                        <div class="slicewp-affiliate-card">

                            <a href="<?php echo esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'subpage' => 'edit-affiliate', 'tab' => 'network', 'affiliate_id' => $affiliate->get( 'id' ) ), admin_url( 'admin.php' ) ) ); ?>">

                                <?php echo get_avatar( $affiliate->get( 'user_id' ), 36 ); ?>

                                <div>
                                    <div class="slicewp-affiliate-card-name"><?php echo slicewp_get_affiliate_name( $affiliate ); ?></div>
                                    <div class="slicewp-affiliate-card-email"><?php echo slicewp_get_affiliate_email( $affiliate ); ?></div>
                                </div>

                            </a>

                        </div>

                        <?php self::output_children( $affiliate ); ?>

                    </li>

                <?php endforeach; ?>

            </ul>
        
        <?php

    }

}