<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * AJAX callback that removes the invoice from the payment.
 * 
 */
function slicewp_action_ajax_payment_remove_invoice() {

    // Check for nonce.
    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_payment_remove_invoice' ) ) {
		wp_die( 0 );
	}

    // Check that the payment ID is given.
    if ( empty( absint( $_POST['payment_id'] ) ) ) {
        wp_die( 0 );
    }

    slicewp_delete_payment_meta( absint( $_POST['payment_id'] ), '_invoice_attachment_id' );

    wp_send_json_success();

}
add_action( 'wp_ajax_slicewp_action_ajax_payment_remove_invoice', 'slicewp_action_ajax_payment_remove_invoice' );


/**
 * AJAX callback that adds the invoice from the payment.
 * 
 */
function slicewp_action_ajax_payment_add_invoice() {

    // Check for nonce.
    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_payment_add_invoice' ) ) {
		wp_die( 0 );
	}

    $payment_id = ( ! empty( $_POST['payment_id'] ) ? absint( $_POST['payment_id'] ) : 0 );

    // Check that the payment ID is given and payment is valid.
    if ( empty( $payment_id ) ) {
        wp_die( 0 );
    }

    $payment = slicewp_get_payment( $payment_id );

    if ( is_null( $payment ) ) {
        wp_die( 0 );
    }

    $attachment_id = ( ! empty( $_POST['attachment_id'] ) ? absint( $_POST['attachment_id'] ) : 0 );

    // Check that the attachment ID is given and attachment is valid.
    if ( empty( $attachment_id ) ) {
        wp_die( 0 );
    }

    $attachment_url = wp_get_attachment_url( $attachment_id );

    if ( empty( $attachment_url ) ) {
        wp_die( 0 );
    }

    // Make sure attachment is PDF.
    if ( 'application/pdf' != get_post_mime_type( $attachment_id ) ) {
        wp_die( 0 );
    }

    slicewp_add_payment_meta( $payment_id, '_invoice_attachment_id', $attachment_id );

    ob_start();

    $invoice_attachment_id = $attachment_id;

    include 'views/view-element-payment-invoice-attachment.php';

    $view = ob_get_contents();

    ob_end_clean();

    wp_send_json_success( array( 'html' => $view ) );

}
add_action( 'wp_ajax_slicewp_action_ajax_payment_add_invoice', 'slicewp_action_ajax_payment_add_invoice' );