<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Registers the "requested" payment type.
 *
 * @param array $statuses
 *
 * @return array
 *
 */
function slicewp_register_payment_status_request( $statuses ) {

	$statuses['requested'] = __( 'Requested', 'slicewp' );

	return $statuses;

}
add_filter( 'slicewp_payment_available_statuses', 'slicewp_register_payment_status_request' );


/**
 * 
 * 
 */
function slicewp_generate_affiliate_payment_request_preview( $affiliate_id ) {

	$grace_period = absint( slicewp_get_setting( 'commissions_grace_period', 0 ) );

	// Set up to date.
	$date_max = new DateTime( date( 'Y-m-d' ) . ' 23:59:59' );

	// Take into account the grace period.
	if ( ! empty( $grace_period ) ) {

		$date_grace_end = new DateTime( date( 'Y-m-d' ) . ' 23:59:59');
		$date_grace_end = $date_grace_end->modify( '-' . $grace_period . ' day' );

		if ( $date_max > $date_grace_end ) {

			$date_max = $date_grace_end;

		}

	}

	// Prepare the arguments to read the commissions.
	$commission_args = array(
		'fields'       => array( 'id', 'amount' ),
		'number'	   => -1,
		'status'	   => 'unpaid',
		'date_min' 	   => '',
		'date_max' 	   => ( ! empty( $date_max ) ? get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ) : '' ),
		'affiliate_id' => $affiliate_id,
		'payment_id'   => 0
	);

	$commissions = slicewp_get_commissions( $commission_args );

	// Bail if the affiliate doesn't have any commissions.
	if ( empty( $commissions ) ) {
		
		return array(
			'amount' 		 => 0,
			'currency' 		 => slicewp_get_setting( 'active_currency', 'USD' ),
			'commission_ids' => array()
		);

	}

	$commissions = array_map( 'slicewp_object_to_array', $commissions );	

	return array(
		'amount' 		 => array_sum( array_column( $commissions, 'amount' ) ),
		'currency' 		 => slicewp_get_setting( 'active_currency', 'USD' ),
		'commission_ids' => array_column( $commissions, 'id' )
	);
	
}