<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Payout Requests" add-on class.
 * 
 */
class SliceWP_Add_On_Payout_Requests extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'payout_requests';

		// Name.
		$this->name = 'Payout Requests';

		// Description.
		$this->description = 'Allow your affiliates to request payouts for payable commissions from their account.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-payout-requests.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/payout-requests/';

		// Settings URL.
		$this->settings_url = '';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		add_action( 'slicewp_activated_add_on', array( $this, 'set_general_settings' ) );

        if ( $this->is_active() ) {

			// Frontend scripts.
			add_action( 'slicewp_enqueue_front_end_scripts', array( $this, 'register_front_end_scripts' ) );
			add_action( 'slicewp_affiliate_account_tab_payments_top', array( $this, 'enqueue_front_end_scripts' ), 5 );

		}

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		$files = array(
			'base/functions.php',
            'base/functions-email-notifications.php',
            'admin/functions.php',
			'admin/functions-actions-ajax.php',
            'users/functions.php',
            'users/functions-actions-ajax.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


    /**
	 * Registers and enqueues the scripts and style for the user area.
	 *
	 */
	public function register_front_end_scripts( $hook ) {

		// Plugin script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script', $this->get_dir_url() . 'assets/js/script-front-end.js', array(), $this->get_parent_plugin_version() );

	}


	/**
	 * Enqueues the scripts for the user area.
	 * 
	 */
	public function enqueue_front_end_scripts() {

		// Print the CSS from the front-end file in the page.
		if ( file_exists( $this->get_dir_path() . 'assets/css/style-front-end.css' ) ) {

			ob_start();

			include $this->get_dir_path() . 'assets/css/style-front-end.css';

			$css = ob_get_contents();
			ob_end_clean();

			printf(
				"<style id='slicewp-" . esc_attr( str_replace( '_', '-', $this->slug ) ) . "-style-front-end-inline-css' type='text/css'>\n%s\n</style>\n",
				$css
			);
			
		}

		// Enqueue the front-end script.
		wp_enqueue_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script' );

	}


	/**
	 * Sets the default general settings on add-on activation.
	 * 
	 * @param string $add_on_slug
	 *
	 */
	public function set_general_settings( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		$settings = slicewp_get_option( 'settings', array() );

		if ( ! is_array( $settings ) ) {
			return;
		}

		if ( ! isset( $settings['email_notifications']['admin_payment_request'] ) ) {

			$settings['email_notifications']['admin_payment_request'] = array(
				'enabled' => 1,
				'subject' => __( "Affiliate Payout Request", 'slicewp' ),
				'content' => __( "{{affiliate_first_name}} {{affiliate_last_name}} has requested a payout, totalling {{payment_amount}}.", 'slicewp' )
			);

		}

		if ( ! isset( $settings['email_notifications']['affiliate_payment_request'] ) ) {

			$settings['email_notifications']['affiliate_payment_request'] = array(
				'enabled' => 1,
				'subject' => __( "Payout Request Received", 'slicewp' ),
				'content' => __( "We've received your payout request and we will be processing it soon. Thank you!", 'slicewp' )
			);
			
		}

		slicewp_update_option( 'settings', $settings );

	}

}


/**
 * Registers the "Payout Requests" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_payout_requests( $add_ons ) {

	$add_ons['payout_requests'] = 'SliceWP_Add_On_Payout_Requests';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_payout_requests', 140 );