<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Include the settings for the PayPal App credentials.
 *
 */
function slicewp_view_settings_paypal_credentials() {

	include_once 'views/view-settings-paypal-credentials.php';

}
add_action( 'slicewp_view_settings_tab_integrations_bottom', 'slicewp_view_settings_paypal_credentials' );


/**
 * Include the do single payment card.
 * 
 */
function slicewp_view_payouts_review_payment_bottom_do_single_payment_paypal_payouts() {

	include_once 'views/view-payouts-do-single-payment.php';

}
add_action( 'slicewp_view_payouts_review_payment_bottom', 'slicewp_view_payouts_review_payment_bottom_do_single_payment_paypal_payouts' );


/**
 * Include the PayPal Payout details card.
 * 
 */
function slicewp_view_payouts_review_payment_bottom_payout_details_paypal_payouts() {

	include_once 'views/view-payouts-paypal-payout-details.php';

}
add_action( 'slicewp_view_payouts_review_payment_bottom', 'slicewp_view_payouts_review_payment_bottom_payout_details_paypal_payouts' );


/**
 * Register admin notices sent via the URL.
 * 
 */
function slicewp_register_query_url_admin_notices_paypal_payouts() {

	// Because we are on "admin_init", make sure core is active.
	if ( ! function_exists( 'slicewp' ) ) {
		return;
	}

	if ( empty( $_GET['slicewp_message'] ) ) {
		return;
	}

	// Single payment success.
	slicewp_admin_notices()->register_notice( 'payout_single_payment_paypal_payouts_success', '<p>' . __( 'The payout was successfully created in PayPal. The payment is being processed, which may take a few minutes.', 'slicewp' ) . '</p>' );

	// Bulk payments success.
	slicewp_admin_notices()->register_notice( 'payout_bulk_payments_paypal_payouts_success', '<p>' . __( 'The payout was successfully created in PayPal. The payments are being processed, which may take a few minutes.', 'slicewp' ) . '</p>' );

}
add_action( 'admin_init', 'slicewp_register_query_url_admin_notices_paypal_payouts' );


/**
 * Register and display an admin notice if the PayPal credentials are missing
 *
 */
function slicewp_paypal_credentials_admin_notice() {

	// Because we are on "admin_init", make sure core is active.
	if ( ! function_exists( 'slicewp' ) ) {
		return;
	}

	if ( empty( $_GET['page'] ) || ! is_string( $_GET['page'] ) ) {
		return;
	}

	if ( false === strpos( $_GET['page'], 'slicewp' ) || $_GET['page'] == 'slicewp-dashboard' ) {
		return;
	}

	if ( slicewp_has_paypal_api_credentials_set() ) {
		return;
	}

	slicewp_admin_notices()->register_notice( 'slicewp_paypal_credentials_missing', '<p>' . sprintf( __( 'Your PayPal credentials are missing. To be able to pay your affiliates using PayPal Payouts, please %sadd your PayPal credentials in SliceWP &rarr; Settings%s', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), 'admin.php' ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ) . '</p>', 'notice-error' );
	slicewp_admin_notices()->display_notice( 'slicewp_paypal_credentials_missing' );

}
add_action( 'admin_init', 'slicewp_paypal_credentials_admin_notice' );


/**
 * Register core admin dashboard notifications for missing API credentials.
 *
 */
function slicewp_register_admin_dashboard_notification_paypal_api_credentials() {

	// Because we are on "admin_init", make sure core is active.
	if ( ! function_exists( 'slicewp' ) ) {
		return;
	}

	if ( slicewp_has_paypal_api_credentials_set() ) {
		return;
	}

	slicewp_admin_dashboard_notifications()->register_notification( 'paypal_credentials_missing', '<p>' . __( 'Your PayPal API credentials are missing. To be able to pay your affiliates using PayPal Payouts, you need to connect your PayPal business account to SliceWP.', 'slicewp' ) . '</p><p>' . sprintf( __( '%sAdd your PayPal credentials%s', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), 'admin.php' ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ) . '</p>' );

}
add_action( 'admin_init', 'slicewp_register_admin_dashboard_notification_paypal_api_credentials' );


/**
 * Adds extra HTML after the "Payout Method" field found in the do bulk payments admin form.
 * 
 * @param int $payout_id
 * 
 */
function slicewp_form_do_bulk_payments_payout_method_bottom_paypal_payouts( $payout_id ) {

	if ( empty( $payout_id ) ) {
		return;
	}

	if ( ! slicewp_has_paypal_api_credentials_set() ) {

		?>

			<div class="slicewp-field-notice slicewp-field-notice-warning" data-payout-method="paypal_payouts">
				<p><?php echo sprintf( __( 'Your PayPal credentials are missing. To be able to pay your affiliates using PayPal Payouts, please %sadd your PayPal credentials in SliceWP &rarr; Settings%s', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), 'admin.php' ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ); ?></p>
			</div>

		<?php

	} else {

		$payments = slicewp_get_payments( array( 'number' => -1, 'payout_id' => $payout_id, 'payout_method' => 'paypal_payouts', 'status' => 'unpaid' ) );

		// Take into account only payments that haven't been processed through PayPal already.
		foreach ( $payments as $key => $payment ) {

			$paypal_payout_batch_id = slicewp_get_payment_meta( $payment->get( 'id' ), 'paypal_payout_batch_id', true );
	
			if ( ! empty( $paypal_payout_batch_id ) ) {
	
				unset( $payments[$key] );
				continue;
	
			}
	
		}
	
		$payments = array_values( $payments );

		if ( empty( $payments ) ) {
			return;
		}

		if ( ! empty( slicewp_get_setting( 'paypal_api_test_mode' ) ) ) {

			?>

				<div class="slicewp-field-notice slicewp-field-notice-warning" data-payout-method="paypal_payouts">
					<p><?php echo sprintf( __( '%sPayPal Payouts is in test mode.%s This means that payments will be processed through your PayPal Sandbox account, not your live PayPal Business account.', 'slicewp' ), '<strong>', '</strong>' ); ?></p>
					<p><?php echo sprintf( __( 'To send real affiliate payments, %sdisable Test Mode from the Settings page%s.', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), admin_url( 'admin.php' ) ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ); ?></p>
				</div>

			<?php

		}
		
		?>

			<div class="slicewp-select2-option-selection-description" data-option="paypal_payouts">
				<p><?php echo sprintf( _n( 'There is %d unpaid payment in this payout, totaling %s, payable through PayPal Payouts.', 'There are %d unpaid payments in this payout, totaling %s, payable through PayPal Payouts.', count( $payments ), 'slicewp' ), count( $payments ), slicewp_format_amount( array_sum( array_column( array_map( 'slicewp_object_to_array', $payments ), 'amount' ) ), slicewp_get_setting( 'active_currency', 'USD' ) ) ); ?></p>
				<p><?php echo __( 'By clicking the button below, these payments will be processed through your PayPal account.', 'slicewp' ) ?></p>
			</div>

		<?php
		
	}

}
add_action( 'slicewp_form_do_bulk_payments_payout_method_bottom', 'slicewp_form_do_bulk_payments_payout_method_bottom_paypal_payouts' );


/**
 * Adds the "Pay with PayPal" option to the payments tables.
 * 
 * @param array $row_actions
 * @param array $item
 * 
 * @return array
 * 
 */
function slicewp_list_table_payments_row_actions_paypal_payouts( $row_actions, $item ) {

	if ( 'paypal_payouts' != $item['payout_method'] ) {
		return $row_actions;
	}

	if ( ! in_array( $item['status'], array( 'unpaid', 'requested' ) ) ) {
		return $row_actions;
	}

	// Bail if the payment has a PayPal payout batch ID saved.
	$payout_batch_id = slicewp_get_payment_meta( $item['id'], 'paypal_payout_batch_id', true );

	if ( ! empty( $payout_batch_id ) ) {
		return $row_actions;
	}

	$row_actions = array_reverse( $row_actions );

	$payout_methods = slicewp_get_payout_methods();
	$confirmation   = ( ! empty( $payout_methods['paypal_payouts']['messages']['payout_action_confirmation_single_payment'] ) ? $payout_methods['paypal_payouts']['messages']['payout_action_confirmation_single_payment'] : '' );

	$row_actions['pay_with_paypal_payouts'] = '<a ' . ( ! empty( $confirmation ) ? 'onclick="return confirm(' . esc_attr( '"' . $confirmation . '"' ) . ');"' : '' ) . ' href="' . esc_url( wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'do_single_payment', 'payout_method' => 'paypal_payouts', 'payment_id' => absint( $item['id'] ) ) ), 'slicewp_do_single_payment', 'slicewp_token' ) ) . '">' . __( 'Pay with PayPal', 'slicewp' ) . '</a>';

	$row_actions = array_reverse( $row_actions );

	return $row_actions;

}
add_filter( 'slicewp_list_table_payout_payments_row_actions', 'slicewp_list_table_payments_row_actions_paypal_payouts', 15, 2 );
add_filter( 'slicewp_list_table_payments_row_actions', 'slicewp_list_table_payments_row_actions_paypal_payouts', 15, 2 );