<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "PayPal Payouts" add-on class.
 * 
 */
class SliceWP_Add_On_PayPal_Payouts extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'paypal_payouts';

		// Name.
		$this->name = 'PayPal Payouts';

		// Description.
		$this->description = "Pay affiliates in bulk directly from your WordPress administrator interface through PayPal's Payouts feature.";

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-paypal-payouts.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/docs/paying-affiliates-paypal-payouts/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), admin_url( 'admin.php' ) ) . '#slicewp-card-payouts-settings';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'base/class-paypal-payouts-api.php',
			'admin/functions.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}

}


/**
 * Registers the "PayPal Payouts" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_paypal_payouts( $add_ons ) {

	$add_ons['paypal_payouts'] = 'SliceWP_Add_On_PayPal_Payouts';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_paypal_payouts', 30 );