<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * List table class outputter for performance bonuses.
 *
 */
Class SliceWP_WP_List_Table_Performance_Bonuses extends SliceWP_WP_List_Table {

	/**
	 * The number of bonuses that should appear in the table.
	 *
	 * @access private
	 * @var int
	 *
	 */
	private $items_per_page;

	/**
	 * The data of the table.
	 *
	 * @access public
	 * @var array
	 *
	 */
	public $data = array();

	/**
	 * Constructor.
	 *
	 */
	public function __construct() {

		parent::__construct( array(
			'plural' 	=> 'slicewp_performance_bonuses',
			'singular' 	=> 'slicewp_performance_bonus',
			'ajax' 		=> false
		));

		$this->items_per_page = 100000;
		$this->paged 		  = 1;

		// Get and set table data
		$this->set_table_data();
		
		// Add column headers and table items
		$this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );
		$this->items 		   = $this->data;

	}


	/**
	 * Returns all the columns for the table.
	 *
	 */
	public function get_columns() {

		$columns = array(
            'sort_handle'   => '',
			'id'			=> __( 'ID', 'slicewp' ),
			'name'		    => __( 'Name' , 'slicewp'),
            'target'        => __( 'Target', 'slicewp' ),
            'reward'        => __( 'Reward', 'slicewp' ),
			'recurrence'	=> __( 'Recurrence', 'slicewp' ),
			'status'		=> __( 'Status', 'slicewp' ),
			'actions'		=> ''
		);

		/**
		 * Filter the columns of the table.
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_performance_bonuses_columns', $columns );

	}


	/**
     * Returns the possible views for the performance bonuses list table.
     *
     */
    protected function get_views() {

        return array();

	}


    /**
	 * Get a list of CSS classes for the table tag.
	 *
	 * @return array
	 * 
	 */
	protected function get_table_classes() {

		return array( 'striped', $this->_args['plural'] );

	}

	
	/**
	 * Gets the bonuses data and sets it.
	 *
	 */
	private function set_table_data() {

		$bonuses = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );
		
		if ( empty( $bonuses ) ) {
            return;
        }

		foreach ( $bonuses as $bonus ) {

			$row_data = $bonus;

			/**
			 * Filter the performance bonus row data.
			 *
			 * @param array $row_data
			 *
			 */
			$row_data = apply_filters( 'slicewp_list_table_performance_bonuses_row_data', $row_data );

			$this->data[] = $row_data;

		}
		
	}


	/**
	 * Returns the HTML that will be displayed in each columns.
	 *
	 * @param array  $item 			- data for the current row
	 * @param string $column_name 	- name of the current column
	 *
	 * @return string
	 *
	 */
	public function column_default( $item, $column_name ) {

		return isset( $item[ $column_name ] ) ? $item[ $column_name ] : '-';

	}


    /**
     * Returns the HTML that will be displayed in the "sort_handle" column.
     * 
     * @param array $item - data for the current row
	 *
	 * @return string
	 *
     */
    public function column_sort_handle( $item ) {

        return '<div class="slicewp-sort-handle ui-sortable-handle" data-bonus-id="' . absint( $item['id'] ) . '"></div>';

    }


    /**
	 * Returns the HTML that will be displayed in the "name" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_name( $item ) {

		$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'subpage' => 'edit-performance-bonus', 'bonus_id' => absint( $item['id'] ) ), 'admin.php' ) ) . '">' . $item['name'] . '</a>';

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "target" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_target( $item ) {

        $output = '';

        if ( $item['target_type'] == 'referred_orders_count' ) {
            $output  = absint( $item['target'] );
			$output .= '<div>' . __( 'Referred orders', 'slicewp' ) . '</div>';
        }

        if ( $item['target_type'] == 'referred_orders_totals' ) {
            $output  = slicewp_format_amount( $item['target'], slicewp_get_setting( 'active_currency', 'USD' ) );
			$output .= '<div>' . __( 'Referred orders total', 'slicewp' ) . '</div>';
        }

		if ( $item['target_type'] == 'earned_commissions_totals' ) {
            $output  = slicewp_format_amount( $item['target'], slicewp_get_setting( 'active_currency', 'USD' ) );
			$output .= '<div>' . __( 'Earned commissions total', 'slicewp' ) . '</div>';
        }

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "reward" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_reward( $item ) {

		$output = '';

        if ( $item['reward_type'] == 'commission' ) {
			$output  = slicewp_format_amount( $item['reward_commission_amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
            $output .= '<div>' . __( 'Fixed commission', 'slicewp' ) . '</div>';
        }

        if ( $item['reward_type'] == 'store_credit' ) {
            $output  = slicewp_format_amount( $item['reward_store_credit_amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
			$output .= '<div>' . __( 'Store credit', 'slicewp' ) . '</div>';
        }

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "recurrence" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_recurrence( $item ) {

		$recurrences = array(
            'one_time'  => __( 'One-time', 'slicewp' ),
            'monthly'   => __( 'Monthly', 'slicewp' ),
            'quarterly' => __( 'Quarterly', 'slicewp' ),
            'yearly'    => __( 'Yearly', 'slicewp' )
        );

		return ( ! empty( $recurrences[$item['recurrence']] ) ? $recurrences[$item['recurrence']] : '-' );

	}


    /**
	 * Returns the HTML that will be displayed in the "status" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_status( $item ) {

		$statuses = array(
            'active'   => __( 'Active', 'slicewp' ),
            'inactive' => __( 'Inactive', 'slicewp' )
        );

		$output = ( ! empty( $statuses[$item['status']] ) ? '<span class="slicewp-status-pill slicewp-status-' . esc_attr( $item['status'] ) . '">' . $statuses[$item['status']] . '</span>' : '' );

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "date_created" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_date_created( $item ) {

		$output = slicewp_date_i18n( $item['date_created'] );

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "actions" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_actions( $item ) {

		/**
		 * Set row actions.
		 *
		 */
		$row_actions = array();

        if ( $item['status'] == 'active' ) {
			$row_actions['deactivate'] = '<a href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_action' => 'deactivate_performance_bonus', 'bonus_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_deactivate_performance_bonus', 'slicewp_token' ) ) . '">' . __( 'Deactivate', 'slicewp' ) . '</a>';
		}

		if ( $item['status'] == 'inactive' ) {
			$row_actions['activate'] = '<a href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_action' => 'activate_performance_bonus', 'bonus_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_activate_performance_bonus', 'slicewp_token' ) ) . '">' . __( 'Activate', 'slicewp' ) . '</a>';
		}

		$row_actions['delete'] = '<a class="slicewp-trash" onclick="return confirm( \'' . __( "Are you sure you want to delete this bonus?", "slicewp" ) . ' \' )" href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_action' => 'delete_performance_bonus', 'bonus_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_delete_performance_bonus', 'slicewp_token' ) ) . '">' . __( 'Delete', 'slicewp' ) . '</a>';

		/**
		 * Filter the row actions.
		 * 
		 * @param array $row_actions
		 * @param array $item
		 * 
		 */
		$row_actions = apply_filters( 'slicewp_list_table_performance_bonuses_row_actions', $row_actions, $item );

		$output = '<div class="row-actions">';

			$output .= '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'subpage' => 'edit-performance-bonus', 'bonus_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ) ) . '" class="slicewp-button-secondary">' . __( 'Edit', 'slicewp' ) . '</a>';
			$output .= '<a href="#" class="slicewp-button-toggle-actions"><svg class="" height="24" width="24" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M7 12c0 1.104-.896 2-2 2s-2-.896-2-2 .896-2 2-2 2 .896 2 2zm12-2c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2zm-7 0c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2z"></path></svg></a>';

			$output .= '<div class="slicewp-actions-dropdown">';
			
				foreach ( $row_actions as $row_action ) {

					if ( empty( $row_action ) ) {
						continue;
					}
					
					$output .= $row_action;

				}

			$output .= '</div>';

		$output .= '</div>';

		return $output;

	}

	/**
	 * HTML display when there are no items in the table.
	 *
	 */
	public function no_items() {

		echo __( 'No bonuses found.', 'slicewp' );

	}

}