<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Register the "Performance Bonuses" admin submenu page.
 *
 */
function slicewp_register_submenu_page_performance_bonuses( $submenu_pages ) {

	if ( ! is_array( $submenu_pages ) ) {
		return $submenu_pages;
	}

	$submenu_pages['performance_bonuses'] = array(
		'class_name' => 'SliceWP_Submenu_Page_Performance_Bonuses',
		'data' 		 => array(
			'page_title' => __( 'Bonuses', 'slicewp' ),
			'menu_title' => __( 'Bonuses', 'slicewp' ),
			'capability' => apply_filters( 'slicewp_submenu_page_capability_performance_bonuses', 'manage_options' ),
			'menu_slug'  => 'slicewp-performance-bonuses'
		)
	);

	return $submenu_pages;

}
add_filter( 'slicewp_register_submenu_page', 'slicewp_register_submenu_page_performance_bonuses', 45 );


/**
 * Includes the affiliate bonuses progress view in the affiliate edit page.
 * 
 */
function slicewp_output_view_affiliate_bonuses_progress() {

	$affiliate_id = ( ! empty( $_GET['affiliate_id'] ) ? sanitize_text_field( $_GET['affiliate_id'] ) : 0 );

	if ( empty( $affiliate_id ) ) {
		return;
	}

	$bonuses = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );

	if ( ! empty( $bonuses ) ) {

		// Filter out inactive bonuses.
		foreach ( $bonuses as $bonus_id => $bonus ) {

			if ( $bonus['status'] != 'active' ) {
				unset( $bonuses[$bonus_id] );
			}

		}

		// Filter out bonuses that are not meant for this affiliate.
		$affiliate_group_id = slicewp_get_affiliate_group_id( $affiliate_id );

		foreach ( $bonuses as $bonus_id => $bonus ) {

			if ( empty( $bonus['availability_type'] ) ) {
				continue;
			}

			if ( $bonus['availability_type'] == 'exclude' && ( in_array( $affiliate_id, $bonus['availability_affiliate_id'] ) || in_array( $affiliate_group_id, $bonus['availability_affiliate_group_id'] ) ) ) {
				unset( $bonuses[$bonus_id] );
			}

			if ( $bonus['availability_type'] == 'include' && ( ! in_array( $affiliate_id, $bonus['availability_affiliate_id'] ) && ! in_array( $affiliate_group_id, $bonus['availability_affiliate_group_id'] ) ) ) {
				unset( $bonuses[$bonus_id] );
			}

		}

	}

	include_once 'views/view-affiliate-bonuses-progress.php';

}
add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', 'slicewp_output_view_affiliate_bonuses_progress', 15 );