<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * List table class outputter for bonus rewards.
 *
 */
Class SliceWP_WP_List_Table_Bonus_Rewards extends SliceWP_WP_List_Table {

	/**
	 * The number of rewards that should appear in the table.
	 *
	 * @access private
	 * @var int
	 *
	 */
	private $items_per_page;

	/**
	 * The data of the table.
	 *
	 * @access public
	 * @var array
	 *
	 */
	public $data = array();

	/**
	 * Constructor.
	 *
	 */
	public function __construct() {

		parent::__construct( array(
			'plural' 	=> 'slicewp_bonus_rewards',
			'singular' 	=> 'slicewp_bonus_reward',
			'ajax' 		=> false
		));

		$this->items_per_page = 10;
		$this->paged 		  = ( ! empty( $_GET['paged'] ) ? (int)$_GET['paged'] : 1 );

		$this->set_pagination_args( array(
            'total_items' => slicewp_get_bonus_rewards( array( 'number' => -1, 'search' => ( ! empty( $_GET['s'] ) ? $_GET['s'] : '' ), 'affiliate_id' => ( ! empty( $_GET['affiliate_id'] ) ? $_GET['affiliate_id'] : '' ), 'date_min' => ( ! empty ( $date_min ) ? get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ) : '' ), 'date_max' => ( ! empty( $date_max ) ? get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ) : '' ) ), true ),
 			'per_page'    => $this->items_per_page
        ));

		// Get and set table data.
		$this->set_table_data();
		
		// Add column headers and table items.
		$this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );
		$this->items 		   = $this->data;

	}


	/**
	 * Returns all the columns for the table.
	 *
	 */
	public function get_columns() {

		$columns = array(
            'id'           => __( 'ID', 'slicewp' ),
			'reward'       => __( 'Reward' , 'slicewp'),
            'affiliate'    => __( 'Affiliate', 'slicewp' ),
            'bonus'        => __( 'Bonus', 'slicewp' ),
            'target'       => __( 'Target', 'slicewp' ),
            'date_created' => __( 'Date', 'slicewp' ),
            'actions'      => ''
		);

		/**
		 * Filter the columns of the table.
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_bonus_rewards_columns', $columns );

	}


	/**
     * Returns the possible views for the bonus rewards list table.
     *
     */
    protected function get_views() {

        return array();

	}


    /**
	 * Get a list of CSS classes for the table tag.
	 *
	 * @return array
	 * 
	 */
	protected function get_table_classes() {

		return array( 'striped', $this->_args['plural'] );

	}

	
	/**
	 * Gets the bonus rewards data and sets it.
	 *
	 */
	private function set_table_data() {

        // Get the start date from the filter, or set it to the default value if not present.
		$date_min = ( ! empty( $_GET['date_min'] ) ? new DateTime( $_GET['date_min'] . ' 00:00:00' ) : '' );

		// Get the end date from the filter, or set it to the default value if not present.
		$date_max = ( ! empty( $_GET['date_max'] ) ? new DateTime( $_GET['date_max'] . ' 23:59:59') : '' );

		$rewards_args = array(
			'number'		=> $this->items_per_page,
			'offset'		=> ( $this->get_pagenum() - 1 ) * $this->items_per_page,
			'affiliate_id'	=> ( ! empty( $_GET['affiliate_id'] ) ? absint( $_GET['affiliate_id'] ) : '' ),
			'date_min'		=> ( ! empty( $date_min ) ? get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ) : '' ),
			'date_max'		=> ( ! empty( $date_max ) ? get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ) : '' ),
			'orderby'		=> ( ! empty( $_GET['orderby'] ) ? sanitize_text_field( $_GET['orderby'] ) : 'id' ),
			'order'			=> ( ! empty( $_GET['order'] ) ? sanitize_text_field( $_GET['order'] ) : 'desc' )
		);

		$rewards = slicewp_get_bonus_rewards( $rewards_args );
		
		if ( empty( $rewards ) ) {
			return;
		}

		foreach( $rewards as $reward ) {

			$row_data = $reward->to_array();

			/**
			 * Filter the bonus reward row data.
			 *
			 * @param array			       $row_data
			 * @param SliceWP_Bonus_Reward $reward
			 *
			 */
			$row_data = apply_filters( 'slicewp_list_table_bonus_rewards_row_data', $row_data, $reward );

			$this->data[] = $row_data;

		}
		
	}


	/**
	 * Returns the HTML that will be displayed in each columns.
	 *
	 * @param array  $item 			- data for the current row
	 * @param string $column_name 	- name of the current column
	 *
	 * @return string
	 *
	 */
	public function column_default( $item, $column_name ) {

		return isset( $item[ $column_name ] ) ? $item[ $column_name ] : '-';

	}


    /**
	 * Returns the HTML that will be displayed in the "reward" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_reward( $item ) {

		$output = '';

        if ( $item['type'] == 'commission' ) {

            $commission_id   = slicewp_get_bonus_reward_meta( $item['id'], '_commission_id', true );
            $commission_data = slicewp_get_bonus_reward_meta( $item['id'], '_commission_data', true );

            $output = '<div>';

                $output .= slicewp_get_svg( 'outline-cash' );

                $output .= '<div>';
                    $output .= '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-commissions', 'subpage' => 'edit-commission', 'commission_id' => absint( $commission_id ) ), 'admin.php' ) ) . '">';
                        $output .= slicewp_format_amount( $commission_data['amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
                        $output .= '<span>' . __( 'Fixed commission', 'slicewp' ) . '</span>';
                    $output .= '</a>';
                $output .= '</div>';

            $output .= '</div>';

        }

        if ( $item['type'] == 'store_credit' ) {

            $store_credit_data = slicewp_get_bonus_reward_meta( $item['id'], '_store_credit_data', true );

            $output = '<div>';

                $output .= slicewp_get_svg( 'outline-wallet' );

                $output .= '<div>';
                    $output .= slicewp_format_amount( $store_credit_data['amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
                    $output .= '<span>' . __( 'Store credit', 'slicewp' ) . '</span>';
                $output .= '</div>';

            $output .= '</div>';

        }

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "affiliate" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_affiliate( $item ) {

		$affiliate_name = slicewp_get_affiliate_name( $item['affiliate_id'] );

		if ( null === $affiliate_name ) {
			$output = __( '(inexistent affiliate)', 'slicewp' );
		} else {
			$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'subpage' => 'edit-affiliate', 'affiliate_id' => $item['affiliate_id'] ) , admin_url( 'admin.php' ) ) ) . '">' . $affiliate_name . '</a>';
		}

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "bonus" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_bonus( $item ) {

        $bonuses = array_filter( get_option( 'slicewp_performance_bonuses', array() ) );

        if ( ! empty( $bonuses[$item['bonus_id']] ) ) {

            $output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'subpage' => 'edit-performance-bonus', 'bonus_id' => absint( $item['bonus_id'] ) ), 'admin.php' ) ) . '">' . esc_html( $bonuses[$item['bonus_id']]['name'] ) . '</a>';

        } else {

            $bonus_data = slicewp_get_bonus_reward_meta( absint( $item['id'] ), '_bonus_data', true );

            $output = ( ! empty( $bonus_data['name'] ) ? $bonus_data['name'] : '-' );

        }

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "target" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_target( $item ) {

        $target_types = array(
            'referred_orders_count'  	=> __( 'Referred orders', 'slicewp' ),
            'referred_orders_totals' 	=> __( 'Referred orders total', 'slicewp' ),
			'earned_commissions_totals' => __( 'Earned commissions total' )
        );

        $target_data = slicewp_get_bonus_reward_meta( $item['id'], '_target_data', true );

        $output = '';

        if ( ! empty( $target_data ) && is_array( $target_data ) ) {

            $output .= ( in_array( $target_data['target_type'], array( 'referred_orders_totals', 'earned_commissions_totals' ) ) ? slicewp_format_amount( $target_data['target'], slicewp_get_setting( 'active_currency', 'USD' ) ) : $target_data['target'] );
            $output .= '<div>' . $target_types[$target_data['target_type']] . '</div>';

        }

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "date_created" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_date_created( $item ) {

		$output = slicewp_date_i18n( $item['date_created'] );

		return $output;

	}


    /**
	 * Returns the HTML that will be displayed in the "actions" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_actions( $item ) {

		/**
		 * Set row actions.
		 *
		 */
		$row_actions = array();

        if ( 'store_credit' == $item['type'] ) {
            $row_actions['delete'] = '<a class="slicewp-trash" onclick="return confirm( \'' . addslashes( __( "Are you sure you want to delete this bonus reward?", "slicewp" ) ) . '\n\n' . addslashes( __( "The store credit that has been rewarded to the affiliate will not be debited from the affiliate's balance by this action. You will need to manually adjust the affiliate's store credit balance." , "slicewp" ) ) . ' \' )" href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-bonus-rewards', 'slicewp_action' => 'delete_bonus_reward', 'bonus_reward_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_delete_bonus_reward', 'slicewp_token' ) ) . '">' . __( 'Delete', 'slicewp' ) . '</a>';
        }

        if ( 'commission' == $item['type'] ) {
            $row_actions['delete'] = '<a class="slicewp-trash" onclick="return confirm( \'' . addslashes( __( "Are you sure you want to delete this bonus reward?", "slicewp" ) ) . '\n\n' . addslashes( __( "The bonus commission that has been rewarded to the affiliate will not be deleted by this action. You will need to manually delete the bonus commission attached to this reward." , "slicewp" ) ) . ' \' )" href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-bonus-rewards', 'slicewp_action' => 'delete_bonus_reward', 'bonus_reward_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_delete_bonus_reward', 'slicewp_token' ) ) . '">' . __( 'Delete', 'slicewp' ) . '</a>';
        }

		/**
		 * Filter the row actions.
		 * 
		 * @param array $row_actions
		 * @param array $item
		 * 
		 */
		$row_actions = apply_filters( 'slicewp_list_table_bonus_rewards_row_actions', $row_actions, $item );

		$output = '<div class="row-actions">';

			$output .= '<a href="#" class="slicewp-button-toggle-actions"><svg class="" height="24" width="24" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M7 12c0 1.104-.896 2-2 2s-2-.896-2-2 .896-2 2-2 2 .896 2 2zm12-2c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2zm-7 0c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2z"></path></svg></a>';

			$output .= '<div class="slicewp-actions-dropdown">';
			
				foreach ( $row_actions as $row_action ) {

					if ( empty( $row_action ) ) {
						continue;
					}
					
					$output .= $row_action;

				}

			$output .= '</div>';

		$output .= '</div>';

		return $output;

	}


	/**
	 * HTML display when there are no items in the table.
	 *
	 */
	public function no_items() {

		echo __( 'No rewards found.', 'slicewp' );

	}


    /**
	 * Adds extra content to the table nav.
	 * 
	 * @param string $which
	 * 
	 */
	protected function extra_tablenav( $which ) {

		// Table ID.
		$table_id = str_replace( 'slicewp_', '', $this->_args['plural'] );

		// Add table data filters.
		if ( 'top' === $which ) {

			ob_start();

			?>

				<!-- Affiliate User ID -->
				<div class="slicewp-list-table-data-filter slicewp-list-table-data-filter-user-search">

					<label for="slicewp-list-table-data-filter-affiliate" class="screen-reader-text"><?php echo __( 'Affiliate', 'slicewp' ); ?></label>

					<?php slicewp_output_select2_user_search( array( 'id' => 'slicewp-affiliate-id', 'data_attributes' => array( 'container-class' => 'slicewp-select2-small' ), 'name' => 'affiliate_id', 'placeholder' => __( 'Select affiliate...', 'slicewp' ), 'user_type' => 'affiliate', 'value' => ( ! empty( $_GET['affiliate_id'] ) ? absint( $_GET['affiliate_id'] ) : '' ) ) ); ?>
					
				</div>

				<!-- Date Min -->
				<div class="slicewp-list-table-data-filter slicewp-list-table-data-filter-datepicker">

					<input type="text" name="date_min" class="slicewp-datepicker" autocomplete="off" placeholder="<?php echo __( 'From', 'slicewp' ); ?>" value="<?php echo ( ! empty( $_GET['date_min'] ) ? esc_attr( $_GET['date_min'] ) : '' )?>" />

				</div>

				<!-- Date Max -->
				<div class="slicewp-list-table-data-filter slicewp-list-table-data-filter-datepicker">

					<input type="text" name="date_max" class="slicewp-datepicker" autocomplete="off" placeholder="<?php echo __( 'To', 'slicewp' ); ?>" value="<?php echo ( ! empty( $_GET['date_max'] ) ? esc_attr( $_GET['date_max'] ) : '' )?>" />

				</div>

			<?php

			/**
			 * Action to add extra data filters.
			 * 
			 */
			do_action( "slicewp_list_table_{$table_id}_data_filters_output" );

			$output = ob_get_clean();

			if ( $output ) {

				echo '<div class="alignleft actions slicewp-list-table-data-filters" style="display: flex;">';

					// Output the filters.
					echo $output;

					// Output the filters submit button.
					echo '<button type="submit" class="slicewp-form-submit slicewp-spinner-inner slicewp-button-secondary"><span>' . __( 'Filter', 'slicewp' ) . '</span></button>';

					// Output reset link.
					echo '<a class="slicewp-list-table-data-filters-reset" style="display: none;" href="' . esc_url( remove_query_arg( array( 'paged' ) ) ) . '">' . __( 'Clear', 'slicewp' ) . '</a>';

				echo '</div>';

			}

		}

		/**
		 * Add extra functionality from the outside.
		 * 
		 * @param string $which
		 * 
		 */
		do_action( "slicewp_list_table_{$table_id}_extra_table_nav", $which );

	}

}