<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Validates and handles the deleting of a bonus reward from the database.
 *
 */
function slicewp_admin_action_delete_bonus_reward() {

	// Verify for nonce.
	if ( empty( $_GET['slicewp_token'] ) || ! wp_verify_nonce( $_GET['slicewp_token'], 'slicewp_delete_bonus_reward' ) ) {
		return;
	}

	// Verify for reward ID.
	if ( empty( $_GET['bonus_reward_id'] ) ) {
		return;
	}

	// Verify for bonus reward's existance.
	$bonus_reward_id = absint( $_GET['bonus_reward_id'] );
	$bonus_reward    = slicewp_get_bonus_reward( $bonus_reward_id );

	if ( is_null( $bonus_reward ) ) {
		return;
	}

	// Delete the bonus reward.
	$deleted = slicewp_delete_bonus_reward( $bonus_reward_id );

	if ( ! $deleted ) {

		slicewp_admin_notices()->register_notice( 'bonus_reward_delete_false', '<p>' . __( 'Something went wrong. Could not delete the bonus reward. Please try again.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'bonus_reward_delete_false' );

		return;

	}

    // Delete the reward's metadata
	$bonus_reward_meta = slicewp_get_bonus_reward_meta( $bonus_reward_id );

	if ( ! empty( $bonus_reward_meta ) ) {

		foreach( $bonus_reward_meta as $key => $value ) {

			slicewp_delete_bonus_reward_meta( $bonus_reward_id, $key );

		}

	}

	// Redirect to the current page.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-bonus-rewards', 'slicewp_message' => 'bonus_reward_delete_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_delete_bonus_reward', 'slicewp_admin_action_delete_bonus_reward', 50 );