<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Adds a new "Bonuses" tab in the affiliate account.
 *
 * @param array $tabs
 *
 * @return array
 *
 */
function slicewp_affiliate_account_tabs_bonuses( $tabs ) {

	$affiliate_id = slicewp_get_current_affiliate_id();

	// Get all bonuses available to the affiliate.
	$bonuses = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );

	if ( ! empty( $bonuses ) ) {

		// Filter out inactive bonuses.
		foreach ( $bonuses as $bonus_id => $bonus ) {

			if ( $bonus['status'] != 'active' ) {
				unset( $bonuses[$bonus_id] );
			}

		}

		// Filter out bonuses that are not meant for this affiliate.
		$affiliate_group_id = slicewp_get_affiliate_group_id( $affiliate_id );

		foreach ( $bonuses as $bonus_id => $bonus ) {

			if ( empty( $bonus['availability_type'] ) ) {
				continue;
			}

			if ( $bonus['availability_type'] == 'exclude' && ( in_array( $affiliate_id, $bonus['availability_affiliate_id'] ) || in_array( $affiliate_group_id, $bonus['availability_affiliate_group_id'] ) ) ) {
				unset( $bonuses[$bonus_id] );
			}

			if ( $bonus['availability_type'] == 'include' && ( ! in_array( $affiliate_id, $bonus['availability_affiliate_id'] ) && ! in_array( $affiliate_group_id, $bonus['availability_affiliate_group_id'] ) ) ) {
				unset( $bonuses[$bonus_id] );
			}

		}

	}

	// Get the rewards that were given to the affiliate.
	$rewards = slicewp_get_bonus_rewards( array( 'affiliate_id' => $affiliate_id ), true );

	// If no bonuses and no rewards are found, don't register the tab for this affiliate.
	if ( empty( $bonuses ) && empty( $rewards ) ) {
		return $tabs;
	}

	$tabs = array_merge( 
		array_slice( $tabs, 0, array_search( 'settings', array_keys( $tabs ) ) ),
		array( 
			'bonuses' => array(
				'label' => __( 'Bonuses', 'slicewp' ),
				'icon'  => slicewp_get_svg( 'outline-gift' )
			)),
		array_slice( $tabs, array_search( 'settings', array_keys( $tabs ) ), count( $tabs ) )
	);

	return $tabs;

}
add_filter( 'slicewp_affiliate_account_tabs', 'slicewp_affiliate_account_tabs_bonuses' );


/**
 * Outputs the affiliate coupon codes in the affiliate account page.
 *
 */
function slicewp_affiliate_account_tab_content_bonuses( $slug, $name, $templates, $args ) {

	if ( 'affiliate-area/affiliate-account-tab-bonuses' != $slug ) {
		return;
	}

    $outputter = new SliceWP_Outputter_Affiliate_Bonuses();
    $outputter->output();

	echo '<h3>' . __( 'Your rewards', 'slicewp' ) . '</h3>';

	$table = new SliceWP_List_Table_Affiliate_Account_Bonus_Rewards( array(
        'screen_base_url' => add_query_arg( array( 'affiliate-account-tab' => 'bonuses' ), strtok( set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] ), '?' ) )
    ));

    $table->output();

}
add_action( 'slicewp_get_template_part', 'slicewp_affiliate_account_tab_content_bonuses', 10, 4 );