<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add commission settings in download page
add_action( 'slicewp_mepr_metabox_commission_settings_bottom', 'slicewp_pcr_add_product_commission_settings_mepr', 10 );

// Save the product commission rate settings
add_action( 'save_post_memberpressproduct', 'slicewp_pcr_save_product_commission_settings_mepr', 15, 2 );

// Calculates the product commission amount
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_mepr', 15, 3 );


/**
 * Adds the product commission rate fields in MemberPress add/edit subscription page
 * 
 * 
 */
function slicewp_pcr_add_product_commission_settings_mepr() {
    
    // Get the commission types supported for Easy Digital Downloads
    $integration_commission_types = slicewp_get_integration_supports( 'mepr' )['commission_types'];    
    
    if ( empty( $integration_commission_types ) ) {
        return;
    }
    
    global $post;
            
    // Add the fields into an option group
    echo '<div class="slicewp-options-group slicewp-hide-if-disabled-commissions">';
            
        // Get the current product commission settings
        $commission_rate_type = get_post_meta( $post->ID, 'slicewp_commission_rate_type_subscription', true );
        $commission_rate      = get_post_meta( $post->ID, 'slicewp_commission_rate_subscription', true );

        ?>

        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-subscription">

            <label for="slicewp-product-commission-rate-type-subscription">
                <p>
                    <strong><?php echo __( 'Commission Rate Type:', 'slicewp' ); ?></strong>
                </p>
            </label>

            <select class="widefat" name="slicewp_commission_rate_type_subscription" id="slicewp-product-commission-rate-type-subscription">
                <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                <?php foreach( slicewp_get_commission_type_rate_types( 'subscription' ) as $rate_type => $rate_type_label ) : ?>
                    <option value="<?php echo esc_attr( $rate_type ); ?>" <?php selected( $commission_rate_type, $rate_type ); ?>><?php echo esc_html( $rate_type_label ); ?></option>
                <?php endforeach; ?>
            </select>

        </div>

        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-subscription">

            <label for="slicewp-product-commission-rate-subscription>">
                <p>
                    <strong><?php echo __( 'Commission Rate:', 'slicewp' ); ?></strong>
                </p>
            </label>

            <input class="widefat" type="text" name="slicewp_commission_rate_subscription" id="slicewp-product-commission-rate-subscription" value="<?php echo esc_attr( $commission_rate ); ?>">

        </div>

        <?php

    echo '</div>';

}


/**
 * Saves the subscription commission settings into the subscription meta
 * 
 * @param int $post_id
 * @param WP_Post $post
 * 
 */
function slicewp_pcr_save_product_commission_settings_mepr( $post_id, $post ) {

    // Update commission rate type
    if ( ! empty( $_POST['slicewp_commission_rate_type_subscription'] ) ) {

        update_post_meta( $post_id, 'slicewp_commission_rate_type_subscription', sanitize_text_field( $_POST['slicewp_commission_rate_type_subscription'] ) );

    } else {

        delete_post_meta( $post_id, 'slicewp_commission_rate_type_subscription' );

    }

    // Update commission rate
    if ( ! empty( $_POST['slicewp_commission_rate_subscription'] ) ) {

        update_post_meta( $post_id, 'slicewp_commission_rate_subscription', sanitize_text_field( $_POST['slicewp_commission_rate_subscription'] ) );

    } else {

        delete_post_meta( $post_id, 'slicewp_commission_rate_subscription' );

    }

}


/**
 * Calculates the product commission amount
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_mepr( $commission_amount, $amount, $args ) {

    // Check that the commission is from MemberPress
    if ( $args['origin'] != 'mepr' ) {
        return $commission_amount;
    }

    // Only subscriptions are treated here
    if ( $args['type'] != 'subscription' ) {
        return $commission_amount;
    }

    // Get the product id
    $product_id = absint( $args['product_id'] );

    // Get the product commission type and rate
    $commission_rate_type = get_post_meta( $product_id, 'slicewp_commission_rate_type_subscription', true );
    $commission_rate      = get_post_meta( $product_id, 'slicewp_commission_rate_subscription', true );

    // Check if the product commission type and rate are valid
    if ( ! empty( $commission_rate_type ) && ! empty( $commission_rate ) && is_numeric( $commission_rate ) ) {

        // Calculate the commission using the product type and rate
        $commission_amount = ( $commission_rate_type == 'percentage' ? round( ( $amount * $commission_rate / 100 ), 2 ) : $commission_rate );

    }

    // Nothing changed. Return the untouched commission amount.
    return $commission_amount;

}