<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add commission settings in product page
add_filter( 'slicewp_upsell_product_field_group_commission_settings_bottom', 'slicewp_pcr_add_product_commission_settings_upsell', 10, 2 );

// Calculates the product commission amount
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_upsell', 15, 3 );

/**
 * Adds the product commission rate fields in Upsell add/edit product page
 * 
 * @param array $fieldGroup
 * @param int $id
 * 
 */
function slicewp_pcr_add_product_commission_settings_upsell( $fieldGroup, $id ) {

    // Get the commission types supported for Upsell
    $integration_commission_types = slicewp_get_integration_supports( 'upsell' )['commission_types'];    
    
    if ( empty( $integration_commission_types ) ) {
		return;
	}
    
    // Get the comission types data
    $available_commission_types = slicewp_get_available_commission_types( true );

	// Parse all the integration commission types
	foreach ( $integration_commission_types as $commission_type ) {

		// Accept only supported commission types
		if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
			continue;
		}

		// Prepare the commission types for select field
		$rate_types[''] = __( 'General Settings Default', 'slicewp');

		foreach ( slicewp_get_commission_type_rate_types( $commission_type ) as $rate_type => $rate_type_label ) {
			$rate_types[$rate_type] = $rate_type_label;
		}

		// Add the commission rate type field
		$fields['slicewp_commission_rate_type' . $commission_type] = array(
			'key' => 'slicewp_commission_rate_type_' . $commission_type,
			'label' => sprintf( __( '%s Rate Type', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
			'name' => 'slicewp_commission_rate_type_' . $commission_type,
			'type' => 'select',
			'choices' => $rate_types,
			'instructions' => __( 'The selected commission rate type will be used to calculate the commission for this product.', 'slicewp' ),
			'required' => 0,
			'conditional_logic' => array(
					array(
						'field' => 'slicewp_disable_commissions',
						'operator' => '==',
						'value' => '0',
					),
					array(
						'field' => 'field_5cb6c00780eff',
						'operator' => '==',
						'value' => $commission_type == 'sale' ? 'single' : 'subscription',
					),
			),
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'message' => '',
			'default_value' => '',
			'ui' => 0,
			'ui_on_text' => '',
			'ui_off_text' => '',
		);

		// Add the commission rate field
		$fields['slicewp_commission_rate_' . $commission_type] = array(
			'key' => 'slicewp_commission_rate_' . $commission_type,
			'label' => sprintf( __( '%s Rate', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
			'name' => 'slicewp_commission_rate_' . $commission_type,
			'type' => 'number',
			'instructions' => __( 'This rate will be used to calculate the commission for this product.', 'slicewp' ),
			'required' => 0,
			'conditional_logic' => array(
					array(
						'field' => 'slicewp_commission_rate_type_' . $commission_type,
						'operator' => '!=',
						'value' => '',
					)
				),
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'message' => '',
			'ui' => 0,
			'ui_on_text' => '',
			'ui_off_text' => '',
		);

	}

	$fieldGroup['fields'] = array_merge( $fieldGroup['fields'], $fields );

	return $fieldGroup;

}


/**
 * Calculates the product commission amount
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_upsell( $commission_amount, $amount, $args ) {

    // Check that the commission is from Upsell
    if ( $args['origin'] != 'upsell' ) {
		return $commission_amount;
	}

    // Only sales and subscriptions are treated here
    if ( ! in_array( $args['type'], array( 'sale', 'subscription' ) ) ) {
		return $commission_amount;
	}

    // Check if the commission rate is per order
    if ( slicewp_is_commission_basis_per_order() ) {
		return $commission_amount;
	}

    // Get the product id
    $product_id = absint( $args['product_id'] );

    // Get the product commission type and rate
    $product_commission_rate_type = get_post_meta( $product_id, 'slicewp_commission_rate_type_' . $args['type'], true );
    $product_commission_rate      = get_post_meta( $product_id, 'slicewp_commission_rate_' . $args['type'], true );

    // Check if the product commission type and rate are valid
    if ( ! empty( $product_commission_rate_type ) && ! empty( $product_commission_rate ) && is_numeric( $product_commission_rate ) ) { 

        // Calculate the commission using the product type and rate
        $commission_amount = ( $product_commission_rate_type == 'percentage' ? round( ( $amount * $product_commission_rate / 100 ), 2 ) : $product_commission_rate );

        return $commission_amount;

    }

    // Nothing changed. Return the untouched commission amount.
    return $commission_amount;

}