<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Activates an API key.
 * 
 */
function slicewp_action_ajax_activate_api_key() {

	if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}
	
	if ( empty( $_REQUEST['api_key_id'] ) ) {
		wp_die( 0 );
	}

	$api_key_id = absint( $_REQUEST['api_key_id'] );

	// Bail early if the API key isn't found.
    $api_key = slicewp_get_api_key( $api_key_id );

	if ( is_null( $api_key ) ) {

		wp_send_json_error();

	}

	// If the API key is already active, return with success.
	if ( $api_key->get( 'status' ) == 'active' ) {

		wp_send_json_success();

	}

    $api_key_data = array(
        'status'        => 'active',
        'date_modified' => slicewp_mysql_gmdate()
    );

    $updated = slicewp_update_api_key( $api_key_id, $api_key_data );

	// Activate API key and return success/error.
	if ( $updated ) {

		wp_send_json_success();

	} else {

		wp_send_json_error();

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_activate_api_key', 'slicewp_action_ajax_activate_api_key' );


/**
 * Deactivates an API key.
 * 
 */
function slicewp_action_ajax_deactivate_api_key() {

	if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}
	
	if ( empty( $_REQUEST['api_key_id'] ) ) {
		wp_die( 0 );
	}

	$api_key_id = absint( $_REQUEST['api_key_id'] );

	// Bail early if the API key isn't found.
    $api_key = slicewp_get_api_key( $api_key_id );

	if ( is_null( $api_key ) ) {

		wp_send_json_error();

	}

	// If the API key is already inactive, return with success.
	if ( $api_key->get( 'status' ) == 'inactive' ) {

		wp_send_json_success();

	}

	$api_key_data = array(
        'status'        => 'inactive',
        'date_modified' => slicewp_mysql_gmdate()
    );

    $updated = slicewp_update_api_key( $api_key_id, $api_key_data );

	// Activate API key and return success/error.
	if ( $updated ) {

		wp_send_json_success();

	} else {

		wp_send_json_error();

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_deactivate_api_key', 'slicewp_action_ajax_deactivate_api_key' );


/**
 * Updates an API key.
 * 
 */
function slicewp_action_ajax_update_api_key() {

    if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}
	
	if ( empty( $_REQUEST['api_key_id'] ) ) {
		wp_die( 0 );
	}

	$api_key_id = absint( $_REQUEST['api_key_id'] );

	// Bail early if the API key isn't found.
    $api_key = slicewp_get_api_key( $api_key_id );

	if ( is_null( $api_key ) ) {
		wp_send_json_error( array( 'message' => __( 'API key does not exist.', 'slicewp' ) ) );
	}

    if ( empty( trim( $_REQUEST['api_key_name'] ) ) || empty( trim( $_REQUEST['api_key_permissions'] ) ) || empty( trim( $_REQUEST['api_key_user_id'] ) ) ) {
        wp_send_json_error( array( 'message' => __( 'Please fill in all the fields.', 'slicewp' ) ) );
    }

    // Check that the owner (user_id) is an admin.
    if ( ! user_can( absint( $_REQUEST['api_key_user_id'] ), 'manage_options' ) ) {
        wp_send_json_error( array( 'message' => __( 'Selected owner must be an administrator user.', 'slicewp' ) ) );
    }

    $api_key_data = array(
        'name'          => sanitize_text_field( $_REQUEST['api_key_name'] ),
        'user_id'       => absint( $_REQUEST['api_key_user_id'] ),
        'permissions'   => sanitize_text_field( $_REQUEST['api_key_permissions'] ),
        'date_modified' => slicewp_mysql_gmdate()
    );

    $updated = slicewp_update_api_key( $api_key_id, $api_key_data );

	// Activate API key and return success/error.
	if ( $updated ) {

		wp_send_json_success();

	} else {

		wp_send_json_error( array( 'message' => __( 'Something went wrong. Could not update API key data.', 'slicewp' ) ) );

	}

}
add_action( 'wp_ajax_slicewp_action_ajax_update_api_key', 'slicewp_action_ajax_update_api_key' );


/**
 * Deletes an API key.
 * 
 */
function slicewp_action_ajax_delete_api_key() {

    if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}
	
	if ( empty( $_REQUEST['api_key_id'] ) ) {
		wp_die( 0 );
	}

	$api_key_id = absint( $_REQUEST['api_key_id'] );

	// Bail early if the API key isn't found.
    $api_key = slicewp_get_api_key( $api_key_id );

	if ( is_null( $api_key ) ) {
		wp_die( 0 );
	}

    $deleted = slicewp_delete_api_key( $api_key_id );

    if ( $deleted ) {
        wp_send_json_success();
    }

    wp_die( 0 );

}
add_action( 'wp_ajax_slicewp_action_ajax_delete_api_key', 'slicewp_action_ajax_delete_api_key' );


/**
 * Generate new API key.
 * 
 */
function slicewp_action_ajax_generate_api_key() {

    if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die( 0 );
	}

    // Make sure all fields have been completed.
    if ( empty( trim( $_REQUEST['api_key_name'] ) ) || empty( trim( $_REQUEST['api_key_permissions'] ) ) || empty( trim( $_REQUEST['api_key_user_id'] ) ) ) {
        wp_send_json_error( array( 'message' => __( 'Please fill in all the fields.', 'slicewp' ) ) );
    }

    // Make sure the user exists and is administrator.
    $user = get_userdata( absint( $_REQUEST['api_key_user_id'] ) );

    if ( ! $user ) {
        wp_send_json_error( array( 'message' => __( 'Selected user does not exist.', 'slicewp' ) ) );
    }

    if ( ! in_array( 'administrator', $user->roles ) ) {
        wp_send_json_error( array( 'message' => __( 'Selected user does not have the needed capabilities. Please select an administrator user.', 'slicewp' ) ) );
    }

    // Generate keys.
    $consumer_key    = 'ck_' . _slicewp_generate_random_string( 30 );
    $consumer_secret = 'cs_' . _slicewp_generate_random_string( 30 );

    // Prepare API key data.
    $api_key_data = array(
        'name'            => sanitize_text_field( $_REQUEST['api_key_name'] ),
        'user_id'         => $user->ID,
        'permissions'     => sanitize_text_field( $_REQUEST['api_key_permissions'] ),
        'consumer_key'    => $consumer_key,
        'consumer_secret' => hash_hmac( 'sha256', $consumer_secret, 'slicewp-api' ),
        'status'          => 'active',
        'date_created'    => slicewp_mysql_gmdate(),
        'date_modified'   => slicewp_mysql_gmdate()
    );

    // Insert API key.
    $api_key_id = slicewp_insert_api_key( $api_key_data );

    if ( ! $api_key_id ) {
        wp_send_json_error( array( 'message' => __( 'Something went wrong. Could not generate API key.', 'slicewp' ) ) );
    }

    // Prepare HTML output
    ob_start();

    ?>

        <div class="slicewp-api-key-settings-wrapper slicewp-expandable-item slicewp-active" style="display: none;">

            <div class="slicewp-api-key-settings-header">

                <div class="slicewp-settings-api-key-name">

                    <div class="slicewp-switch slicewp-is-ajax">

                        <span class="slicewp-loader"></span>

                        <input id="slicewp-enable-api-key-<?php echo absint( $api_key_id ); ?>" class="slicewp-toggle slicewp-toggle-round" name="" type="checkbox" value="<?php echo absint( $api_key_id ); ?>" checked="checked" />
                        <label for="slicewp-enable-api-key-<?php echo absint( $api_key_id ); ?>"></label>

                    </div>

                    <span><?php echo $api_key_data['name']; ?></span>

                </div>

                <div class="slicewp-settings-api-key-consumer-key"><?php echo substr_replace( $consumer_key, '******', 5, strlen( $consumer_key ) - 10 ); ?></div>

                <div class="slicewp-settings-api-key-actions">
                    <a href="#" class="slicewp-expand-item"><?php echo __( 'Details', 'slicewp' ); ?><?php echo slicewp_get_svg( 'outline-chevron-down' ); ?></a>
                    <a href="#" class="slicewp-trash" data-confirmation-message="<?php echo __( 'Are you sure you want to delete this API key? Any integrations using it will stop working.', 'slicewp' ); ?>"><?php echo __( 'Delete', 'slicewp' ); ?></a>
                </div>

            </div>

            <div class="slicewp-api-key-settings-panel" style="display: block;">

                <div class="slicewp-field-notice slicewp-field-notice-warning" style="display: block; margin-top: 0; margin-bottom: 25px;"><?php echo sprintf( __( "For security reasons, %sthis is the only time the keys will ever be displayed%s! So please keep them safe and make sure you've copied them down.", 'slicewp' ), '<strong>', '</strong>' ); ?></div>

                <!-- API key ID -->
                <input type="hidden" data-name="api_key_id" value="<?php echo absint( $api_key_id ); ?>">

                <!-- API key consumer key -->
                <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                    <div class="slicewp-field-label-wrapper">
                        <label for="slicewp-api-key-consumer-key-<?php echo absint( $api_key_id ); ?>"><?php echo __( 'Consumer Key', 'slicewp' ); ?></label>
                    </div>

                    <input id="slicewp-api-key-consumer-key-<?php echo absint( $api_key_id ); ?>" type="text" value="<?php echo esc_attr( $consumer_key ); ?>" disabled />

                </div>
                <!-- / API key consumer key -->

                <!-- API key consumer secret -->
                <div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-last">

                    <div class="slicewp-field-label-wrapper">
                        <label for="slicewp-api-key-consumer-secret-<?php echo absint( $api_key_id ); ?>"><?php echo __( 'Consumer Secret', 'slicewp' ); ?></label>
                    </div>

                    <input id="slicewp-api-key-consumer-secret-<?php echo absint( $api_key_id ); ?>" type="text" value="<?php echo esc_attr( $consumer_secret ); ?>" disabled />

                </div>
                <!-- / API key consumer secret -->

            </div>

        </div>

    <?php

    $html = ob_get_contents();
    ob_end_clean();

    wp_send_json_success( array( 'html' => $html ) );

}
add_action( 'wp_ajax_slicewp_action_ajax_generate_api_key', 'slicewp_action_ajax_generate_api_key' );