<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * REST API controller for "affiliates".
 * 
 */
class SliceWP_REST_API_Controller_Affiliates extends SliceWP_REST_API_Controller {

    /**
	 * Route base.
	 *
	 * @var    string
     * @access protected
     * 
	 */
    protected $rest_base = 'affiliates';


    /**
     * Registers the routes.
     * 
     */
    public function register_routes() {

        // Get all affiliates.
        register_rest_route( $this->namespace, '/' . $this->rest_base, array(
			'methods' 			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_items' ),
			'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => $this->get_collection_params()
		));

        // Get single affiliate.
		register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
			'methods'			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_item' ),
			'permission_callback' => array( $this, 'permissions_check' ),
		));

        // Create single affiliate.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/', array(
            'methods'             => WP_REST_Server::CREATABLE,
            'callback'			  => array( $this, 'create_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'user_id' => array(
                    'description'       => __( 'The ID of the user that is attached to the affiliate.', 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'payment_email' => array(
                    'description'       => __( "The affiliate's payment email address", 'slicewp' ),
                    'type'              => 'string',
                    'format'            => 'email',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The affiliate's status.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'enum'              => array_keys( slicewp_get_affiliate_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'website' => array(
                    'description'       => __( "The affiliate's website.", 'slicewp' ),
                    'type'              => 'string',
                    'validate_callback' => array( $this, 'validate_request_arg_url' )
                ),
                'parent_id' => array(
                    'description'       => __( "The ID of the affiliate's parent affiliate.", 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'create_user' => array(
                    'description'       => __( 'Whether to create the user account for the affiliate or not.', 'slicewp' ),
                    'type'              => 'boolean',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'user_login' => array(
                    'description'       => __( 'The username that should be used to create the user account. Should be provided only when create_user argument is true.', 'slicewp' ),
                    'type'              => 'string',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'user_email' => array(
                    'description'       => __( 'The email address that should be used to create the user account. Should be provided only when create_user argument is true.', 'slicewp' ),
                    'type'              => 'string',
                    'format'            => 'email',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'user_first_name' => array(
                    'description'       => __( "The user's first name, value that should be used when creating the user account. Should be provided only when create_user argument is true.", 'slicewp' ),
                    'type'              => 'string',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'user_last_name' => array(
                    'description'       => __( "The user's last name, value that should be used when creating the user account. Should be provided only when create_user argument is true.", 'slicewp' ),
                    'type'              => 'string',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the affiliate', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Update single affiliate.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::EDITABLE,
            'callback'			  => array( $this, 'update_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'payment_email' => array(
                    'description'       => __( "The affiliate's payment email address", 'slicewp' ),
                    'type'              => 'string',
                    'format'            => 'email',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The affiliate's status.", 'slicewp' ),
                    'type'              => 'string',
                    'enum'              => array_keys( slicewp_get_affiliate_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'website' => array(
                    'description'       => __( "The affiliate's website.", 'slicewp' ),
                    'type'              => 'string',
                    'validate_callback' => array( $this, 'validate_request_arg_url' )
                ),
                'parent_id' => array(
                    'description'       => __( "The ID of the affiliate's parent affiliate.", 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the affiliate', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Delete single affiliate.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::DELETABLE,
            'callback'			  => array( $this, 'delete_item' ),
            'permission_callback' => array( $this, 'permissions_check' )
        ));

    }


    /**
     * Returns an array of affiliates data as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_items( $request ) {

        // Prepare query args.
        $args = array();

        foreach ( $request->get_params() as $key => $value ) {

            if ( in_array( $key, array_keys( $this->get_collection_params() ) ) ) {
                $args[$key] = $value;
            }

        }

        // Get affiliates.
        $affiliates = slicewp_get_affiliates( $args );

        foreach ( $affiliates as $key => $affiliate ) {

            $affiliate = (object)$affiliate->to_array();

            // Add default referral URL.
            $affiliate->default_referral_url = slicewp_get_affiliate_url( $affiliate->id );

            // Add user data.
            if ( ! is_null( $request->get_param( 'user' ) ) && filter_var( $request->get_param( 'user' ), FILTER_VALIDATE_BOOLEAN ) ) {

                $user = get_userdata( $affiliate->user_id );

                if ( $user ) {

                    $user_data = (array)$user->data;

                    // Unset the password and user activation keys.
                    unset( $user_data['user_pass'] );
                    unset( $user_data['user_activation_key'] );

                    // Add first name and last name.
                    $user_data = _slicewp_array_assoc_push_after_key( $user_data, 'user_nicename', array( 'first_name' => $user->first_name, 'last_name' => $user->last_name ) );

                    $affiliate->user = (object)$user_data;

                }

            }

            // Add affiliate meta.
            if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

                $affiliate->meta = slicewp_get_affiliate_meta( $affiliate->id );

            }

            $affiliates[$key] = $affiliate;

        }

        return rest_ensure_response( $affiliates );

    }


    /**
     * Returns the affiliate with the given ID as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_item( $request ) {

        $affiliate = slicewp_get_affiliate( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $affiliate ) ) {
            return new WP_Error( 'invalid_affiliate_id', 'Affiliate does not exist.', array( 'status' => 404 ) );
        }

        $affiliate = (object)$affiliate->to_array();

        // Add default referral URL.
        $affiliate->default_referral_url = slicewp_get_affiliate_url( $affiliate->id );

        // Add user data.
        if ( ! is_null( $request->get_param( 'user' ) ) && filter_var( $request->get_param( 'user' ), FILTER_VALIDATE_BOOLEAN ) ) {

            $user = get_userdata( $affiliate->user_id );

            if ( $user ) {

                $user_data = (array)$user->data;

                // Unset the password and user activation keys.
                unset( $user_data['user_pass'] );
                unset( $user_data['user_activation_key'] );

                // Add first name and last name.
                $user_data = _slicewp_array_assoc_push_after_key( $user_data, 'user_nicename', array( 'first_name' => $user->first_name, 'last_name' => $user->last_name ) );

                $affiliate->user = (object)$user_data;

            }

        }

        // Add affiliate meta.
        if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

            $affiliate->meta = slicewp_get_affiliate_meta( $affiliate->id );

        }

        return rest_ensure_response( $affiliate );

    }


    /**
     * Creates a new affiliate.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function create_item( $request ) {

        // Prepare item data.
        $affiliate_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to create object, return.
        if ( empty( $affiliate_data ) ) {
            return new WP_Error( 'affiliate_create_false', 'Did not create affiliate. No writable data provided.', array( 'status' => 400 ) );
        }

        $user_id = ( ! empty( $affiliate_data['user_id'] ) ? $affiliate_data['user_id'] : 0 );

        // If the user ID is provided, make sure it can be used.
        if ( ! empty( $user_id ) ) {

            // Make sure the provided user ID exists.
            if ( false === get_userdata( $user_id ) ) {
                return new WP_Error( 'affiliate_create_false', 'Did not create affiliate. Provided user ID does not exist.', array( 'status' => 400 ) );
            }

            // Make sure affiliate isn't already linked to the provided user ID.
            if ( ! is_null( slicewp_get_affiliate_by_user_id( $request->get_param( 'user_id' ) ) ) ) {
                return new WP_Error( 'affiliate_create_false', 'Did not create affiliate. Provided user ID is already linked to another affiliate.', array( 'status' => 400 ) );
            }

        } else {

            // Check if we need to create the user.
            if ( ! empty( $request->get_param( 'create_user' ) ) ) {

                // Make sure the email address is provided.
                if ( empty( $request->get_param( 'user_email' ) ) ) {
                    return new WP_Error( 'rest_missing_callback_param', 'Missing parameter(s): user_email', array( 'status' => 400, 'params' => 'user_email' ) );
                }

                $user_data = array(
                    'user_email' => sanitize_email( $request->get_param( 'user_email' ) ),
                    'user_login' => sanitize_user( ! empty( $request->get_param( 'user_login' ) ) ? $request->get_param( 'user_login' ) : $request->get_param( 'user_email' ) ),
                    'first_name' => sanitize_text_field( ! empty( $request->get_param( 'user_first_name' ) ) ? $request->get_param( 'user_first_name' ) : '' ),
                    'last_name'  => sanitize_text_field( ! empty( $request->get_param( 'user_last_name' ) ) ? $request->get_param( 'user_last_name' ) : '' ),
                    'user_pass'  => wp_generate_password( 30, false )
                );

                $user_id = wp_insert_user( $user_data );

                // Return if user could not be created.
                if ( is_wp_error( $user_id ) ) {

                    $user_id->add_data( array( 'status' => 400 ) );

                    return $user_id;

                }

            }

        }

        // Bail if we don't have a user_id by now.
        if ( empty( $user_id ) ) {
            return new WP_Error( 'affiliate_create_false', 'Did not create affiliate. No user account found to associate the affiliate to. Make sure you either create a user or specify a user_id that is valid.', array( 'status' => 400 ) );
        }

        // Add user_id to the data.
        $affiliate_data['user_id'] = $user_id;

        // Add dates.
        $affiliate_data['date_created']  = slicewp_mysql_gmdate();
        $affiliate_data['date_modified'] = slicewp_mysql_gmdate();

        // Insert the item.
        $inserted = slicewp_insert_affiliate( $affiliate_data );

        // If inserted, return item.
        if ( $inserted ) {

            $affiliate = slicewp_get_affiliate( $inserted );
            $affiliate = (object)$affiliate->to_array();

            // Add meta data.
            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $this->update_item_meta( $inserted, $request->get_param( 'meta_data' ) );

                $affiliate->meta = $this->prepare_item_meta_for_response( slicewp_get_affiliate_meta( $inserted ) );

            }

            return rest_ensure_response( $affiliate );

        }

        return new WP_Error( 'affiliate_create_false', 'Something went wrong. Could not create affiliate.', array( 'status' => 500 ) );

    }


    /**
     * Updates the affiliate with the given ID.
     * 
     * @todo Return errors when providing invalid properties.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function update_item( $request ) {
        
        $affiliate = slicewp_get_affiliate( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $affiliate ) ) {
            return new WP_Error( 'invalid_affiliate_id', 'Affiliate does not exist.', array( 'status' => 404 ) );
        }

        // Prepare item data.
        $affiliate_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to update, return.
        if ( empty( $affiliate_data ) && empty( $request->get_param( 'meta_data' ) ) ) {
            return new WP_Error( 'affiliate_update_false', 'Did not update affiliate. No writable data provided.', array( 'status' => 400 ) );
        }

        // Make sure user ID exists.
        if ( ! empty( $affiliate_data['user_id'] ) ) {

            if ( false === get_userdata( $affiliate_data['user_id'] ) ) {
                return new WP_Error( 'affiliate_update_false', 'Did not update affiliate. Provided user ID does not exist.', array( 'status' => 400 ) );
            }

        }

        // Update item.
        if ( ! empty( $affiliate_data ) ) {

            // Add date modified before updating.
            $affiliate_data['date_modified'] = slicewp_mysql_gmdate();

            $updated = slicewp_update_affiliate( $affiliate->get( 'id' ), $affiliate_data );

        }

        // Update item meta.
        if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

            $this->update_item_meta( $affiliate->get( 'id' ), $request->get_param( 'meta_data' ) );

            $updated = true;

        }

        // If updated, return item.
        if ( $updated ) {

            $affiliate = slicewp_get_affiliate( absint( $request->get_param( 'id' ) ) );
            $affiliate = (object)$affiliate->to_array();

            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $affiliate->meta = $this->prepare_item_meta_for_response( slicewp_get_affiliate_meta( absint( $affiliate->id ) ) );

            }

            return rest_ensure_response( $affiliate );

        }

        return new WP_Error( 'affiliate_update_false', 'Something went wrong. Could not update affiliate.', array( 'status' => 500 ) );

    }


    /**
     * Delete the affiliate with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function delete_item( $request ) {

        $affiliate = slicewp_get_affiliate( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $affiliate ) ) {
            return new WP_Error( 'invalid_affiliate_id', 'Affiliate does not exist.', array( 'status' => 404 ) );
        }

        // Add userdata to affiliate.
        $affiliate = (object)$affiliate->to_array();
        $user      = get_userdata( $affiliate->user_id );

        if ( $user ) {

            $user_data = $user->data;

            // Unset the password and user activation keys.
            unset( $user_data->user_pass );
            unset( $user_data->user_activation_key );

            $affiliate->user = $user_data;

        }

        // Add metadata to affiliate.
        $affiliate->meta = slicewp_get_affiliate_meta( $affiliate->id );

        // Delete affiliate.
        $deleted = slicewp_delete_affiliate( $affiliate->id );

        if ( $deleted ) {
            return rest_ensure_response( $affiliate );
        }

        return new WP_Error( 'affiliate_delete_false', 'Something went wrong. Could not delete affiliate.', array( 'status' => 500 ) );

    }


    /**
     * Filters and sanitizes the request data to prepare it for the database.
     * 
     * @param WP_REST_Request $request
     * 
     * @return array
     * 
     */
    protected function prepare_item_data_for_database( $request ) {

        $schema    = $this->get_item_schema();
        $data_keys = array_keys( array_filter( $schema['properties'], array( $this, 'filter_writable_properties' ) ) );

        $data = array();

        foreach ( $data_keys as $key ) {

            $value = $request->get_param( $key );

            if ( is_null( $value ) ) {
                continue;
            }

            if ( in_array( $key, array( 'user_id', 'parent_id' ) ) ) {
                $data[$key] = absint( $value );
            }

            if ( $key == 'payment_email' ) {
                $data[$key] = sanitize_email( $value );
            }

            if ( $key == 'website' ) {
                $data[$key] = esc_url_raw( $value );
            }

            if ( $key == 'status' ) {
                $data[$key] = sanitize_text_field( $value );
            }

        }

        return $data;

    }


    /**
     * Get the affiliate's schema, conforming to JSON Schema.
     * 
     * @return array
     * 
     */
    public function get_item_schema() {

        $schema = array(
            '$schema'    => 'http://json-schema.org/draft-04/schema#',
            'title'      => 'affiliate',
            'type'       => 'object',
            'properties' => array(
                'id' => array(
                    'description' => esc_html( __( 'Unique identifier for the object.', 'slicewp' ) ),
                    'type'        => 'integer',
                    'readonly'    => true
                ),
                'user_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the user that the affiliate is attached to.', 'slicewp' ) ),
                    'type'        => 'integer',
                ),
                'date_created' => array(
                    'description' => esc_html( __( 'The date at which the item was created, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                ),
                'date_modified' => array(
                    'description' => esc_html( __( 'The date at which the item was last modified, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                ),
                'payment_email' => array(
                    'description' => esc_html( __( 'The payment email address of the affiliate.', 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'website' => array(
                    'description' => esc_html( __( "The affiliate's default website.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'status' => array(
                    'description' => esc_html( __( "The affiliate's status.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'parent_id' => array(
                    'description' => esc_html( __( "The affiliate's parent ID.", 'slicewp' ) ),
                    'type'        => 'integer'
                )
            )
        );

        return $schema;

    }


    /**
     * Get the query params for collections.
     *
     * @return array
     * 
     */
    public function get_collection_params() {

        return array(
            'number' => array(
                'description'       => __( 'The number of items to query for. Use -1 to query for all.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => function( $param ) {
                    return (int)$param;
                },
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'offset' => array(
                'description'       => __( 'The number of items to offset the query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'user_id' => array(
                'description'       => __( 'The user ID to query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'status' => array(
                'description'       => __( 'The affiliate status to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_min' => array(
                'description'       => __( 'The minimum creation date of the affiliate to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_max' => array(
                'description'       => __( 'The maximum creation date of the affiliate to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'order' => array(
                'description'       => __( 'How to order the results. Use ASC for ascending order or DESC for descending order.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            )
        );

    }


    /**
     * Updates the meta data for the given item.
     * 
     * @param int   $item_id
     * @param array $meta_data
     * 
     */
    protected function update_item_meta( $item_id, $meta_data ) {

        // Sanitize array.
        $meta_data = _slicewp_array_wp_kses_post( $meta_data );

        foreach ( $meta_data as $key => $value ) {

            if ( ! is_string( $key ) ) {
                continue;
            }

            slicewp_update_affiliate_meta( absint( $item_id ), $key, $value );

        }

    }

}

new SliceWP_REST_API_Controller_Affiliates();