<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * REST API controller for "commissions".
 * 
 */
class SliceWP_REST_API_Controller_Commissions extends SliceWP_REST_API_Controller {

    /**
	 * Route base.
	 *
	 * @var    string
     * @access protected
     * 
	 */
    protected $rest_base = 'commissions';


    /**
     * Registers the routes.
     * 
     */
    public function register_routes() {

        // Get all commissions.
        register_rest_route( $this->namespace, '/' . $this->rest_base, array(
			'methods' 			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_items' ),
			'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => $this->get_collection_params()
		));

        // Get single commission.
		register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
			'methods'			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_item' ),
			'permission_callback' => array( $this, 'permissions_check' )
		));

        // Create single commission.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/', array(
            'methods'             => WP_REST_Server::CREATABLE,
            'callback'			  => array( $this, 'create_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'affiliate_id' => array(
                    'description'       => __( 'The ID of the affiliate that was rewarded the commission.', 'slicewp' ),
                    'type'              => 'integer',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'amount' => array(
                    'description'       => __( "The commission's amount.", 'slicewp' ),
                    'type'              => 'number',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'origin' => array(
                    'description'       => __( "The origin of the event that led to this commission's creation. Usually, this is the slug of the integration where the referred order was created.", 'slicewo' ),
                    'type'              => 'string',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'reference' => array(
                    'description'       => __( "The origin reference identifier. Usually, this value represents the referred order that led to this commission's creation.", 'slicewo' ),
                    'type'              => 'string',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'type' => array(
                    'description'       => __( "The commission's type.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'enum'              => array_keys( slicewp_get_commission_types() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The commission's status.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'enum'              => array_keys( slicewp_get_commission_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the commission', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Update single commission.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::EDITABLE,
            'callback'			  => array( $this, 'update_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'affiliate_id' => array(
                    'description'       => __( 'The ID of the affiliate that was rewarded the commission.', 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'amount' => array(
                    'description'       => __( "The commission's amount.", 'slicewp' ),
                    'type'              => 'number',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'type' => array(
                    'description'       => __( "The commission's type.", 'slicewp' ),
                    'type'              => 'string',
                    'enum'              => array_keys( slicewp_get_commission_types() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The commission's status.", 'slicewp' ),
                    'type'              => 'string',
                    'enum'              => array_keys( slicewp_get_commission_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the commission', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Delete single commission.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::DELETABLE,
            'callback'			  => array( $this, 'delete_item' ),
            'permission_callback' => array( $this, 'permissions_check' )
        ));

    }


    /**
     * Returns an array of commissions data as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_items( $request ) {

        // Prepare query args.
        $args = array();

        foreach ( $request->get_params() as $key => $value ) {

            if ( in_array( $key, array_keys( $this->get_collection_params() ) ) ) {
                $args[$key] = $value;
            }

        }

        // Get commissions.
        $commissions = slicewp_get_commissions( $args );

        foreach ( $commissions as $key => $commission ) {

            $commission = (object)$commission->to_array();

            // Add commission meta.
            if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

                $commission->meta = slicewp_get_commission_meta( $commission->id );

            }

            $commissions[$key] = $commission;

        }

        return rest_ensure_response( $commissions );

    }


    /**
     * Returns the commission with the given ID as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_item( $request ) {

        $commission = slicewp_get_commission( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $commission ) ) {
            return new WP_Error( 'invalid_commission_id', 'Commission does not exist.', array( 'status' => 404 ) );
        }

        $commission = (object)$commission->to_array();

        // Add commission meta.
        if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

            $commission->meta = slicewp_get_commission_meta( $commission->id );

        }

        return rest_ensure_response( $commission );

    }


    /**
     * Creates a new commission.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function create_item( $request ) {

        // Prepare item data.
        $commission_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to create object, return.
        if ( empty( $commission_data ) ) {
            return new WP_Error( 'commission_create_false', 'Did not create commission. No writable data provided.', array( 'status' => 400 ) );
        }

        // Check if there's a commission with the same origin and reference.
        $commissions = slicewp_get_commissions( array( 'number' => 1, 'origin' => $commission_data['origin'], 'reference' => $commission_data['reference'] ) );

        if ( ! empty( $commissions ) ) {
            return new WP_Error( 'commission_create_false', 'Did not create commission. A commission with the same origin and reference already exists.', array( 'status' => 400 ) );
        }

        // Add dates.
        $commission_data['date_created']  = slicewp_mysql_gmdate();
        $commission_data['date_modified'] = slicewp_mysql_gmdate();

        // Set the currency if it isn't set.
        if ( empty( $commission_data['currency'] ) ) {
            $commission_data['currency'] = slicewp_get_setting( 'active_currency', 'USD' );
        }

        // Insert the item.
        $inserted = slicewp_insert_commission( $commission_data );

        // If inserted, return item.
        if ( $inserted ) {

            $commission = slicewp_get_commission( $inserted );
            $commission = (object)$commission->to_array();

            // Add meta data.
            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $this->update_item_meta( $inserted, $request->get_param( 'meta_data' ) );

                $commission->meta = $this->prepare_item_meta_for_response( slicewp_get_commission_meta( $inserted ) );

            }

            return rest_ensure_response( $commission );

        }

        return new WP_Error( 'commission_create_false', 'Something went wrong. Could not create commission.', array( 'status' => 500 ) );

    }


    /**
     * Updates the commission with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function update_item( $request ) {
        
        $commission = slicewp_get_commission( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $commission ) ) {
            return new WP_Error( 'invalid_commission_id', 'Commission does not exist.', array( 'status' => 404 ) );
        }

        // Prepare item data.
        $commission_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to update, return.
        if ( empty( $commission_data ) && empty( $request->get_param( 'meta_data' ) ) ) {
            return new WP_Error( 'commission_update_false', 'Did not update commission. No writable data provided.', array( 'status' => 400 ) );
        }

        // Update item.
        if ( ! empty( $commission_data ) ) {

            // Add date modified before updating.
            $commission_data['date_modified'] = slicewp_mysql_gmdate();

            $updated = slicewp_update_commission( $commission->get( 'id' ), $commission_data );
            
        }

        // Update item meta.
        if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

            $this->update_item_meta( $commission->get( 'id' ), $request->get_param( 'meta_data' ) );

            $updated = true;

        }

        // If updated, return item.
        if ( $updated ) {

            $commission = slicewp_get_commission( absint( $request->get_param( 'id' ) ) );
            $commission = (object)$commission->to_array();

            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $commission->meta = $this->prepare_item_meta_for_response( slicewp_get_commission_meta( absint( $commission->id ) ) );

            }

            return rest_ensure_response( $commission );

        }

        return new WP_Error( 'commission_update_false', 'Something went wrong. Could not update commission.', array( 'status' => 500 ) );

    }


    /**
     * Delete the commission with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function delete_item( $request ) {

        $commission = slicewp_get_commission( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $commission ) ) {
            return new WP_Error( 'invalid_commission_id', 'Commission does not exist.', array( 'status' => 404 ) );
        }

        // Add metadata to commission.
        $commission       = (object)$commission->to_array();
        $commission->meta = slicewp_get_commission_meta( $commission->id );

        $deleted = slicewp_delete_commission( $commission->id );

        if ( $deleted ) {
            return rest_ensure_response( $commission );
        }

        return new WP_Error( 'commission_delete_false', 'Something went wrong. Could not delete commission.', array( 'status' => 500 ) );

    }


    /**
     * Filters and sanitizes the request data to prepare it for the database.
     * 
     * @param WP_REST_Request $request
     * 
     * @return array
     * 
     */
    protected function prepare_item_data_for_database( $request ) {

        $schema    = $this->get_item_schema();
        $data_keys = array_keys( array_filter( $schema['properties'], array( $this, 'filter_writable_properties' ) ) );

        $data = array();

        foreach ( $data_keys as $key ) {

            $value = $request->get_param( $key );

            if ( is_null( $value ) ) {
                continue;
            }

            if ( in_array( $key, array( 'affiliate_id', 'visit_id', 'customer_id', 'payment_id' ) ) ) {
                $data[$key] = absint( $value );
            }

            if ( in_array( $key, array( 'origin', 'reference', 'type', 'status', 'currency' ) ) ) {
                $data[$key] = sanitize_text_field( $value );
            }

            if ( in_array( $key, array( 'amount', 'reference_amount' ) ) ) {
                $data[$key] = slicewp_sanitize_amount( $value );
            }

        }

        return $data;

    }


    /**
     * Get the commissions's schema, conforming to JSON Schema.
     * 
     * @return array
     * 
     */
    public function get_item_schema() {

        $schema = array(
            '$schema'    => 'http://json-schema.org/draft-04/schema#',
            'title'      => 'commission',
            'type'       => 'object',
            'properties' => array(
                'id' => array(
                    'description' => esc_html( __( 'Unique identifier for the object.', 'slicewp' ) ),
                    'type'        => 'integer',
                    'readonly'    => true
                ),
                'affiliate_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the affiliate that received this commission.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'visit_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the visit that resulted into this commission being created.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'customer_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the referred customer attached to this commission.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'payment_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the payment this commission is included in.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'date_created' => array(
                    'description' => esc_html( __( 'The date at which the item was created, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                ),
                'date_modified' => array(
                    'description' => esc_html( __( 'The date at which the item was last modified, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                ),
                'amount' => array(
                    'description' => esc_html( __( "The commission's amount.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'origin' => array(
                    'description' => esc_html( __( "The origin of the event that led to this commission's creation. Usually, this is the slug of the integration where the referred order was created.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'reference' => array(
                    'description' => esc_html( __( "The origin reference identifier. Usually, this value represents the referred order that led to this commission's creation.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'reference_amount' => array(
                    'description' => esc_html( __( "The total amount from reference. Usually, this value represents the referred order's total amount.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'type' => array(
                    'description' => esc_html( __( "The commission's status.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'status' => array(
                    'description' => esc_html( __( "The commission's status.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'currency' => array(
                    'description' => esc_html( __( "The currency of the commission's amount.", 'slicewp' ) ),
                    'type'        => 'string'
                )
            )
        );

        return $schema;

    }


    /**
     * Get the query params for collections.
     *
     * @return array
     * 
     */
    public function get_collection_params() {

        return array(
            'number' => array(
                'description'       => __( 'The number of items to query for. Use -1 to query for all.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => function( $param ) {
                    return (int)$param;
                },
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'offset' => array(
                'description'       => __( 'The number of items to offset the query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'affiliate_id' => array(
                'description'       => __( 'The affiliate ID to query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'visit_id' => array(
                'description'       => __( 'The visit ID to query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'type' => array(
                'description'       => __( 'The commission type to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'status' => array(
                'description'       => __( 'The commission status to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'origin' => array(
                'description'       => __( 'The commission origin to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'reference' => array(
                'description'       => __( 'The commission reference to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_min' => array(
                'description'       => __( 'The minimum creation date of the commission to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_max' => array(
                'description'       => __( 'The maximum creation date of the commission to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'order' => array(
                'description'       => __( 'How to order the results. Use ASC for ascending order or DESC for descending order.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            )
        );

    }

    
    /**
     * Updates the meta data for the given item.
     * 
     * @param int   $item_id
     * @param array $meta_data
     * 
     */
    protected function update_item_meta( $item_id, $meta_data ) {

        // Sanitize array.
        $meta_data = _slicewp_array_wp_kses_post( $meta_data );

        foreach ( $meta_data as $key => $value ) {

            if ( ! is_string( $key ) ) {
                continue;
            }

            slicewp_update_commission_meta( absint( $item_id ), $key, $value );

        }

    }

}

new SliceWP_REST_API_Controller_Commissions();