<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * REST API controller for "payments".
 * 
 */
class SliceWP_REST_API_Controller_Payments extends SliceWP_REST_API_Controller {

    /**
	 * Route base.
	 *
	 * @var    string
     * @access protected
     * 
	 */
    protected $rest_base = 'payments';


    /**
     * Registers the routes.
     * 
     */
    public function register_routes() {

        // Get all payments.
        register_rest_route( $this->namespace, '/' . $this->rest_base, array(
			'methods' 			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_items' ),
			'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => $this->get_collection_params()
		));

        // Get single payment.
		register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
			'methods'			  => WP_REST_Server::READABLE,
			'callback'			  => array( $this, 'get_item' ),
			'permission_callback' => array( $this, 'permissions_check' )
		));

        // Create single payment.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/', array(
            'methods'             => WP_REST_Server::CREATABLE,
            'callback'			  => array( $this, 'create_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'affiliate_id' => array(
                    'description'       => __( 'The ID of the affiliate that was rewarded the payment.', 'slicewp' ),
                    'type'              => 'integer',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'payout_method' => array(
                    'description'       => __( "The payment's payout method.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'enum'              => array_keys( slicewp_get_payout_methods() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'amount' => array(
                    'description'       => __( "The payment's amount.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The payment's status.", 'slicewp' ),
                    'type'              => 'string',
                    'required'          => true,
                    'enum'              => array_keys( slicewp_get_payment_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'payout_id' => array(
                    'description'       => __( 'The ID of the bulk payout the payment is part of.', 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the payment', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Update single payment.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::EDITABLE,
            'callback'			  => array( $this, 'update_item' ),
            'permission_callback' => array( $this, 'permissions_check' ),
            'args'                => array(
                'affiliate_id' => array(
                    'description'       => __( 'The ID of the affiliate that was rewarded the payment.', 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'payout_method' => array(
                    'description'       => __( "The payment's payout method.", 'slicewp' ),
                    'type'              => 'string',
                    'enum'              => array_keys( slicewp_get_payout_methods() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'status' => array(
                    'description'       => __( "The payment's status.", 'slicewp' ),
                    'type'              => 'string',
                    'enum'              => array_keys( slicewp_get_payment_available_statuses() ),
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'payout_id' => array(
                    'description'       => __( 'The ID of the bulk payout the payment is part of.', 'slicewp' ),
                    'type'              => 'integer',
                    'validate_callback' => 'rest_validate_request_arg'
                ),
                'meta_data' => array(
                    'description'       => __( 'The meta data to add to the payment', 'slicewp' ),
                    'type'              => array( 'array', 'object' ),
                    'validate_callback' => 'rest_validate_request_arg'
                )
            )
        ));

        // Delete single payment.
        register_rest_route( $this->namespace, '/' . $this->rest_base . '/(?P<id>\d+)', array(
            'methods'             => WP_REST_Server::DELETABLE,
            'callback'			  => array( $this, 'delete_item' ),
            'permission_callback' => array( $this, 'permissions_check' )
        ));

    }


    /**
     * Returns an array of payments data as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_items( $request ) {

        // Prepare query args.
        $args = array();

        foreach ( $request->get_params() as $key => $value ) {

            if ( in_array( $key, array_keys( $this->get_collection_params() ) ) ) {
                $args[$key] = $value;
            }

        }

        // Get payments.
        $payments = slicewp_get_payments( $args );

        foreach ( $payments as $key => $payment ) {

            $payment = (object)$payment->to_array();

            // Add payment meta.
            if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

                $payment->meta = slicewp_get_payment_meta( $payment->id );

            }

            $payments[$key] = $payment;

        }

        return rest_ensure_response( $payments );

    }


    /**
     * Returns the payment with the given ID as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_item( $request ) {

        $payment = slicewp_get_payment( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $payment ) ) {
            return new WP_Error( 'invalid_payment_id', 'Payment does not exist.', array( 'status' => 404 ) );
        }

        $payment = (object)$payment->to_array();

        // Add payment meta.
        if ( ! is_null( $request->get_param( 'meta' ) ) && filter_var( $request->get_param( 'meta' ), FILTER_VALIDATE_BOOLEAN ) ) {

            $payment->meta = slicewp_get_payment_meta( $payment->id );

        }

        return rest_ensure_response( $payment );

    }


    /**
     * Creates a new payment.
     * 
     * @param WP_REST_Request $request
     *
     */
    public function create_item( $request ) {

        // Prepare item data.
        $payment_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to create object, return.
        if ( empty( $payment_data ) ) {
            return new WP_Error( 'payment_create_false', 'Did not create payment. No writable data provided.', array( 'status' => 400 ) );
        }

        // Add dates.
        $payment_data['date_created']  = slicewp_mysql_gmdate();
        $payment_data['date_modified'] = slicewp_mysql_gmdate();

        // Set the currency if it isn't set.
        if ( empty( $payment_data['currency'] ) ) {
            $payment_data['currency'] = slicewp_get_setting( 'active_currency', 'USD' );
        }

        // Insert the item.
        $inserted = slicewp_insert_payment( $payment_data );

        // If inserted, return item.
        if ( $inserted ) {

            $payment = slicewp_get_payment( $inserted );
            $payment = (object)$payment->to_array();

            // Add meta data.
            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $this->update_item_meta( $inserted, $request->get_param( 'meta_data' ) );

                $payment->meta = $this->prepare_item_meta_for_response( slicewp_get_payment_meta( $inserted ) );

            }

            return rest_ensure_response( $payment );

        }

        return new WP_Error( 'payment_create_false', 'Something went wrong. Could not create payment.', array( 'status' => 500 ) );

    }


    /**
     * Updates the payment with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function update_item( $request ) {
        
        $payment = slicewp_get_payment( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $payment ) ) {
            return new WP_Error( 'invalid_payment_id', 'Payment does not exist.', array( 'status' => 404 ) );
        }

        // Prepare item data.
        $payment_data = $this->prepare_item_data_for_database( $request );

        // If there's no data to update, return.
        if ( empty( $payment_data ) && empty( $request->get_param( 'meta_data' ) ) ) {
            return new WP_Error( 'payment_update_false', 'Did not update payment. No writable data provided.', array( 'status' => 400 ) );
        }

        // Update item.
        if ( ! empty( $payment_data ) ) {

            // Add date modified before updating.
            $payment_data['date_modified'] = slicewp_mysql_gmdate();

            $updated = slicewp_update_payment( $payment->get( 'id' ), $payment_data );
            
        }

        // Update item meta.
        if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

            $this->update_item_meta( $payment->get( 'id' ), $request->get_param( 'meta_data' ) );

            $updated = true;

        }

        // If updated, return item.
        if ( $updated ) {

            $payment = slicewp_get_payment( absint( $request->get_param( 'id' ) ) );
            $payment = (object)$payment->to_array();

            if ( ! empty( $request->get_param( 'meta_data' ) ) ) {

                $payment->meta = $this->prepare_item_meta_for_response( slicewp_get_payment_meta( absint( $payment->id ) ) );

            }

            return rest_ensure_response( $payment );

        }

        return new WP_Error( 'payment_update_false', 'Something went wrong. Could not update payment.', array( 'status' => 500 ) );

    }


    /**
     * Delete the payment with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function delete_item( $request ) {

        $payment = slicewp_get_payment( absint( $request->get_param( 'id' ) ) );

        if ( is_null( $payment ) ) {
            return new WP_Error( 'invalid_payment_id', 'Payment does not exist.', array( 'status' => 404 ) );
        }

        // Add metadata to payment.
        $payment       = (object)$payment->to_array();
        $payment->meta = slicewp_get_payment_meta( $payment->id );

        // Delete payment.
        $deleted = slicewp_delete_payment( $payment->id );

        if ( $deleted ) {
            return rest_ensure_response( $payment );
        }

        return new WP_Error( 'payment_delete_false', 'Something went wrong. Could not delete payment.', array( 'status' => 500 ) );

    }


    /**
     * Filters and sanitizes the request data to prepare it for the database.
     * 
     * @param WP_REST_Request $request
     * 
     * @return array
     * 
     */
    protected function prepare_item_data_for_database( $request ) {

        $schema    = $this->get_item_schema();
        $data_keys = array_keys( array_filter( $schema['properties'], array( $this, 'filter_writable_properties' ) ) );

        $data = array();

        foreach ( $data_keys as $key ) {

            $value = $request->get_param( $key );

            if ( is_null( $value ) ) {
                continue;
            }

            if ( in_array( $key, array( 'affiliate_id', 'payout_id', 'originator_user_id' ) ) ) {
                $data[$key] = absint( $value );
            }

            if ( in_array( $key, array( 'payout_method', 'currency', 'status' ) ) ) {
                $data[$key] = sanitize_text_field( $value );
            }

            if ( $key == 'amount' ) {
                $data[$key] = slicewp_sanitize_amount( $value );
            }

        }

        return $data;

    }


    /**
     * Get the payment's schema, conforming to JSON Schema.
     * 
     * @return array
     * 
     */
    public function get_item_schema() {

        $schema = array(
            '$schema'    => 'http://json-schema.org/draft-04/schema#',
            'title'      => 'payment',
            'type'       => 'object',
            'properties' => array(
                'id' => array(
                    'description' => esc_html( __( 'Unique identifier for the object.', 'slicewp' ) ),
                    'type'        => 'integer',
                    'readonly'    => true
                ),
                'affiliate_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the affiliate that the payment is destined to.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'payout_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the bulk payout that the payment is part of.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'originator_user_id' => array(
                    'description' => esc_html( __( 'The unique identifier of the user that generated the payment.', 'slicewp' ) ),
                    'type'        => 'integer'
                ),
                'amount' => array(
                    'description' => esc_html( __( "The payment's amount.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'currency' => array(
                    'description' => esc_html( __( "The payment's currency.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'payout_method' => array(
                    'description' => esc_html( __( "The payment's payout method.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'status' => array(
                    'description' => esc_html( __( "The payment's status.", 'slicewp' ) ),
                    'type'        => 'string'
                ),
                'date_created' => array(
                    'description' => esc_html( __( 'The date at which the item was created, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                ),
                'date_modified' => array(
                    'description' => esc_html( __( 'The date at which the item was last modified, in the GMT timezone.', 'slicewp' ) ),
                    'type'        => 'date-time',
                    'readonly'    => true
                )
            )
        );

        return $schema;

    }


    /**
     * Get the query params for collections.
     *
     * @return array
     * 
     */
    public function get_collection_params() {

        return array(
            'number' => array(
                'description'       => __( 'The number of items to query for. Use -1 to query for all.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => function( $param ) {
                    return (int)$param;
                },
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'offset' => array(
                'description'       => __( 'The number of items to offset the query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'affiliate_id' => array(
                'description'       => __( 'The affiliate ID to query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'payout_id' => array(
                'description'       => __( 'The payment payout ID to query by.', 'slicewp' ),
                'type'              => 'integer',
                'sanitize_callback' => 'absint',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'payout_method' => array(
                'description'       => __( 'The payment payout method to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'status' => array(
                'description'       => __( 'The payment status to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_min' => array(
                'description'       => __( 'The minimum creation date of the payment to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'date_max' => array(
                'description'       => __( 'The maximum creation date of the payment to query by.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            ),
            'order' => array(
                'description'       => __( 'How to order the results. Use ASC for ascending order or DESC for descending order.', 'slicewp' ),
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'validate_callback' => 'rest_validate_request_arg'
            )
        );

    }


    /**
     * Updates the meta data for the given item.
     * 
     * @param int   $item_id
     * @param array $meta_data
     * 
     */
    protected function update_item_meta( $item_id, $meta_data ) {

        // Sanitize array.
        $meta_data = _slicewp_array_wp_kses_post( $meta_data );

        foreach ( $meta_data as $key => $value ) {

            if ( ! is_string( $key ) ) {
                continue;
            }

            slicewp_update_payment_meta( absint( $item_id ), $key, $value );

        }

    }

}

new SliceWP_REST_API_Controller_Payments();