<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * List table class outputter for Affiliate Groups.
 *
 */
Class SliceWP_WP_List_Table_Affiliate_Groups extends SliceWP_WP_List_Table {

	/**
	 * The number of affiliate groups that should appear in the table.
	 *
	 * @access private
	 * @var int
	 *
	 */
	private $items_per_page;

	/**
	 * The data of the table.
	 *
	 * @access public
	 * @var array
	 *
	 */
	public $data = array();


	/**
	 * Constructor.
	 *
	 */
	public function __construct() {

		parent::__construct( array(
			'plural' 	=> 'slicewp_affiliate_groups',
			'singular' 	=> 'slicewp_affiliate_group',
			'ajax' 		=> false
		));

		$this->items_per_page = 99999;
		$this->paged 		  = ( ! empty( $_GET['paged'] ) ? (int)$_GET['paged'] : 1 );

		// Get and set table data.
		$this->set_table_data();
		
		// Add column headers and table items.
		$this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );
		$this->items 		   = $this->data;

	}


	/**
	 * Get a list of CSS classes for the table tag.
	 *
	 * @return array
	 * 
	 */
	protected function get_table_classes() {

		return array( 'striped', $this->_args['plural'] );

	}


	/**
	 * Get an associative array ( option_name => option_title ) with the list
	 * of bulk actions available on this table.
	 * 
	 * @return array
	 * 
	 */
	protected function get_bulk_actions() {

		$actions = array(
			'delete' => __( 'Delete', 'slicewp' )
		);

		/**
		 * Filter the bulk actions for this table.
		 * 
		 */
		return apply_filters( 'slicewp_list_table_affiliate_groups_bulk_actions', $actions );

	}


	/**
	 * Returns all the columns for the table.
	 *
	 */
	public function get_columns() {

		$columns = array(
			'cb'				 => 'cb',
			'name'		    	 => __( 'Name', 'slicewp' ),
            'description'        => __( 'Description', 'slicewp' ),
			'affiliates'		 => __( 'Affiliates', 'slicewp' ),
			'notes'				 => '<span class="dashicons dashicons-admin-comments" title="' . __( 'Notes', 'slicewp' ) . '"></span>',
			'actions'			 => ''
		);

		/**
		 * Filter the columns of the affiliate groups table.
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_affiliate_groups_columns', $columns );

	}


	/**
	 * Returns all the sortable columns for the table.
	 *
	 */
	public function get_sortable_columns() {

		$columns = array();

		/**
		 * Filter the sortable columns of the affiliate groups table.
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_affiliate_groups_sortable_columns', $columns );

	}


	/**
     * Returns the possible views for the affiliate groups list table.
     *
     */
    protected function get_views() {

    	// Set the view for "all" affiliate groups.
    	$views = array();

		/**
		 * Filter the views of the affiliate groups table.
		 *
		 * @param array $views
		 *
		 */
		return apply_filters( 'slicewp_list_table_affiliate_groups_views', $views );

    }


	/**
	 * Gets the affiliate groups data and sets it.
	 *
	 */
	private function set_table_data() {

		$query_args = array(
			'number'         => -1,
            'object_context' => 'affiliate',
            'type'           => 'group',
			'orderby'        => ( ! empty( $_GET['orderby'] ) ? sanitize_text_field( $_GET['orderby'] ) : 'id' ),
			'order'	         => ( ! empty( $_GET['order'] ) ? sanitize_text_field( $_GET['order'] ) : 'desc' )
		);

		$affiliate_groups = slicewp_get_collections( $query_args );

		if ( empty( $affiliate_groups ) ) {
			return;
		}

		foreach ( $affiliate_groups as $affiliate_group ) {

			$row_data = $affiliate_group->to_array();

            $row_data['description'] = slicewp_get_collection_meta( $affiliate_group->get( 'id' ), '_description', true );

			/**
			 * Filter the affiliate group row data.
			 *
			 * @param array 		     $row_data
			 * @param SliceWP_Collection $affiliate_group
			 *
			 */
			$row_data = apply_filters( 'slicewp_list_table_affiliate_groups_row_data', $row_data, $affiliate_group );

			$this->data[] = $row_data;

		}
		
	}


	/**
	 * Returns the HTML that will be displayed in the "cb" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_cb( $item ) {

		return sprintf( '<input type="checkbox" name="affiliate_group_ids[]" value="%1$s" />', absint( $item['id'] ) );

	}


	/**
	 * Returns the HTML that will be displayed in each columns.
	 *
	 * @param array $item 			- data for the current row
	 * @param string $column_name 	- name of the current column
	 *
	 * @return string
	 *
	 */
	public function column_default( $item, $column_name ) {

		return isset( $item[ $column_name ] ) ? $item[ $column_name ] : '-';

	}


	/**
	 * Returns the HTML that will be displayed in the "name" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_name( $item ) {

        $output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliate-groups', 'subpage' => 'edit-affiliate-group', 'affiliate_group_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ) ) . '">' . esc_html( $item['name'] ) . '</a>';

        if ( $item['id'] == slicewp_get_setting( 'default_affiliate_group' ) ) {
            $output .= ' — ' . __( 'Default', 'slicewp' );
        }

		return $output;

	}


    /**
     * Returns the HTML that will be displayed in the "description" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
     * 
     */
    public function column_description( $item ) {

        $output = ( ! empty( $item['description'] ) ? force_balance_tags( html_entity_decode( wp_trim_words( htmlentities( wpautop( $item['description'] ) ), 25 ) ) ) : '-' );

        return $output;

    }


    /**
     * Returns the HTML that will be displayed in the "affiliates" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
     * 
     */
    public function column_affiliates( $item ) {

        $query_args = array(
            'collections' => array(
                array( 'in', 'collection_id', absint( $item['id'] ) )
            )
        );

        $affiliates_count = slicewp_get_affiliates( $query_args, true );

        if ( ! empty( $affiliates_count ) ) {
            $output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'affiliate_group_id' => absint( $item['id'] ) ), 'admin.php' ) ) . '">' . $affiliates_count . '</a>';
        } else {
            $output = $affiliates_count;
        }

        return $output;

    }


	/**
	 * Returns the HTML that will be displayed in the "notes" column.
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_notes( $item ) {

		$notes_count = slicewp_get_notes( array( 'object_context' => 'collection', 'object_id' => $item['id'] ), true );

		if ( empty( $notes_count ) ) {
            return '-';
        }

		$output = '<span class="slicewp-notes-count">' . absint( $notes_count ) . '</span>';

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "actions" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_actions( $item ) {

        /**
         * @todo - When deleting an affiliate group, if there are affiliates in the group, a pop-up should appear
         *         letting the admin know this, and asking whether these affiliates should be added to another group or not.
         *       - If the admin selects to add the affiliates to another group, add these affiliates to the selected group.
         *         We may need to bulk process this, just to make sure the system does not break.
         * 
         */

		/**
		 * Set row actions.
		 *
		 */
		$row_actions = array(
            'make_default' => ( $item['id'] != slicewp_get_setting( 'default_affiliate_group' ) ? '<a onclick="return confirm( \'' . __( "Are you sure you want to make this group the default one? New affiliates will be added to this group going forward.", "slicewp" ) . ' \' )" href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-affiliate-groups', 'slicewp_action' => 'make_affiliate_group_default', 'affiliate_group_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_make_affiliate_group_default', 'slicewp_token' ) ) . '">' . __( 'Make default', 'slicewp' ) . '</a>' : '' ),
			'delete'       => '<a class="slicewp-trash" onclick="return confirm( \'' . __( "Are you sure you want to delete this affiliate group? All affiliates from this group will no longer be in any group.", "slicewp" ) . ' \' )" href="' . esc_url( wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-affiliate-groups', 'slicewp_action' => 'delete_affiliate_group', 'affiliate_group_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ), 'slicewp_delete_affiliate_group', 'slicewp_token' ) ) . '">' . __( 'Delete', 'slicewp' ) . '</a>'
		);

        $row_actions = array_filter( $row_actions );

		/**
		 * Filter the row actions.
		 * 
		 * @param array $row_actions
		 * @param array $item
		 * 
		 */
		$row_actions = apply_filters( 'slicewp_list_table_affiliate_groups_row_actions', $row_actions, $item );

		$output = '<div class="row-actions">';

			$output .= '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliate-groups', 'subpage' => 'edit-affiliate-group', 'affiliate_group_id' => absint( $item['id'] ) ) , admin_url( 'admin.php' ) ) ) . '" class="slicewp-button-secondary">' . __( 'Edit', 'slicewp' ) . '</a>';
			
			$output .= '<a href="#" class="slicewp-button-toggle-actions"><svg class="" height="24" width="24" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><path d="M7 12c0 1.104-.896 2-2 2s-2-.896-2-2 .896-2 2-2 2 .896 2 2zm12-2c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2zm-7 0c-1.104 0-2 .896-2 2s.896 2 2 2 2-.896 2-2-.896-2-2-2z"></path></svg></a>';

			$output .= '<div class="slicewp-actions-dropdown">';
			
				foreach ( $row_actions as $row_action ) {

					if ( empty( $row_action ) ) {
						continue;
					}
					
					$output .= $row_action;

				}

			$output .= '</div>';

		$output .= '</div>';

		return $output;

	}


	/**
	 * HTML display when there are no items in the table.
	 *
	 */
	public function no_items() {

		echo __( 'No affiliate groups found.', 'slicewp' );

	}


	/**
	 * Adds extra content to the table nav.
	 * 
	 * @param string $which
	 * 
	 */
	protected function extra_tablenav( $which ) {

        /**
         * @todo - When bulk deleting affiliate groups, if there are affiliates in a certain group, a pop-up should appear
         *         letting the admin know this, and asking whether these affiliates should be added to another group or not.
         *       - If the admin selects to add the affiliates to another group, add these affiliates to the selected group.
         *         We may need to bulk process this, just to make sure the system does not break.
         * 
         */

		if ( 'bottom' !== $which ) {
			return;
		}

		?>

			<script>

				var selector_top    = document.getElementById( 'bulk-action-selector-top' );
				var selector_bottom = document.getElementById( 'bulk-action-selector-bottom' );

				if ( selector_top ) {
					selector_top.querySelector( 'option[value="delete"]' ).setAttribute( 'data-confirmation-message', "<?php echo esc_attr( __( 'Are you sure you want to delete the selected affiliate group(s)? All affiliates from these groups will no longer be in a group.', 'slicewp' ) ); ?>" );
				}

				if ( selector_bottom ) {
					selector_bottom.querySelector( 'option[value="delete"]' ).setAttribute( 'data-confirmation-message', "<?php echo esc_attr( __( 'Are you sure you want to delete the selected affiliate group(s)? All affiliates from these groups will no longer be in a group.', 'slicewp' ) ); ?>" );
				}

			</script>

		<?php

	}

}