<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Register the Affiliate Groups admin submenu page.
 * 
 * @param array $submenu_pages
 * 
 * @return array
 *
 */
function slicewp_register_submenu_page_affiliate_groups( $submenu_pages ) {

    if ( empty( $_GET['page'] ) ) {
        return $submenu_pages;
    }

    if ( ! in_array( $_GET['page'], array( 'slicewp-affiliates', 'slicewp-affiliate-groups' ) ) ) {
        return $submenu_pages;
    }

	if ( ! is_array( $submenu_pages ) ) {
		return $submenu_pages;
	}

	$submenu_pages['affiliate_groups'] = array(
		'class_name' => 'SliceWP_Submenu_Page_Affiliate_Groups',
		'data' 		 => array(
			'page_title' => __( 'Groups', 'slicewp' ),
			'menu_title' => '<svg xmlns="http://www.w3.org/2000/svg" width="15" height="15" viewBox="0 0 20 20"><path fill="currentColor" d="M10.72 16.78a.75.75 0 0 0 1.06 0l4-4a.75.75 0 0 0 0-1.06l-4-4a.75.75 0 1 0-1.06 1.06l2.72 2.72H7A1.5 1.5 0 0 1 5.5 10V3.75a.75.75 0 0 0-1.5 0V10a3 3 0 0 0 3 3h6.44l-2.72 2.72a.75.75 0 0 0 0 1.06Z"></path></svg>' . __( 'Groups', 'slicewp' ),
			'capability' => apply_filters( 'slicewp_submenu_page_capability_affiliate_groups', 'manage_options' ),
			'menu_slug'  => 'slicewp-affiliate-groups'
		)
	);

	return $submenu_pages;

}
add_filter( 'slicewp_register_submenu_page', 'slicewp_register_submenu_page_affiliate_groups', 20 );


/**
 * Sets globals for affiliate groups.
 * 
 */
function slicewp_admin_init_set_globals_affiliate_groups() {

    if ( empty( $_GET['page'] ) || $_GET['page'] != 'slicewp-affiliates' ) {
        return;
    }

    $collections_count = slicewp_get_collections( array( 'object_context' => 'affiliate', 'type' => 'group' ), true );

    slicewp()->globals()->set( 'affiliate_groups_count', $collections_count );

}
add_action( 'admin_init', 'slicewp_admin_init_set_globals_affiliate_groups' );


/**
 * Registers the "Manage Groups" page title action on the "Affiliates" admin page.
 * 
 */
function slicewp_register_page_title_actions_affiliates() {

	if ( ! method_exists( slicewp()->submenu_pages['slicewp-affiliates'], 'set' ) ) {
		return;
	}

	if ( empty( slicewp()->submenu_pages['slicewp-affiliate-groups'] ) ) {
		return;
	}

	if ( ! empty( $_GET['subpage'] ) ) {
		return;
	}

	$title_actions 	 = slicewp()->submenu_pages['slicewp-affiliates']->get( 'title_actions' );
	$title_actions[] = '<a href="' . esc_url( slicewp()->submenu_pages['slicewp-affiliate-groups']->get( 'admin_url' ) ) . '" class="page-title-action">' . __( 'Manage Groups', 'slicewp' ) . '</a>';

	slicewp()->submenu_pages['slicewp-affiliates']->set( 'title_actions', $title_actions );

}
add_action( 'admin_menu', 'slicewp_register_page_title_actions_affiliates', 200 );


/**
 * Register the "Group" column in the "Affiliates" admin list table.
 * 
 * @param array $columns
 * 
 * @return array
 * 
 */
function slicewp_list_table_affiliates_columns_register_affiliate_group( $columns ) {

	if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
		return $columns;
	}

	$columns = _slicewp_array_assoc_push_after_key( $columns, 'name', array( 'group' => __( 'Group', 'slicewp' ) ) );

	return $columns;

}
add_filter( 'slicewp_list_table_affiliates_columns', 'slicewp_list_table_affiliates_columns_register_affiliate_group', 25 );


/**
 * Output for the "Group" column in the "Affiliates" admin list table.
 * 
 * @param string $output
 * @param array  $item
 * 
 * @return string
 * 
 */
function slicewp_list_table_affiliates_column_group_output( $output, $item ) {

	$affiliate_group = slicewp_get_affiliate_group( absint( $item['id'] ) );

	if ( is_null( $affiliate_group ) ) {
		return $output;
	}

	$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'affiliate_group_id' => absint( $affiliate_group->get( 'id' ) ) ), 'admin.php' ) ) . '">' . $affiliate_group->get( 'name' ) . '</a>';

	return $output;

}
add_filter( 'slicewp_list_table_affiliates_column_group', 'slicewp_list_table_affiliates_column_group_output', 25, 2 );


/**
 * Adds the "Default affiliate group" selector in the "General Settings" card of the plugin's main settings page.
 * 
 */
function slicewp_view_settings_section_general_settings_bottom_default_affiliate_group() {

	$affiliate_groups = slicewp_get_collections( array( 'number' => -1, 'object_context' => 'affiliate', 'type' => 'group' ) );

	?>

		<div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-tooltip-wide">

			<div class="slicewp-field-label-wrapper">
				<label for="slicewp-default-affiliate-group">
					<?php echo __( 'Default Affiliate Group', 'slicewp' ); ?>
					<?php echo slicewp_output_tooltip( __( "Select the default group you want new affiliates to be added to upon registration." , 'slicewp' ) ); ?>
				</label>
			</div>

			<select class="slicewp-select2" name="settings[default_affiliate_group]">

				<option value=""><?php echo __( 'Select...', 'slicewp' ); ?></option>

				<?php foreach ( $affiliate_groups as $key => $collection ): ?>
					<option value="<?php echo absint( $collection->get( 'id' ) ); ?>" <?php echo selected( ( ! empty( $_POST['settings']['default_affiliate_group'] ) ? $_POST['settings']['default_affiliate_group'] : ( empty( $_POST ) ? slicewp_get_setting( 'default_affiliate_group' ) : '' ) ) , $collection->get( 'id' ) ); ?>><?php echo $collection->get( 'name' ); ?></option>
				<?php endforeach; ?>

			</select>

		</div>

	<?php

}
add_action( 'slicewp_view_settings_section_general_settings_bottom', 'slicewp_view_settings_section_general_settings_bottom_default_affiliate_group' );


/**
 * Include the affiliate group field in the admin affiliate add/edit forms.
 * 
 * @param string $form
 * 
 */
function slicewp_affiliate_form_field_affiliate_group( $form ) {

    if ( ! in_array( $form, array( 'add_affiliate', 'edit_affiliate' ) ) ) {
		return;
	}

    // Bail if there aren't any affiliate groups.
    if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
        return;
    }

	$affiliate_groups  = slicewp_get_collections( array( 'number' => -1, 'object_context' => 'affiliate', 'type' => 'group' ) );
	$selected_group_id = ( $form == 'add_affiliate' ? slicewp_get_setting( 'default_affiliate_group', 0 ) : slicewp_get_affiliate_group_id( ( ! empty( $_GET['affiliate_id'] ) ? absint( $_GET['affiliate_id'] ) : 0 ) ) );

    ?>

		<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

			<div class="slicewp-field-label-wrapper">
				<label for="slicewp-affiliate-group"><?php echo __( 'Group', 'slicewp' ); ?></label>
				<?php echo slicewp_output_tooltip( __( "The group this affiliate belongs to.", 'slicewp' ) ); ?>
			</div>

			<select id="slicewp-affiliate-group" class="slicewp-select2" name="affiliate_group">

				<option value=""><?php echo __( 'Select...', 'slicewp' ); ?></option>

				<?php foreach ( $affiliate_groups as $key => $collection ): ?>
					<option value="<?php echo absint( $collection->get( 'id' ) ); ?>" <?php echo selected( ( ! empty( $_POST['affiliate_group'] ) ? $_POST['affiliate_group'] : ( empty( $_POST ) ? $selected_group_id : '' ) ), $collection->get( 'id' ) ); ?>><?php echo $collection->get( 'name' ); ?></option>
				<?php endforeach; ?>

			</select>

		</div>

	<?php

}
add_action( 'slicewp_admin_form_fields', 'slicewp_affiliate_form_field_affiliate_group', 100 );


/**
 * Save the affiliate group when adding/updating the affiliate.
 * 
 * @param int $affiliate_id
 * 
 */
function slicewp_admin_action_insert_update_affiliate_set_affiliate_group( $affiliate_id ) {

	if ( ! is_admin() ) {
		return;
	}
	
	// Bail if the action isn't "add_affiliate" or "update_affiliate".
    if ( ! slicewp_verify_request_action( 'add_affiliate' ) && ! slicewp_verify_request_action( 'update_affiliate' ) ) {
        return;
    }

	$affiliate_group_id = ( ! empty( $_POST['affiliate_group'] ) ? absint( $_POST['affiliate_group'] ) : 0 );

	if ( ! empty( $affiliate_group_id ) ) {

		// Make sure the collection exists and is valid.
		$collection = slicewp_get_collection( $affiliate_group_id );

		if ( ! is_null( $collection ) && $collection->get( 'object_context' ) == 'affiliate' && $collection->get( 'type' ) == 'group' ) {
			
			slicewp_set_object_collections( $affiliate_id, 'affiliate', 'group', $affiliate_group_id );

		}

	} else {

		slicewp_set_object_collections( $affiliate_id, 'affiliate', 'group', array() );

	}

}
add_action( 'slicewp_insert_affiliate', 'slicewp_admin_action_insert_update_affiliate_set_affiliate_group', 5 );
add_action( 'slicewp_update_affiliate', 'slicewp_admin_action_insert_update_affiliate_set_affiliate_group', 5 );


/**
 * Adds the notes card to the secondary (sidebar) section in the add/edit affiliate group.
 *
 */
function slicewp_views_affiliate_group_add_notes_card() {

	if ( empty( $_GET['subpage'] ) ) {
		return;
	}

	$object_context = 'collection';
	$object_id		= ( ! empty( $_GET['affiliate_group_id'] ) ? absint( $_GET['affiliate_group_id'] ) : 0 );

	$notes_outputter = new SliceWP_Outputter_Notes( $object_context, $object_id );
	$notes_outputter->output_card();

}
add_action( 'slicewp_view_affiliate_groups_add_affiliate_group_secondary', 'slicewp_views_affiliate_group_add_notes_card' );
add_action( 'slicewp_view_affiliate_groups_edit_affiliate_group_secondary', 'slicewp_views_affiliate_group_add_notes_card' );


/**
 * Adds the "group" selector filter to the affiliates admin list table.
 * 
 */
function slicewp_list_table_affiliates_data_filters_output_affiliate_groups_selector() {

	// Bail if there aren't any affiliate groups.
    if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
        return;
    }

	$affiliate_groups  = slicewp_get_collections( array( 'number' => -1, 'object_context' => 'affiliate', 'type' => 'group' ) );
	$selected_group_id = ( ! empty( $_GET['affiliate_group_id'] ) ? absint( $_GET['affiliate_group_id'] ) : '' );

	echo '<div class="slicewp-list-table-data-filter slicewp-list-table-data-filter-affiliate-group">';

		echo '<label for="slicewp-list-table-data-filter-affiliate-group" class="screen-reader-text">' . __( 'Affiliate Group', 'slicewp' ) . '</label>';

		echo '<select id="slicewp-list-table-data-filter-affiliate-group" class="slicewp-select2 slicewp-select2-small" name="affiliate_group_id">';

			echo '<option value="">' . __( 'Select group...', 'slicewp' ) . '</option>';

			foreach ( $affiliate_groups as $affiliate_group ) {
				echo '<option value="' . absint( $affiliate_group->get( 'id' ) ) . '" ' . selected( $selected_group_id, $affiliate_group->get( 'id' ) ) . '>' . esc_html( $affiliate_group->get( 'name' ) ) . '</option>';
			}

		echo '</select>';

	echo '</div>';

}
add_action( 'slicewp_list_table_affiliates_data_filters_output', 'slicewp_list_table_affiliates_data_filters_output_affiliate_groups_selector' );


/**
 * Appends the "collections" argument to the query args of the slicewp_get_affiliates queries from the "affiliates" page.
 * 
 * @param array $args
 * 
 * @return array
 * 
 */
function slicewp_get_affiliates_args_add_affiliate_group_filter( $args ) {

	if ( empty( $_GET['page'] ) || $_GET['page'] !== 'slicewp-affiliates' ) {
		return $args;
	}

	if ( empty( $_GET['affiliate_group_id'] ) ) {
		return $args;
	}

	if ( ! is_admin() ) {
		return $args;
	}

	global $wp_current_filter;

	if ( ! in_array( 'slicewp_page_slicewp-affiliates', $wp_current_filter ) ) {
		return $args;
	}

	$args['collections'] = ( ! empty( $args['collections'] ) ? $args['collections'] : array() );

	$args['collections'][] = array( 'in', 'collection_id', absint( $_GET['affiliate_group_id'] ) );
	
	return $args;

}
add_filter( 'slicewp_get_affiliates_args', 'slicewp_get_affiliates_args_add_affiliate_group_filter' );


/**
 * Registers the "Add to group" bulk action for the "Affiliates" table.
 * 
 * @param array $actions
 * 
 * @return array
 * 
 */
function slicewp_list_table_affiliates_bulk_actions_add_to_group( $actions ) {

    // Bail if there aren't any affiliate groups.
    if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
        return $actions;
    }

    $affiliate_group_actions = array(
        'add_to_group' => __( 'Add to group', 'slicewp' )
    );

    $actions = $affiliate_group_actions + $actions;

    return $actions;

}
add_filter( 'slicewp_list_table_affiliates_bulk_actions', 'slicewp_list_table_affiliates_bulk_actions_add_to_group' );


/**
 * Registers the "Add to group" row action for the "Affiliates" table.
 * 
 * @param array $actions
 * @param array $item
 * 
 * @return array
 * 
 */
function slicewp_list_table_affiliates_row_actions_add_to_group( $actions, $item ) {

    // Bail if there aren't any affiliate groups.
    if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
        return $actions;
    }

    $affiliate_group_actions = array(
        'add_to_group' => '<a href="#" class="slicewp-list-table-row-action" data-action="add_to_group" data-affiliate-id="' . absint( $item['id'] ) . '">' . __( 'Add to group', 'slicewp' ) . '</a>'
    );

    $actions = $affiliate_group_actions + $actions;

    return $actions;

}
add_filter( 'slicewp_list_table_affiliates_row_actions', 'slicewp_list_table_affiliates_row_actions_add_to_group', 15, 2 );


/**
 * Registers the "add_affiliates_to_group_success" success message.
 * 
 */
function slicewp_register_admin_notices_affiliate_groups_affiliates() {

    if ( empty( $_GET['page'] ) || $_GET['page'] != 'slicewp-affiliates' ) {
        return;
    }

    if ( empty( $_GET['slicewp_message'] ) || $_GET['slicewp_message'] != 'add_affiliates_to_group_success' ) {
        return;
    }

    if ( empty( $_GET['updated'] ) ) {
        return;
    }

    $updated = json_decode( stripslashes_deep( $_GET['updated'] ), true );

    // Get affiliate group.
    $affiliate_group = slicewp_get_collection( $updated['affiliate_group_id'] );
    
    if ( count( $updated['affiliate_ids'] ) == 1 ) {

        $affiliate_name = slicewp_get_affiliate_name( absint( $updated['affiliate_ids'][0] ) );

        slicewp_admin_notices()->register_notice( 'add_affiliates_to_group_success', '<p>' . sprintf( __( '%s successfully added to the %s group.', 'slicewp' ), '<strong>' . $affiliate_name . '</strong>', '<strong>' . $affiliate_group->get( 'name' ) . '</strong>' ) . '</p>' );

    } else {

        slicewp_admin_notices()->register_notice( 'add_affiliates_to_group_success', '<p>' . sprintf( __( '%d affiliates successfully added to the %s group.', 'slicewp' ), count( $updated['affiliate_ids'] ), '<strong>' . $affiliate_group->get( 'name' ) . '</strong>' ) . '</p>' );

    }

}
add_action( 'admin_init', 'slicewp_register_admin_notices_affiliate_groups_affiliates' );


/**
 * Outputs the "add affiliates to group" modal, used by bulk actions and row actions from 
 * the affiliates admin table.
 * 
 */
function slicewp_output_modal_add_affiliates_to_group() {

    if ( empty( $_GET['page'] ) || $_GET['page'] != 'slicewp-affiliates' ) {
        return;
    }

    // Bail if there aren't any affiliate groups.
    if ( empty( slicewp()->globals()->get( 'affiliate_groups_count', 0 ) ) ) {
        return;
    }

    include 'views/view-modal-add-affiliates-to-group.php';
    
}
add_action( 'admin_footer', 'slicewp_output_modal_add_affiliates_to_group' );