<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

// Verify for affiliate group ID.
$affiliate_group_id = ( ! empty( $_GET['affiliate_group_id'] ) ? absint( $_GET['affiliate_group_id'] ) : 0 );

if ( empty( $affiliate_group_id ) ) {
	return;
}

// Get the affiliate group data.
$affiliate_group = slicewp_get_collection( $affiliate_group_id );

if ( is_null( $affiliate_group ) ) {
	return;
}

?>

<div class="wrap slicewp-wrap slicewp-wrap-edit-affiliate-group">

	<form action="" method="POST">

		<!-- Page Heading -->
		<h1 class="wp-heading-inline"><?php echo __( 'Edit Affiliate Group', 'slicewp' ); ?></h1>
		<hr class="wp-header-end" />

		<div id="slicewp-content-wrapper">

			<!-- Primary Content -->
			<div id="slicewp-primary">

				<div class="slicewp-card slicewp-first">

					<div class="slicewp-card-header">
						<span class="slicewp-card-title"><?php echo __( 'Group Details', 'slicewp' ); ?></span>
					</div>

					<!-- Form Fields -->
					<div class="slicewp-card-inner">

						<!-- Affiliate Group Name -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-affiliate-group-name"><?php echo __( 'Name', 'slicewp' ); ?> *</label>
                                <?php echo slicewp_output_tooltip( __( 'A name so that you can quickly identify the group.', 'slicewp' ) ); ?>
							</div>
							
							<input id="slicewp-affiliate-group-name" name="group_name" type="text" required value="<?php echo esc_attr( ! empty( $_POST['group_name'] ) ? $_POST['group_name'] : $affiliate_group->get( 'name' ) ); ?>" />

						</div>

                        <!-- Affiliate Group Description -->
                        <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                            <div class="slicewp-field-label-wrapper">
								<label for="slicewp-affiliate-group-description"><?php echo __( 'Description', 'slicewp' ); ?></label>
                                <?php echo slicewp_output_tooltip( __( 'A description so that you can add more context to the group. This description is visible only by administrators.', 'slicewp' ) ); ?>
							</div>

                            <textarea id="slicewp-affiliate-group-description" name="group_description"><?php echo esc_textarea( ! empty( $_POST['group_description'] ) ? $_POST['group_description'] : slicewp_get_collection_meta( $affiliate_group_id, '_description', true ) ); ?></textarea>

                        </div>
					
					</div>

				</div>

                <!-- Commission Rates -->
                <div class="slicewp-card">

                    <div class="slicewp-card-header">
                        <span class="slicewp-card-title"><?php echo __( 'Commission Rates', 'slicewp' ); ?></span>

                        <div class="slicewp-card-actions">
                            <a href="https://slicewp.com/docs/commission-rates/#commission-rates-per-affiliate-group" target="_blank" class="slicewp-button-info" title="<?php echo esc_attr( __( 'Click to learn more...', 'slicewp' ) ); ?>"><svg height="18" width="18" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><g><path d="M13 9h-2V7h2v2zm0 2h-2v6h2v-6zm-1-7c-4.41 0-8 3.59-8 8s3.59 8 8 8 8-3.59 8-8-3.59-8-8-8m0-2c5.523 0 10 4.477 10 10s-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2z"></path></g></svg></a>
                        </div>
                    </div>

                    <div class="slicewp-card-inner">

                        <?php 
                            $commission_types = slicewp_get_available_commission_types( true );
                            $currency_symbol  = slicewp_get_currency_symbol( slicewp_get_setting( 'active_currency', 'USD' ) );
                        ?>

                        <?php foreach ( $commission_types as $type => $details ): ?>

                            <?php if ( $type == 'recurring' || $type == 'lifetime_sale' ) continue; ?>

                            <?php
                                $rate 	   = slicewp_get_collection_meta( $affiliate_group_id, '_commission_rate_' . $type, true );
                                $rate_type = slicewp_get_collection_meta( $affiliate_group_id, '_commission_rate_type_' . $type, true );
                            ?>

                            <div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-field-wrapper-commission-rate">

                                <div class="slicewp-field-label-wrapper">
                                    <label for="slicewp-commission-rate-<?php echo str_replace( '_', '-', $type ); ?>">
                                        <?php echo sprintf( __( '%s rate', 'slicewp' ), $details['label'] ); ?>
                                    </label>
                                </div>

                                <input id="slicewp-commission-rate-<?php echo str_replace( '_', '-', $type ); ?>" name="commission_rate_<?php echo esc_attr( $type ); ?>" type="number" step="any" min="0" value="<?php echo esc_attr( ! empty( $_POST['commission_rate_' . $type] ) ? $_POST['commission_rate_' . $type] : $rate ); ?>" />					

                                <select name="commission_rate_type_<?php echo esc_attr( $type ); ?>" class="slicewp-select2">
                                    <option value=""><?php echo __( 'Site default', 'slicewp' ); ?></option>
                                    <?php foreach ( $details['rate_types'] as $details_rate_type ): ?>
                                        <option value="<?php echo esc_attr( $details_rate_type ); ?>" <?php ( ! empty( $_POST['commission_rate_type_' . $type] ) ? selected( $_POST['commission_rate_type_' . $type], $details_rate_type ) : selected( $rate_type, $details_rate_type ) ); ?>><?php echo ( $details_rate_type == 'percentage' ? __( 'Percentage (%)', 'slicewp' ) : sprintf( __( 'Fixed Amount (%s)', 'slicewp' ), $currency_symbol ) ); ?></option>
                                    <?php endforeach; ?>
                                </select>

                            </div>

                        <?php endforeach; ?>

                        <div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-last" style="display: none;">

                            <div class="slicewp-field-label-wrapper">
                                <label>
                                    <?php echo __( 'Sale Commission Basis', 'slicewp' ); ?>
                                </label>
                            </div>

                            <select id="slicewp-fixed-amount-commission-basis" name="commission_fixed_amount_rate_basis" class="slicewp-select2">
                                <option value="product" <?php echo ( ! empty( $_POST['commission_fixed_amount_rate_basis'] ) && $_POST['commission_fixed_amount_rate_basis'] == 'product' ? 'selected="selected"' : ( slicewp_get_collection_meta( $affiliate_group_id, '_commission_fixed_amount_rate_basis', true ) == 'product' ? 'selected="selected"' : '' ) ); ?>><?php echo __( 'Fixed amount per product', 'slicewp' ); ?></option>
                                <option value="order" <?php echo ( ! empty( $_POST['commission_fixed_amount_rate_basis'] ) && $_POST['commission_fixed_amount_rate_basis'] == 'order' ? 'selected="selected"' : ( slicewp_get_collection_meta( $affiliate_group_id, '_commission_fixed_amount_rate_basis', true ) == 'order' ? 'selected="selected"' : '' ) ); ?>><?php echo __( 'Fixed amount per order', 'slicewp' ); ?></option>
                            </select>

                        </div>

                    </div>

                </div>
                <!-- / Commission Rates -->

				<?php 

					/**
					 * Hook to add extra cards if needed.
					 *
					 */
					do_action( 'slicewp_view_affiliate_groups_edit_affiliate_group_bottom' );

				?>

			</div><!-- / Primary Content -->

			<!-- Sidebar Content -->
			<div id="slicewp-secondary">

				<?php

					/**
					 * Hook to add extra cards if needed in the sidebar.
					 *
					 */
					do_action( 'slicewp_view_affiliate_groups_edit_affiliate_group_secondary' );

				?>

			</div><!-- / Sidebar Content -->

		</div>

		<!-- Action and nonce -->
		<input type="hidden" name="slicewp_action" value="update_affiliate_group" />
		<?php wp_nonce_field( 'slicewp_update_affiliate_group', 'slicewp_token', false ); ?>

        <!-- Hidden affiliate group id field -->
		<input type="hidden" name="affiliate_group_id" value="<?php echo $affiliate_group_id; ?>" />

        <!-- Submit -->
        <div id="slicewp-content-actions">
            
            <input type="submit" class="slicewp-form-submit slicewp-button-primary" value="<?php echo __( 'Update Affiliate Group', 'slicewp' ); ?>" />

            <span class="slicewp-trash"><a onclick="return confirm( '<?php echo __( "Are you sure you want to delete this affiliate group? All affiliates from this group will no longer be in any group.", "slicewp" ); ?>' )" href="<?php echo wp_nonce_url( add_query_arg( array( 'page' => 'slicewp-affiliate-groups', 'slicewp_action' => 'delete_affiliate_group', 'affiliate_group_id' => absint( $affiliate_group->get( 'id' ) ) ) , admin_url( 'admin.php' ) ), 'slicewp_delete_affiliate_group', 'slicewp_token' ); ?>"><?php echo __( 'Delete affiliate group', 'slicewp' ) ?></a></span>

        </div>
		
	</form>

</div>