<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Custom Conversion shortcode class
 *
 */
class SliceWP_Shortcode_Custom_Conversion {

	/**
	 * The default attributes array.
	 *
	 * @access protected
	 * @var    array
	 *
	 */
	protected $default_atts = array();


	/**
	 * The attributes array with values collected from the request.
	 *
	 * @access protected
	 * @var    array
	 *
	 *
	 */
	protected $request_atts = array();


	/**
	 * Constructor.
	 *
	 */
	public function __construct() {

		$this->default_atts = array(
			'amount' 	=> 0,
			'origin' 	=> '',
			'reference' => '',
			'type'		=> 'sale',
			'status'	=> 'pending'
		);

		add_action( 'wp_loaded', array( $this, 'prepare_request_atts' ) );

		add_shortcode( 'slicewp_custom_conversion', array( $this, 'shortcode' ) );

	}


	/**
	 * Looks for the default atts keys in the $_REQUEST array, pulls the data if it exists,
	 * sanitizes it and adds it to the $request_atts attribute.
	 *
	 */
	public function prepare_request_atts() {

		foreach ( array_keys( $this->default_atts ) as $key ) {

			if ( isset( $_REQUEST[$key] ) ) {

				switch ( $key ) {

					case 'amount':
						$this->request_atts[$key] = slicewp_sanitize_amount( $_REQUEST[$key] );
						break;
					
					default:
						$this->request_atts[$key] = sanitize_text_field( $_REQUEST[$key] );
						break;

				}

			}

		}

		/**
		 * Filter the request atts
		 *
		 * @param array
		 *
		 */
		$this->request_atts = apply_filters( 'slicewp_custom_conversion_request_atts', $this->request_atts );

	}


	/**
	 * The shortcode handler callback
	 *
	 * @param mixed $atts - an associative array of attributes, or an empty string if no attributes are given
	 *
	 */
	public function shortcode( $atts ) {

		if ( is_admin() ) {
			return;
		}

		if ( defined( 'REST_REQUEST' ) && REST_REQUEST ) {
			return;
		}

		$atts = shortcode_atts( array_merge( $this->default_atts, $this->request_atts ), $atts, 'slicewp_custom_conversion' );

		?>

		<script type="text/javascript">

			var slicewp_custom_conversion_script = function() {

				/**
				 * Get a cookie
				 *
				 * @param {string} name
				 *
				 * @return {string}
				 *
				 */
				function get_cookie( name ) {

					var name = name + "=";
					var ca 	 = document.cookie.split(';');

					for ( var i=0; i<ca.length; i++ ) {
						var c = ca[i];
						while ( c.charAt(0)==' ' ) c = c.substring(1);
						if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
					}

					return false;

				}

				var cookie_aff   = get_cookie( 'slicewp_aff' );
				var cookie_visit = get_cookie( 'slicewp_visit' );

				if ( cookie_aff && cookie_visit ) {

					var data = new FormData();

					data.append( 'action', 'slicewp_action_ajax_register_custom_conversion' );
					data.append( 'amount', '<?php echo $atts["amount"]; ?>' );
					data.append( 'origin', '<?php echo $atts["origin"]; ?>' );
					data.append( 'reference', '<?php echo $atts["reference"]; ?>' );
					data.append( 'type', '<?php echo $atts["type"]; ?>' );
					data.append( 'status', '<?php echo $atts["status"]; ?>' );
					data.append( 'slicewp_token', '<?php echo wp_create_nonce( "slicewp_custom_conversion" ); ?>' );

					var request = new XMLHttpRequest();

					request.open( 'POST', slicewp_ajaxurl, true );

					request.onload = function() {

						if ( this.status >= 200 && this.status < 400 ) {

							// For debugging purposes.
							console.log( JSON.parse( this.response ) );

						}

					};

					request.send( data );

				}

			}

			if ( document.readyState === "complete" || ( document.readyState !== "loading" && ! document.documentElement.doScroll ) ) {

				slicewp_custom_conversion_script();

			} else {

				document.addEventListener( "DOMContentLoaded", slicewp_custom_conversion_script );

			}

		</script>

		<?php

	}

}

new SliceWP_Shortcode_Custom_Conversion();